@@ -1,5 +1,5 @@
 ;;; dtk-speak.el --- Provides Emacs Lisp interface to speech server
-;;;$Id: dtk-speak.el 5348 2007-11-01 17:32:59Z tv.raman.tv $
+;;;$Id: dtk-speak.el 8500 2013-11-02 01:54:49Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacs interface to TTS
 ;;; Keywords: Dectalk Emacs Elisp
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-11-01 10:32:59 -0700 (Thu, 01 Nov 2007) $ |
+;;; $Date: 2008-07-06 10:18:30 -0700 (Sun, 06 Jul 2008) $ |
 ;;;  $Revision: 4670 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -53,13 +53,40 @@
 
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
-(require 'backquote)
 (require 'custom)
 (require 'dtk-interp)
-(require 'dectalk-voices)
-(require 'outloud-voices)
-(require 'multispeech-voices)
+(require 'dtk-unicode)
+
 (require 'espeak-voices)
+(require 'flite-voices)
+
+;;}}}
+;;{{{ Forward Declarations:
+(declare-function emacspeak-auditory-icon "emacspeak-sounds.el" (icon))
+(declare-function emacspeak-queue-auditory-icon "emacspeak-sounds.el" (icon))
+;;;###autoload 
+(defvar dtk-program
+  (or  (getenv "DTK_PROGRAM" ) "dtk-exp")
+  "The program to use to talk to the speech engine.
+Possible choices at present:
+dtk-exp     For the Dectalk Express.
+dtk-mv      for the Multivoice and older Dectalks.
+outloud     For IBM ViaVoice Outloud
+multispeech For Multilingual speech server
+espeak      For eSpeak
+The default is dtk-exp.")
+
+(defvar dtk-program-args
+  (when (getenv "DTK_PROGRAM_ARGS")
+    (split-string   (getenv "DTK_PROGRAM_ARGS")))
+  "Arguments passed to the dtk-program")
+
+(defvar emacspeak-pronounce-pronunciation-table)
+(defvar emacspeak-ssh-tts-server )
+(defvar emacspeak-auditory-icon-function )
+(defvar emacspeak-directory )
+(defvar emacspeak-use-auditory-icons )
+(defvar emacspeak-pronounce-pronunciation-personality )
 
 ;;}}}
 ;;{{{  user customizations:
@@ -76,22 +103,17 @@ Particularly useful for web browsing."
   :group  'dtk
   :group  'tts)
 (make-variable-buffer-local 'tts-strip-octals)
+
 ;;;###autoload
-(defcustom dtk-stop-immediately-while-typing t
-  "*Set it to nil if you dont want speech to flush as you
-type.  You can use command
-`dtk-toggle-stop-immediately-while-typing' bound to
-\\[dtk-toggle-stop-immediately-while-typing] to toggle this setting."
-  :group 'tts
-  :type 'boolean)
-(make-variable-buffer-local 'dtk-stop-immediately-while-typing)
 ;;;###autoload
-(defcustom dtk-speech-rate-base 50
+(defcustom dtk-speech-rate-base
+  (if (string-match "dtk" dtk-program) 180 50)
   "*Value of lowest tolerable speech rate."
   :type 'integer
   :group 'tts)
 ;;;###autoload
-(defcustom dtk-speech-rate-step 50
+(defcustom dtk-speech-rate-step
+  (if (string-match "dtk" dtk-program) 50 8)
   "*Value of speech rate increment.
 This determines step size used when setting speech rate via command
 `dtk-set-predefined-speech-rate'.  Formula used is
@@ -106,17 +128,6 @@ hook."
   :type 'hook
   :group 'tts)
 
-(defvar dtk-program
-  (or  (getenv "DTK_PROGRAM" ) "dtk-exp")
-  "The program to use to talk to the speech engine.
-Possible choices at present:
-dtk-exp     For the Dectalk Express.
-dtk-mv      for the Multivoice and older Dectalks.
-outloud     For IBM ViaVoice Outloud
-multispeech For Multilingual speech server
-espeak      For eSpeak
-The default is dtk-exp.")
-
 (defvar dtk-quiet nil
   "Switch indicating if the speech synthesizer is to keep quiet.
 Do not set this variable by hand.
@@ -157,7 +168,7 @@ Do not set this variable by hand, use command
   "Non-nil means produce a beep to indicate  capitalization.
 Do not set this variable by hand, use command dtk-toggle-capitalization
 bound to \\[dtk-toggle-capitalization].")
-(make-variable-buffer-local 'dtk-captialize)
+(make-variable-buffer-local 'dtk-capitalize)
 
 (defvar dtk-allcaps-beep nil
   "Option to indicate capitalization.
@@ -172,7 +183,9 @@ split caps Do not set this variable by hand, use command
 (defvar dtk-last-output nil
   "Variable holding last output.")
 
-(defvar dtk-speech-rate 225
+(defvar dtk-speech-rate
+  (if (string-match "dtk" dtk-program)
+      225 100)
   "Rate at which tts talks.
 Do not modify this variable directly; use command  `dtk-set-rate'
  bound to \\[dtk-set-rate].")
@@ -317,29 +330,26 @@ Argument PITCH   is specified in hertz.
 Argument DURATION  is specified in milliseconds.
 Optional argument FORCE  flushes the command to the speech server."
   (declare (special dtk-quiet dtk-speaker-process
-                    dtk-use-tones
-                    dtk-speak-server-initialized))
-  (unless dtk-quiet
-    (when (and dtk-use-tones
-               dtk-speak-server-initialized)
-      (dtk-interp-tone pitch duration force))))
+                    dtk-use-tones dtk-speak-server-initialized))
+  (unless
+      (or dtk-quiet
+          (not dtk-use-tones)
+          (not dtk-speak-server-initialized))
+    (dtk-interp-tone pitch duration force)))
 
 (defun dtk-set-language (lang)
   "Set language according to the argument lang."
   (interactive "sEnter new language: \n")
   (declare (special dtk-quiet dtk-speaker-process
                     dtk-speak-server-initialized))
-  ;;  (unless dtk-quiet
-  (when dtk-speak-server-initialized
-    (dtk-interp-language lang (interactive-p))))
-;;)
+  (when dtk-speak-server-initialized (dtk-interp-language lang (ems-interactive-p ))))
 
 (defun dtk-set-next-language ()
   "Switch to the next available language"
   (interactive)
   (declare (special dtk-speak-server-initialized))
   (when dtk-speak-server-initialized
-    (dtk-interp-next-language (interactive-p))))
+    (dtk-interp-next-language (ems-interactive-p ))))
 ;;)
 
 (defun dtk-set-previous-language ()
@@ -349,7 +359,7 @@ Optional argument FORCE  flushes the command to the speech server."
                     dtk-speak-server-initialized))
   ;;  (unless dtk-quiet
   (when dtk-speak-server-initialized
-    (dtk-interp-previous-language (interactive-p))))
+    (dtk-interp-previous-language (ems-interactive-p ))))
 ;;)
 
 (defun dtk-set-preferred-language (alias lang)
@@ -384,8 +394,9 @@ will set \"en_GB\".
 ;;;  [] marks dtk commands; {} is special to tcl
 ;;; Optionally post-process the text with cleanup function if one is specified.
 (defconst dtk-bracket-regexp
-  "[][{}<>\\|`#]"
+  "[][{}<>\\|`#\n]"
   "Brackets and other chars  that are special to dtk and tcl.
+Newlines  become spaces so each server request is a single line.
 {} is special to tcl.
 [] is special to both dtk and tcl.
 <> and | are fixed to improve pronunciation.
@@ -400,7 +411,7 @@ will set \"en_GB\".
 
 (defsubst  dtk-fix-brackets (mode)
   "Quote any delimiters that need special treatment.
-Argument MODE  specifies the current pronunciation mode."
+Argument MODE  specifies the current pronunciation mode --- See \\[dtk-bracket-regexp]"
   (declare  (special dtk-bracket-regexp ))
   (let ((inhibit-read-only t))
     (goto-char (point-min))
@@ -414,6 +425,8 @@ Argument MODE  specifies the current pronunciation mode."
                 (get-text-property
                  start 'personality))
           (cond
+           ((= 10  (char-after (match-beginning 0 ))) ; newline
+            (replace-match " "))
            ((= ?| (char-after (match-beginning 0 )))
             (replace-match " pipe "))
            ((= ?< (char-after (match-beginning 0 )))
@@ -440,6 +453,7 @@ Argument MODE  specifies the current pronunciation mode."
      (t
       (while (re-search-forward dtk-bracket-regexp   nil t )
         (replace-match " " nil t ))))))
+
 ;;;###autoload
 (defcustom dtk-speak-nonprinting-chars nil
   "*Option that specifies handling of non-printing chars.
@@ -596,29 +610,32 @@ Argument COMPLEMENT  is the complement of separator."
 
 (defsubst dtk-speak-using-voice (voice text)
   "Use voice VOICE to speak text TEXT."
-  (declare (special tts-voice-reset-code))
+  (declare (special tts-voice-reset-code dtk-quiet))
+                                        ; ensure text is a  string
+  (unless (stringp text) (setq text (format "%s" text)))
   (unless (or (eq 'inaudible voice )
-              (and (listp voice)
-                   (member 'inaudible voice)))
-    (dtk-interp-queue
-     (format "%s%s %s \n"
-             (cond
-              ((symbolp voice)
-               (tts-get-voice-command
-                (if (boundp  voice )
-                    (symbol-value voice )
-                  voice)))
-              ((listp voice)
-               (mapconcat  #'(lambda (v)
-                               (tts-get-voice-command
-                                (if (boundp  v )
-                                    (symbol-value v )
-                                  v)))
-                           voice
-                           " "))
-              (t       ""))
-             text
-             tts-voice-reset-code))))
+              dtk-quiet
+              (null text)
+              (string-equal  text "")
+              (and (listp voice) (memq 'inaudible voice)))
+    (dtk-interp-queue-code
+     (cond
+      ((symbolp voice)
+       (tts-get-voice-command
+        (if (boundp  voice )
+            (symbol-value voice )
+          voice)))
+      ((listp voice)
+       (mapconcat  #'(lambda (v)
+                       (tts-get-voice-command
+                        (if (boundp  v )
+                            (symbol-value v )
+                          v)))
+                   voice
+                   " "))
+      (t       "")))
+    (dtk-interp-queue text)
+    (dtk-interp-queue-code tts-voice-reset-code)))
 
 ;;;Internal function used by dtk-speak to send text out.
 ;;;Handles voice locking etc.
@@ -629,15 +646,6 @@ Argument COMPLEMENT  is the complement of separator."
 ;;; causes the sound
 ;;; to be queued.
 
-(defsubst tts-get-overlay-personality (position)
-  "Return personality at the front of the overlay list at position."
-  (car
-   (delete nil
-           (mapcar
-            #'(lambda (o)
-                (overlay-get o 'personality))
-            (overlays-at position)))))
-
 (defsubst tts-get-overlay-auditory-icon (position)
   "Return auditory icon  at the front of the overlay list at position."
   (car
@@ -647,16 +655,25 @@ Argument COMPLEMENT  is the complement of separator."
                 (overlay-get o 'auditory-icon))
             (overlays-at position)))))
 
+(defsubst tts-get-overlay-personality (position)
+  "Return personality at the front of the overlay list at position."
+  (car
+   (delete nil
+           (mapcar
+            #'(lambda (o)
+                (overlay-get o 'personality))
+            (overlays-at position)))))
+
 (defsubst next-true-single-property-change (start  prop object  limit)
   "Similar to next-single-property-change, but compares property values with equal if they are not atoms."
   (let ((initial-value (get-text-property start  prop object)))
     (if (atom initial-value)
-	(next-single-property-change start prop object limit)
+        (next-single-property-change start prop object limit)
       (let ((pos start))
-	(while  (and (< pos limit)
-		     (equal initial-value (get-text-property pos prop object)))
-	  (setq pos (next-single-property-change pos prop object limit)))
-	pos))))
+        (while  (and (< pos limit)
+                     (equal initial-value (get-text-property pos prop object)))
+          (setq pos (next-single-property-change pos prop object limit)))
+        pos))))
 
 (defsubst dtk-format-text-and-speak (start end )
   "Format and speak text.
@@ -668,7 +685,7 @@ Arguments START and END specify region to speak."
              (get-text-property start 'auditory-icon))
     (emacspeak-queue-auditory-icon
      (get-text-property start 'auditory-icon)))
-  (dtk-interp-queue (format "%s\n" tts-voice-reset-code))
+  (dtk-interp-queue-code tts-voice-reset-code)
   (cond
    (voice-lock-mode
     (let ((last  nil)
@@ -676,15 +693,14 @@ Arguments START and END specify region to speak."
       (while (and (< start end )
                   (setq last
                         (next-true-single-property-change start 'personality
-                                                      (current-buffer) end)))
+                                                          (current-buffer) end)))
         (if personality
-            (dtk-speak-using-voice personality
-                                   (buffer-substring start last ))
+            (dtk-speak-using-voice personality (buffer-substring start last ))
           (dtk-interp-queue (buffer-substring  start last)))
         (setq start  last
               personality
               (get-text-property last  'personality))) ; end while
-      ))                                               ; end clause
+      ))                                ; end clause
    (t (dtk-interp-queue (buffer-substring start end  )))))
 
                                         ;Force the speech.
@@ -780,7 +796,10 @@ Argument OUTPUT is the newly arrived output."
         (setq ,switch (default-value ',switch )))
        (t  (make-local-variable ',switch)
            (setq ,switch (not ,switch ))))
-      (when (interactive-p)
+      (when
+          (if (fboundp 'called-interactively-p)
+              (called-interactively-p 'interactive)
+            (interactive-p))
         (emacspeak-auditory-icon (if ,switch 'on 'off))
         (message "Turned %s %s  %s."
                  (if ,switch "on" "off" )
@@ -810,9 +829,7 @@ current local  value to the result."
       (setq dtk-speech-rate rate))
      (t (setq dtk-speech-rate rate)))
     (dtk-interp-set-rate rate)
-    (when prefix
-      (tts-configure-synthesis-setup dtk-program))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Set speech rate to %s %s"
                rate
                (if prefix "" "locally")))))
@@ -826,10 +843,10 @@ rate = dtk-speech-rate-base + dtk-speech-rate-step * level."
   (interactive "P")
   (declare (special dtk-speech-rate-step
                     dtk-speech-rate-base
-                    last-input-char))
+                    last-input-event))
   (let ((level
          (condition-case nil
-             (read (format "%c" last-input-char ))
+             (read (format "%c" last-input-event ))
            (error nil ))))
     (or (numberp level)
         (setq level
@@ -844,10 +861,9 @@ speech rate:")))
          (+ dtk-speech-rate-base
             (* dtk-speech-rate-step  level ))
          prefix )
-        (when (interactive-p)
-          (message "Set speech rate to level %s %s"
-                   level
-                   (if prefix " globaly " " locally ")))))))
+        (when (ems-interactive-p )
+          (message "Set speech rate to level %s"
+                   level))))))
 
 ;;;###autoload
 (defun dtk-set-character-scale (factor &optional prefix)
@@ -867,7 +883,7 @@ current local  value to the result."
      (t (make-local-variable 'dtk-character-scale)
         (setq dtk-character-scale factor)))
     (dtk-interp-set-character-scale dtk-character-scale)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Set character scale factor to %s %s"
                dtk-character-scale
                (if  prefix ""  "locally")))))
@@ -878,13 +894,6 @@ current local  value to the result."
 Turning on this switch silences speech.
 Optional interactive prefix arg causes this setting to become global.")
 
-(ems-generate-switcher 'dtk-toggle-stop-immediately-while-typing
-                       'dtk-stop-immediately-while-typing
-                       "Toggle state of variable `dtk-stop-immediately-while-typing'.
-As the name implies, if T then speech flushes immediately as you
-type.  Optional argument PREFIX specifies if the setting applies
-to all buffers.")
-
 (ems-generate-switcher 'dtk-toggle-split-caps
                        'dtk-split-caps
                        "Toggle split caps mode.
@@ -956,7 +965,7 @@ current local  value to the result."
      (t (make-local-variable 'dtk-punctuation-mode)
         (setq dtk-punctuation-mode mode )))
     (dtk-interp-set-punctuations mode)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "set punctuation mode to %s %s"
                mode
                (if prefix "" "locally")))))
@@ -986,7 +995,7 @@ Interactive PREFIX arg makes the new setting global."
     (dtk-set-punctuations-to-some prefix ))
    ((eq 'some  dtk-punctuation-mode )
     (dtk-set-punctuations-to-all prefix )))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "set punctuation mode to %s %s"
              dtk-punctuation-mode
              (if prefix "" "locally"))))
@@ -1013,31 +1022,19 @@ Typically used after the Dectalk has been power   cycled."
   "Records if speech has been paused.")
 
 ;;;###autoload
-(defun dtk-pause (&optional prefix)
-  "Pause ongoing speech.
-The speech can be resumed with command `dtk-resume'
-normally bound to \\[dtk-resume].  Pausing speech is useful when one needs to
-perform a few actions before continuing to read a large document.  Emacspeak
-gives you speech feedback as usual once speech has been paused.  `dtk-resume'
-continues the interrupted speech irrespective of the buffer
-in which it is executed.
-Optional PREFIX arg flushes any previously paused speech."
-  (interactive "P")
+(defun dtk-pause ()
+  "Temporarily pause / resume speech."
+  (interactive)
   (declare (special dtk-paused))
   (cond
    ((not dtk-paused)
     (dtk-interp-pause)
     (setq dtk-paused t)
     (emacspeak-auditory-icon 'button))
-   ((and (interactive-p)
-         prefix
-         dtk-paused)
-    (dtk-interp-pause)
-    (dtk-speak "Flushed previously paused speech ")
-    (setq dtk-paused t))
-   ((and dtk-paused
-         (interactive-p))
-    (emacspeak-auditory-icon 'warn-user))))
+   (t
+    (setq dtk-paused nil)
+    (dtk-interp-resume))))
+
 ;;;###autoload
 (defcustom dtk-resume-should-toggle t
   "*T means `dtk-resume' acts as a toggle."
@@ -1085,6 +1082,7 @@ You should not modify this variable;
 Use command  `dtk-set-punctuations' bound to
 \\[dtk-set-punctuations].  .")
 
+(make-variable-buffer-local 'dtk-punctuation-mode)
 ;;; forward declaration
 (defvar emacspeak-servers-directory
   (expand-file-name
@@ -1517,9 +1515,10 @@ available TTS servers.")
 (defsubst dtk-char-to-speech (char)
   "Translate CHAR to speech string."
   (declare (special dtk-character-to-speech-table))
-  (if (> char 127 )
-      (format "octal %o"  char )
-    (aref dtk-character-to-speech-table char )))
+  (if  (eq (char-charset char) 'ascii)
+      (aref dtk-character-to-speech-table char )
+    (or (dtk-unicode-short-name-for-char char)
+        (format "octal %o"  char ))))
 
 ;;}}}
 ;;{{{  interactively selecting the server:
@@ -1530,35 +1529,102 @@ This is setup on a per engine basis.")
 
 ;;; will be reset on a per TTS engine basis.
 (defalias 'tts-get-voice-command 'dectalk-get-voice-command)
-
+;;;###autoload
 (defun tts-configure-synthesis-setup (&optional tts-name)
   "Setup synthesis environment. "
   (declare (special dtk-program emacspeak-auditory-icon-function
                     tts-voice-reset-code))
   (unless tts-name (setq tts-name dtk-program))
   (cond
-   ((string-match "outloud" tts-name)
-    (outloud-configure-tts))
-   ((string-match "multispeech" tts-name)
-    (multispeech-configure-tts))
-   ((string-match "espeak" tts-name)
-    (espeak-configure-tts))
-   ((string-match "dtk-" tts-name)      ;all dectalks
-    (dectalk-configure-tts))
-   (t (dectalk-configure-tts)           ; will become
-                                        ; generic-configure)))
-      ))
+                                        ;viavoice outloud family 
+   ((string-match "outloud" tts-name) (outloud-configure-tts))
+                                        ;all dectalks
+   ((string-match "dtk-" tts-name) (dectalk-configure-tts))
+   ((string-match "^multispeech$" tts-name) (multispeech-configure-tts))
+                                        ;exact match
+   ((string-match "^mac$" tts-name) (mac-configure-tts))
+                                        ; exact match
+   ((string-match "^espeak$" tts-name) (espeak-configure-tts))
+   ((string-match "^eflite$" tts-name) (flite-configure-tts))
+   ((string-match "^log-server$" tts-name) t); use previous configuration
+                                        ; generic configure
+   (t (plain-configure-tts)))
   (when (string-match "^ssh" tts-name)  ;remote server
     (setq emacspeak-auditory-icon-function 'emacspeak-serve-auditory-icon))
   (load-library "voice-setup")
   (setq tts-voice-reset-code (tts-get-voice-command tts-default-voice)))
 
-;;; forward declaration.
+(defvar tts-device "default"
+  "Name of current sound device in use.")
+
 ;;;###autoload
-(defun dtk-select-server (program )
+(defun dtk-select-server (program &optional device)
   "Select a speech server interactively.
-Argument PROGRAM specifies the speech server program.
-When called  interactively, The selected server is started immediately. "
+Argument PROGRAM specifies the speech server program. When called
+interactively, The selected server is started
+immediately. Optional arg device sets up environment variable
+ALSA_DEFAULT to specified device before starting the server."
+  (interactive
+   (list
+    (completing-read
+     "Select speech server:"
+     (or dtk-servers-alist
+         (tts-setup-servers-alist))
+     nil
+     t  )
+    current-prefix-arg))
+  (declare (special   dtk-program dtk-servers-alist
+                      tts-device emacspeak-servers-directory
+                      emacspeak-ssh-tts-server))
+  (when (and (ems-interactive-p ) device)
+    (setq tts-device (read-from-minibuffer "ALSA_DEFAULT: ")))
+  (setenv "ALSA_DEFAULT" tts-device)
+  (let ((ssh-server (format "ssh-%s" dtk-program)))
+    (setq dtk-program program)
+    (when (file-exists-p (expand-file-name ssh-server emacspeak-servers-directory))
+      (setq emacspeak-ssh-tts-server ssh-server)
+      (setq-default emacspeak-ssh-tts-server ssh-server))
+    (when (ems-interactive-p )
+      (dtk-initialize))))
+
+(defcustom tts-device-list (list "default")
+  "List of ALSA sound devices  we can use."
+  :type '(repeat
+          (choice :tag "Device"
+                  (const   "default")
+                  (const   "$ALSA_DEFAULT")
+                  (string )))
+  :group 'dtk)
+
+;;;###autoload
+(defun tts-cycle-device (&optional restart)
+  "Cycle through available ALSA devices.
+Optional interactive prefix arg restarts current TTS server."
+  (interactive "P")
+  (declare (special tts-device tts-device-list))
+  (let ((pos (position tts-device tts-device-list :test
+                       #'string=))
+        (len (length tts-device-list)))
+    (cond
+     ((= len 1) (message "Only  one ALSA device."))
+     (t                                 ; Cycle
+      (setq tts-device
+            (nth
+             (% (+ 1 pos) len)
+             tts-device-list))
+      (setenv "ALSA_DEFAULT" tts-device)
+      (message "ALSA_DEFAULT: %s" tts-device)
+      (when current-prefix-arg (tts-restart))))))
+
+(defvar dtk-async-server-process nil
+  "Process handle to async server.")
+
+;;;###autoload
+(defun dtk-async-server (program)
+  "Select and start an async  speech server interactively.
+Async servers allow external programs like self-voicing Web browsers to use
+the Emacspeak TTS server abstraction.
+Argument PROGRAM specifies the speech server program."
   (interactive
    (list
     (completing-read
@@ -1567,16 +1633,68 @@ When called  interactively, The selected server is started immediately. "
          (tts-setup-servers-alist))
      nil
      t  )))
-  (declare (special   dtk-program dtk-servers-alist
-                      emacspeak-servers-directory emacspeak-ssh-tts-server))
-  (let ((ssh-server (format "ssh-%s" dtk-program)))
-    (setq dtk-program program)
-    (tts-configure-synthesis-setup dtk-program)
-    (when (file-exists-p (expand-file-name ssh-server emacspeak-servers-directory))
-      (setq emacspeak-ssh-tts-server ssh-server)
-      (setq-default emacspeak-ssh-tts-server ssh-server))
-    (when (interactive-p)
-      (dtk-initialize))))
+  (declare (special    dtk-servers-alist
+                       dtk-async-server-process emacspeak-servers-directory ))
+  (when (and
+         dtk-async-server-process
+         (eq 'run (process-status dtk-async-server-process)))
+    (kill-process dtk-async-server-process))
+  (setq dtk-async-server-process
+        (start-process
+         "AsyncTTS"
+         "*AsyncTTS*"
+         (executable-find "python")
+         (expand-file-name "python/HTTPSpeaker.py" emacspeak-servers-directory)
+         program)))
+
+;;;###autoload
+(defvar dtk-local-server-process nil
+  "Local server process.")
+
+;;;###autoload
+(defcustom dtk-speech-server-program "speech-server"
+  "Local speech server script."
+  :type '(choice :tag "Local Server: "
+                 (const :tag "32 Bit" "32-speech-server")
+                 (const :tag "Default" "speech-server"))
+  :group 'dtk)
+(defvar dtk-local-server-port "2222"
+  "Port where we run our local server.")
+
+(defcustom dtk-local-engine "outloud"
+  "Engine we use  for our local TTS  server."
+  :type '(choice
+          (const :tag "Dectalk Express" "dtk-exp")
+          (const :tag "Viavoice Outloud" "outloud")
+          (const :tag "32Bit ViaVoice on 64Bit Linux" "32-outloud"))
+  :group 'dtk)
+
+(defun dtk-local-server (program)
+  "Select and start an local  speech server interactively.
+Local server lets Emacspeak on a remote host connect back via SSH  port forwarding for instance.
+Argument PROGRAM specifies the speech server program.
+Port  defaults to  dtk-local-server-port"
+  (interactive
+   (list
+    (completing-read
+     "Select speech server:"
+     (or dtk-servers-alist
+         (tts-setup-servers-alist))
+     nil
+     t  )))
+  (declare (special    dtk-servers-alist dtk-local-server-port
+                       dtk-local-server-process emacspeak-servers-directory ))
+  (when (and
+         dtk-local-server-process
+         (eq 'run (process-status dtk-local-server-process)))
+    (kill-process dtk-async-server-process))
+  (setq dtk-local-server-process
+        (start-process
+         "LocalTTS"
+         "*localTTS*"
+         (expand-file-name  dtk-speech-server-program emacspeak-servers-directory)
+         dtk-local-server-port
+         (expand-file-name program  emacspeak-servers-directory))))
 
 ;;}}}
 ;;{{{  initialize the speech process
@@ -1588,30 +1706,23 @@ When called  interactively, The selected server is started immediately. "
 (defvar dtk-speak-server-initialized nil
   "Records if the server is initialized.")
 
-(defvar dtk-speak-process-connection-type nil
-  "*Specifies if we use ptys or pipes to connect to the speech server process.
-Has the same semantics as the builtin `process-connection-type'.
-Default is to use pipes.")
-
 (defvar tts-debug-buffer " *speaker*"
   "Buffer holding speech server debug output.")
 
 (defun  dtk-initialize ()
   "Initialize speech system."
-  (declare (special dtk-program tts-debug-buffer dtk-speak-process-connection-type
+  (declare (special dtk-program tts-debug-buffer 
                     dtk-speaker-process  dtk-debug
                     dtk-speak-server-initialized
                     dtk-startup-hook emacspeak-servers-directory))
   (let ((new-process nil)
-        (process-connection-type  dtk-speak-process-connection-type)
-        (dtk-program (expand-file-name dtk-program
-                                       emacspeak-servers-directory)))
+        (process-connection-type  nil))
     (setq new-process
-          (start-process
-           "speaker"
-           (and dtk-debug tts-debug-buffer)
-           (expand-file-name dtk-program
-                             emacspeak-servers-directory)))
+          (apply 'start-process
+                 "speaker"
+                 (and dtk-debug tts-debug-buffer)
+                 (expand-file-name dtk-program emacspeak-servers-directory)
+                 dtk-program-args))
     (setq dtk-speak-server-initialized
           (or (eq 'run (process-status new-process ))
               (eq 'open (process-status new-process))))
@@ -1624,11 +1735,12 @@ Default is to use pipes.")
                      (eq 'stop (process-status dtk-speaker-process ))))
         (delete-process dtk-speaker-process ))
       (setq dtk-speaker-process new-process)
-      (tts-configure-synthesis-setup dtk-program)
+      (set-process-coding-system dtk-speaker-process 'utf-8 'utf-8)
       (run-hooks 'dtk-startup-hook ))
      (t
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (message "The speech server is not running."))))))
+
 ;;;###autoload
 (defun tts-restart ()
   "Use this to nuke the currently running TTS server and restart it."
@@ -1665,10 +1777,10 @@ since the synthesizer is getting a word at a time."
   (cond
    ((not (string-match " " dtk-chunk-separator-syntax))
     (dtk-chunk-on-white-space-and-punctuations)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (message "Text will be split at punctuations and white space when speaking") ))
    (t (dtk-chunk-only-on-punctuations)
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (message "Text split  at clause boundaries")))))
 
 ;;;###autoload
@@ -1683,7 +1795,7 @@ Argument S specifies the syntax class."
     (read-from-minibuffer "Specify separator syntax string: ")))
   (declare (special dtk-chunk-separator-syntax))
   (setq dtk-chunk-separator-syntax s)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Set  separator to %s" s)))
 
 ;;}}}
@@ -1696,17 +1808,17 @@ No-op if variable `dtk-quiet' is set to t.
 If option `outline-minor-mode' is on and selective display is in effect,
 only speak upto the first ctrl-m."
   (declare (special dtk-speaker-process dtk-stop-immediately
-                    tts-strip-octals
-                    inhibit-point-motion-hooks
+                    tts-strip-octals inhibit-point-motion-hooks
                     dtk-speak-server-initialized emacspeak-use-auditory-icons
-                    dtk-speech-rate
-                    dtk-speak-nonprinting-chars
+                    dtk-speech-rate dtk-speak-nonprinting-chars
                     dtk-speak-treat-embedded-punctuations-specially
                     dtk-quiet  dtk-chunk-separator-syntax
                     voice-lock-mode   dtk-punctuation-mode
                     dtk-split-caps
                     emacspeak-pronounce-pronunciation-table
                     selective-display ))
+                                        ; ensure text is a  string
+  (unless (stringp text) (setq text (format "%s" text)))
                                         ; ensure  the process  is live
   (unless (or (eq 'run (process-status dtk-speaker-process ))
               (eq 'open (process-status dtk-speaker-process )))
@@ -1714,8 +1826,11 @@ only speak upto the first ctrl-m."
                                         ; If you dont want me to talk,
                                         ;or my server is not
                                         ;running, I will remain silent.
+                                        ; Do nothing if text is ""
   (unless
       (or dtk-quiet
+          (null text)
+          (string-equal text "")
           (not dtk-speak-server-initialized))
                                         ; flush previous speech if asked to
     (when dtk-stop-immediately (dtk-stop ))
@@ -1727,6 +1842,7 @@ only speak upto the first ctrl-m."
              (setq text (substring  text 0 ctrl-m ))
              (emacspeak-auditory-icon 'ellipses))))
     (let ((inhibit-point-motion-hooks t)
+          (deactivate-mark nil)
           (invisibility-spec buffer-invisibility-spec)
           (syntax-table (syntax-table ))
           (inherit-speaker-process dtk-speaker-process)
@@ -1738,6 +1854,7 @@ only speak upto the first ctrl-m."
           (inherit-strip-octals tts-strip-octals)
           (complement-separator(dtk-complement-chunk-separator-syntax ))
           (speech-rate dtk-speech-rate)
+          (inherit-enable-multibyte-characters enable-multibyte-characters)
           (dtk-scratch-buffer (get-buffer-create " *dtk-scratch-buffer* "))
           (start 1)
           (end nil )
@@ -1762,11 +1879,13 @@ only speak upto the first ctrl-m."
                 tts-strip-octals inherit-strip-octals
                 voice-lock-mode voice-lock)
           (set-syntax-table syntax-table )
+          (set-buffer-multibyte inherit-enable-multibyte-characters)
           (insert  text)
           (delete-invisible-text)
           (when pronunciation-table
             (tts-apply-pronunciations
              pronunciation-table))
+          (dtk-unicode-replace-chars mode)
           (dtk-handle-repeating-patterns mode)
           (dtk-quote mode))
         (goto-char (point-min))
@@ -1792,6 +1911,12 @@ only speak upto the first ctrl-m."
              (dtk-format-text-and-speak start (point-max)))))
     (dtk-force)))
 
+(defsubst dtk-speak-and-echo (message)
+  "Speak message and echo it to the message area."
+  (let ((emacspeak-speak-messages nil))
+    (dtk-speak message) 
+    (message message)))
+
 (defun dtk-speak-list (text &optional group-count)
   "Speak a  list of strings.
 Argument TEXT  is the list of strings to speak.
@@ -1834,8 +1959,11 @@ Optional argument group-count specifies grouping for intonation."
   "Say these WORDS."
   (declare (special dtk-speaker-process dtk-stop-immediately
                     dtk-speak-server-initialized dtk-quiet))
+                                        ; ensure words is a  string
+  (unless (stringp words) (setq words (format "%s" words)))
   ;; I wont talk if you dont want me to
-  (unless dtk-quiet
+  (unless
+      (or dtk-quiet (string-equal words ""))
     (or (eq 'run (process-status dtk-speaker-process ))
         (eq 'open (process-status dtk-speaker-process ))
         (dtk-initialize))
@@ -1850,7 +1978,7 @@ Optional argument group-count specifies grouping for intonation."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
