@@ -1,5 +1,5 @@
 ;;; emacspeak-alsaplayer.el --- Control alsaplayer from Emacs
-;;; $Id: emacspeak-alsaplayer.el 5339 2007-10-11 04:55:04Z tv.raman.tv $
+;;; $Id: emacspeak-alsaplayer.el 8539 2013-11-13 17:05:25Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Controlling alsaplayer from emacs 
 ;;; Keywords: Emacspeak, alsaplayer
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-10-10 21:55:04 -0700 (Wed, 10 Oct 2007) $ |
+;;; $Date: 2008-08-01 17:37:36 -0700 (Fri, 01 Aug 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -50,28 +50,41 @@
 
 ;;}}}
 ;;{{{  Required modules
-
+(require 'derived)
 (require 'emacspeak-preamble)
+(require 'emacspeak-amark)
+
 ;;}}}
 ;;{{{ define a derived mode for alsaplayer interaction
 
-(defvar emacspeak-alsaplayer-process nil
-  "Process handle to alsaplayer." )
-
 ;;;###autoload
 (define-prefix-command 'emacspeak-alsaplayer-prefix-command
   'emacspeak-alsaplayer-mode-map)
 (defun emacspeak-alsaplayer-header-line ()
   "Return information suitable for header line."
-  (substring
-   (shell-command-to-string "alsaplayer --status | grep title:")
-   0 -1))
+  (let ((title (shell-command-to-string "alsaplayer --status |
+grep title:"))
+        (path (shell-command-to-string "alsaplayer --status |
+grep path:")))
+    (cond
+     ((or (null (get-buffer-process (current-buffer)))
+          (not (eq 'run (process-status (get-buffer-process
+                                         (current-buffer))))))
+      "        No Active Session")
+     ((>  (length title) 0)
+      (substring title 6 -1))
+     ((>  (length path) 0)
+      (setq path (substring path 6 -1))
+      (substring  path
+                  (length (file-name-directory path))))
+     (t "New Session"))))
 
-(define-derived-mode emacspeak-alsaplayer-mode fundamental-mode 
+(define-derived-mode emacspeak-alsaplayer-mode special-mode 
   "Alsaplayer Interaction"
   "Major mode for alsaplayer interaction. \n\n
 \\{emacspeak-alsaplayer-mode-map}"
-  (setq header-line-format '((:eval (emacspeak-alsaplayer-header-line)))))
+  (setq header-line-format '((:eval
+                              (emacspeak-alsaplayer-header-line)))))
 
 ;;}}}
 ;;{{{ launch  emacspeak-alsaplayer
@@ -86,11 +99,6 @@
   :type 'boolean
   :group 'emacspeak-alsaplayer)
 
-(defcustom emacspeak-alsaplayer-height 1
-  "Height of alsaplayer window."
-  :type 'number
-  :group 'emacspeak-alsaplayer)
-
 ;;;###autoload
 (defcustom emacspeak-alsaplayer-program
   "alsaplayer"
@@ -105,6 +113,14 @@
   :group 'emacspeak-alsaplayer)
 (defvar emacspeak-alsaplayer-buffer "*alsaplayer*"
   "Buffer for alsaplayer interaction.")
+(defcustom emacspeak-alsaplayer-device "$ALSA_DEFAULT"
+  "Device to use for alsaplayer"
+  :type '(choice
+          (const  :tag "Ignore" nil)
+          (const  :tag "Card 1" "hw:1,0")
+          (const :tag "ALSA_DEFAULT"  "$ALSA_DEFAULT")
+          (string :tag "Custom"))
+  :group  'emacspeak-alsaplayer)
 
 ;;;###autoload
 (defun emacspeak-alsaplayer-launch ()
@@ -113,26 +129,29 @@ user is placed in a buffer associated with the newly created
 Alsaplayer session."
   (interactive)
   (declare (special emacspeak-alsaplayer-program emacspeak-alsaplayer-buffer
-		    emacspeak-alsaplayer-height))
+                    emacspeak-alsaplayer-device emacspeak-alsaplayer-height))
   (let ((buffer (get-buffer-create emacspeak-alsaplayer-buffer)))
     (save-current-buffer
       (set-buffer buffer)
       (cond
        ((and (get-buffer-process buffer)
              (eq 'run (process-status (get-buffer-process buffer))))
-        (pop-to-buffer buffer 'other-window)
-	(set-window-text-height nil emacspeak-alsaplayer-height))
+        (pop-to-buffer buffer 'other-window))
        (t
         (setq buffer-undo-list t)
         (shell-command
-         (format "%s -r -i daemon &" emacspeak-alsaplayer-program)
+         (format "%s %s -r -i daemon &"
+                 emacspeak-alsaplayer-program
+                 (if emacspeak-alsaplayer-device
+                     (format "--device %s" emacspeak-alsaplayer-device)
+                   ""))
          (current-buffer))
         (pop-to-buffer buffer 'other-window)
-	(set-window-text-height nil emacspeak-alsaplayer-height)
         (emacspeak-alsaplayer-mode)))
-    (when (and emacspeak-alsaplayer-auditory-feedback (interactive-p))
-      (emacspeak-auditory-icon 'open-object)
-      (emacspeak-speak-mode-line)))))
+      (when (and emacspeak-alsaplayer-auditory-feedback (ems-interactive-p ))
+        (emacspeak-auditory-icon 'open-object)
+        (emacspeak-amark-load)
+        (emacspeak-speak-mode-line)))))
 
 ;;}}}
 ;;{{{  Invoke commands:
@@ -158,7 +177,7 @@ Optional second arg watch-pattern specifies line of output to
              (eq (current-buffer) (get-buffer emacspeak-alsaplayer-buffer)))
     (goto-char (point-min))
     (search-forward watch-pattern  nil t)))
-         
+
 (defun emacspeak-alsaplayer-add-to-queue (resource)
   "Add specified resource to queue."
   (interactive
@@ -166,11 +185,12 @@ Optional second arg watch-pattern specifies line of output to
     (let ((completion-ignore-case t)
           (read-file-name-completion-ignore-case t))
       (expand-file-name
-       (read-file-name "Media Resource: "
-                       (if 
-                           (string-match "mp3" (expand-file-name default-directory))
-                           default-directory
-                         emacspeak-alsaplayer-media-directory))))))
+       (read-file-name
+          "Media Resource: "
+          (if 
+              (string-match "\\(audio\\)\\|\\(mp3\\)" (expand-file-name default-directory))
+              default-directory
+            emacspeak-alsaplayer-media-directory))))))
   (emacspeak-alsaplayer-send-command
    (format "--enqueue %s"
            (shell-quote-wildcard-pattern
@@ -179,7 +199,7 @@ Optional second arg watch-pattern specifies line of output to
               resource)))
    "playlist_length:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 ;;;###autoload
@@ -192,7 +212,7 @@ Optional second arg watch-pattern specifies line of output to
    (format "find . -iname '%s' -print0 | xargs -0 alsaplayer -e "
            pattern))
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -213,7 +233,7 @@ Optional second arg watch-pattern specifies line of output to
    "playlist"
    "_length:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -223,7 +243,7 @@ Optional second arg watch-pattern specifies line of output to
   (emacspeak-alsaplayer-send-command "--status"
                                      "position:"
                                      'no-refresh)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (unless (eq (current-buffer)
                 (get-buffer emacspeak-alsaplayer-buffer))
       (switch-to-buffer emacspeak-alsaplayer-buffer))
@@ -231,14 +251,20 @@ Optional second arg watch-pattern specifies line of output to
     (when  emacspeak-alsaplayer-auditory-feedback
       (emacspeak-speak-line)
       (emacspeak-auditory-icon 'select-object))))
+(defvar emacspeak-alsaplayer-paused nil
+  "Record if player is paused.")
 
 (defun emacspeak-alsaplayer-pause ()
   "Pause or resume alsaplayer"
   (interactive)
+  (declare (special emacspeak-alsaplayer-paused))
   (emacspeak-alsaplayer-send-command "--pause"
                                      "position:")
+  (when emacspeak-alsaplayer-paused 
+    (emacspeak-alsaplayer-send-command "--speed 1.0"))
+  (setq emacspeak-alsaplayer-paused (not emacspeak-alsaplayer-paused))
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'button)))
 
@@ -248,7 +274,7 @@ Optional second arg watch-pattern specifies line of output to
   (emacspeak-alsaplayer-send-command "--next"
                                      "path:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -258,17 +284,17 @@ Optional second arg watch-pattern specifies line of output to
   (emacspeak-alsaplayer-send-command "--prev"
                                      "path:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
-    
+
 (defun emacspeak-alsaplayer-start ()
   "Start  alsaplayer"
   (interactive)
   (emacspeak-alsaplayer-send-command "--start"
                                      "position:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'open-object)))
 
@@ -278,7 +304,7 @@ Optional second arg watch-pattern specifies line of output to
   (emacspeak-alsaplayer-send-command "--stop"
                                      "position:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'close-object)))
 
@@ -289,7 +315,7 @@ Optional second arg watch-pattern specifies line of output to
    (format  "--relative %s" offset)
    "position:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
@@ -300,7 +326,7 @@ Optional second arg watch-pattern specifies line of output to
    (format "--speed %s" setting)
    "speed:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -311,7 +337,7 @@ Optional second arg watch-pattern specifies line of output to
    (format "--volume %s" setting)
    "volume:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -322,7 +348,7 @@ Optional second arg watch-pattern specifies line of output to
    (format "--seek %s" offset)
    "position:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
@@ -333,7 +359,7 @@ Optional second arg watch-pattern specifies line of output to
    (format "--jump %s" track)
    "path:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
@@ -343,21 +369,36 @@ Optional second arg watch-pattern specifies line of output to
   (emacspeak-alsaplayer-send-command "--clear"
                                      "playlist_length:")
   (when (and emacspeak-alsaplayer-auditory-feedback
-             (interactive-p))
+             (ems-interactive-p ))
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'delete-object)))
 
 (defun emacspeak-alsaplayer-quit ()
   "Quit  alsaplayer"
   (interactive)
-  (emacspeak-alsaplayer-send-command "--quit")
-  (delete-window)
-  (when (and emacspeak-alsaplayer-auditory-feedback (interactive-p))
-    (when (eq major-mode 'emacspeak-alsaplayer-mode)
-      (kill-buffer (current-buffer)))
-    (emacspeak-auditory-icon 'close-object)
-    (emacspeak-speak-mode-line)))
+  (let ((kill-buffer-query-functions nil))
+    (emacspeak-alsaplayer-send-command "--quit")
+    (delete-window)
+    (when (and emacspeak-alsaplayer-auditory-feedback (ems-interactive-p ))
+      (when (eq major-mode 'emacspeak-alsaplayer-mode)
+        (kill-buffer (current-buffer)))
+      (emacspeak-auditory-icon 'close-object)
+      (emacspeak-speak-mode-line))))
 
+;;;###autoload
+(defun emacspeak-alsaplayer-cd (directory)
+  "Change default directory, and silence its pronunciation."
+  (interactive
+   (list
+    (read-directory-name "Change to directory: ")))
+  (cd directory)
+  (save-excursion
+    (set-buffer emacspeak-alsaplayer-buffer)
+    (emacspeak-pronounce-add-buffer-local-dictionary-entry
+     (expand-file-name directory)
+     ""))
+  (emacspeak-amark-load)
+  (emacspeak-auditory-icon 'item))
 ;;}}}
 ;;{{{ additional temporal navigation 
 
@@ -366,7 +407,7 @@ Optional second arg watch-pattern specifies line of output to
   (interactive)
   (emacspeak-alsaplayer-send-command "--relative 10"
                                      "position:")
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defun emacspeak-alsaplayer-backward-10-seconds()
@@ -375,7 +416,7 @@ Optional second arg watch-pattern specifies line of output to
   (emacspeak-alsaplayer-send-command
    "--relative -10"
    "position:")
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defun emacspeak-alsaplayer-forward-minute ( minutes)
@@ -385,7 +426,7 @@ Optional second arg watch-pattern specifies line of output to
    (format "--relative %s"
            (* 60 (or minutes 1)))
    "position:")
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defun emacspeak-alsaplayer-backward-minute ( minutes)
@@ -396,7 +437,7 @@ Optional second arg watch-pattern specifies line of output to
     "--relative -%s"
     (* 60 (or minutes 1)))
    "position:")
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defun emacspeak-alsaplayer-forward-ten-minutes ( minutes)
@@ -407,7 +448,7 @@ Optional second arg watch-pattern specifies line of output to
     "--relative %s"
     (* 600 (or minutes 1)))
    "position:")
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defun emacspeak-alsaplayer-backward-ten-minutes ( minutes)
@@ -418,22 +459,19 @@ Optional second arg watch-pattern specifies line of output to
     "--relative -%s"
     (* 600 (or minutes 1)))
    "position:")
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 ;;}}}
-;;{{{  saving positions, marking and clipping:
+;;{{{ Helper Accessors:
 
-(defvar emacspeak-alsaplayer-mark nil
-  "Saved mark position.")
-
-(defsubst emacspeak-alsaplayer-get-position ()
-  "Return currently displayed position."
+(defsubst emacspeak-alsaplayer-get-field (field)
+  "Return specified field value."
   (declare (special emacspeak-alsaplayer-buffer))
   (save-current-buffer
     (set-buffer emacspeak-alsaplayer-buffer)
     (goto-char (point-min))
-    (when (search-forward "position:" nil t)
+    (when (search-forward field  nil t)
       (second
        (split-string
         (buffer-substring-no-properties
@@ -441,13 +479,33 @@ Optional second arg watch-pattern specifies line of output to
          (line-end-position))
         ": ")))))
 
+(defsubst emacspeak-alsaplayer-get-position ()
+  "Return currently displayed position."
+  (emacspeak-alsaplayer-get-field "position:"))
+
+(defsubst emacspeak-alsaplayer-get-playlist-length ()
+  "Return playlist length."
+  (emacspeak-alsaplayer-get-field "playlist_length:"))
+
+(defsubst emacspeak-alsaplayer-get-path ()
+  "Return currently displayed path."
+  (emacspeak-alsaplayer-get-field "path:"))
+
+;;}}}
+;;{{{  saving positions, marking and clipping:
+
+(defvar emacspeak-alsaplayer-mark nil
+  "Saved mark position.")
+(make-variable-buffer-local 'emacspeak-alsaplayer-mark)
+
 (defun emacspeak-alsaplayer-mark-position   ()
   "Mark currently displayed position."
   (interactive)
-  (declare (special emacspeak-alsaplayer-mark))e
+  (declare (special emacspeak-alsaplayer-mark))
+  (emacspeak-alsaplayer-status)
   (setq emacspeak-alsaplayer-mark
         (emacspeak-alsaplayer-get-position))
-  (when (and (interactive-p)
+  (when (and (ems-interactive-p )
              emacspeak-alsaplayer-mark)
     (message "mark set at %s"
              emacspeak-alsaplayer-mark)
@@ -462,28 +520,11 @@ Optional second arg watch-pattern specifies line of output to
       (emacspeak-auditory-icon 'yank-object)
       (message "%s" where))))
 
-(defsubst emacspeak-alsaplayer-get-path ()
-  "Return currently displayed path."
-  (declare (special emacspeak-alsaplayer-buffer))
-  (save-current-buffer
-    (set-buffer emacspeak-alsaplayer-buffer)
-    (goto-char (point-min))
-    (when (search-forward "path:" nil t)
-      (second
-       (split-string
-        (buffer-substring-no-properties
-         (line-beginning-position)
-         (line-end-position))
-        ": ")))))
-
 (defun emacspeak-alsaplayer-info ()
   "Speak current path and copy it to kill ring."
   (interactive)
-  (let ((path (emacspeak-alsaplayer-get-path)))
-    (when path
-      (kill-new path)
-      (emacspeak-auditory-icon 'yank-object)
-      (message "%s" path))))
+  (with-current-buffer emacspeak-alsaplayer-buffer
+    (dtk-speak (emacspeak-alsaplayer-header-line))))
 
 (defvar emacspeak-alsaplayer-mp3split-program "mp3splt"
   "Program used to clip mp3 files.")
@@ -509,8 +550,36 @@ Optional second arg watch-pattern specifies line of output to
            (format "%d.%d"
                    (/ end 60)
                    (% end 60)))))
-           
-                    
+
+;;}}}
+;;{{{ AMarks:
+;;;###autoload
+(defun emacspeak-alsaplayer-amark-add (name &optional prompt-position)
+  "Set AMark `name' at current position in current audio stream.
+Interactive prefix arg prompts for position.
+As the default, use current position."
+  (interactive "sAMark Name:\nP")
+  (declare  (special emacspeak-alsaplayer-mark))
+  (emacspeak-alsaplayer-status)
+  (emacspeak-amark-add
+   (emacspeak-alsaplayer-get-path)
+   name
+   (cond
+    (prompt-position (read-number "Position: "))
+    (t (emacspeak-alsaplayer-get-position))))
+  (message "Added Amark %s" name))
+;;;###autoload
+(defun emacspeak-alsaplayer-amark-jump ()
+  "Jump to specified AMark."
+  (interactive)
+  (let ((amark (call-interactively 'emacspeak-amark-find))
+        (length 0))
+    (emacspeak-alsaplayer-add-to-queue
+     (emacspeak-amark-path amark))
+    (emacspeak-alsaplayer-status)
+    (setq length (emacspeak-alsaplayer-get-playlist-length))
+    (emacspeak-alsaplayer-jump  length)
+    (emacspeak-alsaplayer-seek (emacspeak-amark-position amark))))
 
 ;;}}}
 ;;{{{ bind keys
@@ -520,6 +589,10 @@ Optional second arg watch-pattern specifies line of output to
 (loop for k in
       '(
         ("m" emacspeak-alsaplayer-mark-position)
+        ("M" emacspeak-alsaplayer-amark-add)
+        ("J" emacspeak-alsaplayer-amark-jump)
+        ("\M-s" emacspeak-amark-save)
+        ("\M-l" emacspeak-amark-load)
         ("w" emacspeak-alsaplayer-where)
         ("x" emacspeak-alsaplayer-clip)
         ("." emacspeak-alsaplayer-forward-10-seconds)
@@ -530,7 +603,7 @@ Optional second arg watch-pattern specifies line of output to
         ("]" emacspeak-alsaplayer-forward-ten-minutes)
         ("[" emacspeak-alsaplayer-backward-ten-minutes)
         ("a" emacspeak-alsaplayer-add-to-queue)
-        ("d" cd)
+        ("d" emacspeak-alsaplayer-cd)
         ("f" emacspeak-alsaplayer-find-and-add-to-queue)
         ("A"
          emacspeak-alsaplayer-replace-queue)
@@ -546,8 +619,9 @@ Optional second arg watch-pattern specifies line of output to
          emacspeak-alsaplayer-next)
         ("p"
          emacspeak-alsaplayer-previous)
-        ("q" emacspeak-alsaplayer-quit)
-	("o" other-window)
+        ("q" bury-buffer)
+        ("Q" emacspeak-alsaplayer-quit)
+        ("o" other-window)
         ("r" emacspeak-alsaplayer-relative)
         ("s"
          emacspeak-alsaplayer-start)
@@ -562,14 +636,28 @@ Optional second arg watch-pattern specifies line of output to
       do
       (emacspeak-keymap-update  emacspeak-alsaplayer-mode-map k))
 
+;;}}}
+;;{{{ pause/resume if needed
+
+;;;###autoload
+(defun emacspeak-alsaplayer-pause-or-resume ()
+  "Pause/resume if alsaplayer is running. For use  in
+emacspeak-silence-hook."
+  (declare (special emacspeak-alsaplayer-buffer))
+  (when (and (get-buffer-process emacspeak-alsaplayer-buffer)
+             (eq 'run (process-status (get-buffer-process emacspeak-alsaplayer-buffer))))
+    (emacspeak-alsaplayer-pause)))
+
+(add-hook 'emacspeak-silence-hook 'emacspeak-alsaplayer-pause-or-resume)
+
 ;;}}}
 (provide 'emacspeak-alsaplayer)
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
- 
+
