@@ -1,5 +1,5 @@
 ;;; emacspeak-auctex.el --- Speech enable AucTeX -- a powerful TeX/LaTeX authoring environment
-;;; $Id: emacspeak-auctex.el 5315 2007-09-27 16:14:42Z tv.raman.tv $
+;;; $Id: emacspeak-auctex.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; DescriptionEmacspeak extensions for auctex-mode
 ;;; Keywords:emacspeak, audio interface to emacs AUCTEX
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -59,10 +59,6 @@
    (font-latex-string-face voice-lighten)
    (font-latex-subscript-face voice-smoothen)
    (font-latex-superscript-face voice-brighten)
-   (font-latex-title-1-face voice-bolden-extra)
-   (font-latex-title-2-face voice-bolden-medium)
-   (font-latex-title-3-face voice-bolden)
-   (font-latex-title-4-face voice-smoothen-extra)
    (font-latex-verbatim-face voice-monotone)
    (font-latex-warning-face voice-bolden-and-animate)
    ))
@@ -72,38 +68,38 @@
 
 (defadvice LaTeX-fill-paragraph (after emacspeak pre act  comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'fill-object)))
 
 (defadvice LaTeX-mark-section (after emacspeak pre act)
   "Speak the first line. 
 Also provide an auditory icon. "
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'mark-object)))
 
 (defadvice LaTeX-mark-environment (after emacspeak pre act)
   "Speak the first line. 
 Also provide an auditory icon. "
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'mark-object)))
 
 (defadvice LaTeX-format-paragraph (after emacspeak pre act )
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'fill-object)
     (message "Filled current paragraph")))
 (defadvice LaTeX-format-region (around emacspeak pre act )
   "Ask for confirmation.
 Provide auditory feedback after formatting region"
   (cond
-   ((and (interactive-p)
+   ((and (ems-interactive-p )
          (y-or-n-p "Really format region? "))
     ad-do-it
     (emacspeak-auditory-icon 'fill-object)
     (message "Reformatted region"))
-   ((not (interactive-p)) ad-do-it))
+   ((not (ems-interactive-p )) ad-do-it))
   ad-return-value)
 
 ;;}}}
@@ -111,56 +107,59 @@ Provide auditory feedback after formatting region"
 
 (defadvice LaTeX-find-matching-begin (after emacspeak pre act)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defadvice LaTeX-find-matching-end (after emacspeak pre act)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defadvice LaTeX-close-environment (after emacspeak pre act)
   "Speak the inserted line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-read-previous-line)))
 
 (defadvice TeX-insert-quote(around emacspeak pre act com)
   "Speak quotes that were inserted."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (emacspeak-speak-region orig (point))))
    (t ad-do-it))
   ad-return-value)
-(loop for f in
-      '(TeX-insert-dollar TeX-insert-backslash
-                          LaTeX-babel-insert-hyphen)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-	  "Speak what you inserted"
-	  (when (interactive-p)
-	    (emacspeak-speak-this-char  (preceding-char ))))))
+(unless (and (boundp 'post-self-insert-hook)
+             post-self-insert-hook
+             (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
+  (loop for f in
+        '(TeX-insert-dollar TeX-insert-backslash
+                            LaTeX-babel-insert-hyphen)
+        do
+        (eval
+         `(defadvice ,f (after emacspeak pre act comp)
+            "Speak what you inserted"
+            (when (ems-interactive-p )
+              (emacspeak-speak-this-char  (preceding-char )))))))
 
 ;;}}}
 ;;{{{  Inserting structures
 
 (defadvice TeX-newline (after emacspeak pre act comp)
   "Provide auditory feedback to indicate indentation."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)))
 
 (defadvice LaTeX-insert-item (after emacspeak pre act)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line )))
 
 (defadvice LaTeX-environment (after emacspeak pre act)
   "Provide auditory feedback, by speaking
 the opening line of the newly inserted environment. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-read-previous-line)))
 
@@ -175,25 +174,25 @@ the opening line of the newly inserted environment. "
 
 (defadvice TeX-comment-region (after emacspeak pre act)
   "Provide spoken and auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice TeX-un-comment (after emacspeak pre act)
   "Provide spoken and auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice TeX-un-comment-region (after emacspeak pre act)
   "Provide spoken and auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice TeX-comment-paragraph (after emacspeak pre act)
   "Provide spoken and auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'select-object)))
 
@@ -202,7 +201,7 @@ the opening line of the newly inserted environment. "
 
 (defadvice TeX-next-error (after emacspeak pre act)
   "Speak the error line. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line )))
 
@@ -223,7 +222,6 @@ the opening line of the newly inserted environment. "
                       (nil
                        "^ *\\\\\\(sub\\)*section{\\([^}]+\\)"
                        2))))))
-              
 
 ;;}}}
 ;;{{{ advice font changes 
@@ -231,7 +229,7 @@ the opening line of the newly inserted environment. "
 (defadvice TeX-font (around emacspeak pre act comp)
   "Speak the font we inserted"
   (cond 
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (if (ad-get-arg 0)
@@ -246,7 +244,7 @@ the opening line of the newly inserted environment. "
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
