@@ -1,5 +1,5 @@
 ;;; emacspeak-cedet.el --- Speech enable CEDET
-;;; $Id: emacspeak-cedet.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-cedet.el 8309 2013-05-01 15:24:41Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Auditory interface to CEDET
 ;;; Keywords: Emacspeak, Speak, Spoken Output, CEDET
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -44,16 +44,17 @@
 
 ;;}}}
 ;;{{{  Introduction
+;;; Commentary: 
 
 ;;; CEDET consists of speedbar semantic ede and friends.
 ;;; This module speech enables new functionality in semantic,
 ;;senator and friends
-
+;;; Code:
 ;;}}}
 ;;{{{ advice semantic completion
 
 (loop for f in
-      '(semantic-complete-complete-tab semantic-complete-complete-space)
+      '(semantic-complete-symbol)
       do
       (eval
        `(defadvice ,f (around emacspeak pre act comp)
@@ -74,7 +75,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
