@@ -1,6 +1,6 @@
 ;;; emacspeak-daisy.el --- daisy Front-end for emacspeak desktop
-;;; $Id: emacspeak-daisy.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-daisy.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for DAISY Talking Books
 ;;; Keywords: Emacspeak, daisy Digital Talking Books
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
+;;;  $Revision: 4541 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -51,17 +51,17 @@
 
 (require 'emacspeak-preamble)
 (require 'xml-parse)
+
 ;;}}}
 ;;{{{  Customization variables
-;;;###autoload
 (defgroup emacspeak-daisy nil
   "Daisy Digital Talking Books  for the Emacspeak desktop."
   :group 'emacspeak)
 
 ;;}}}
-;;{{{ Book structure 
+;;{{{ Book structure
 
-;;; Book structure 
+;;; Book structure
 
 (defstruct  emacspeak-daisy-book
   base
@@ -102,7 +102,7 @@
                     (emacspeak-daisy-book-base book)))
 
 ;;}}}
-;;{{{ find element by id 
+;;{{{ find element by id
 (defun xml-find-tag-by-id (tree id)
   "Walk tree and return node matching id."
   (let ((children (xml-tag-children tree))
@@ -118,21 +118,19 @@
         (unless (stringp current)
           (setq found (xml-find-tag-by-id current id))))
       found))))
-        
-;;}}}
-;;{{{ return matching children 
-(defun xml-children-by-name  (tag name)
-  "Return list of children  matching NAME, of an xml-parse'd XML TAG."
-  (let ((children (xml-tag-children tag))
-	(result nil))
-    (while children
-      (when (string-equal name (xml-tag-name (car children)))
-	(nconc result (car children)))
-      (setq children (cdr children)))
-    result))
 
 ;;}}}
-;;{{{  play audio clip 
+;;{{{ return matching children
+(defun xml-children-by-name  (tag name)
+  "Return list of children  matching NAME, of an xml-parse'd XML TAG."
+  (let ((children (xml-tag-children tag)))
+    (remove-if 
+     #'(lambda (tag)
+         (not (string-equal name (xml-tag-name tag))))
+     children)))
+
+;;}}}
+;;{{{  play audio clip
 
 (defvar emacspeak-daisy-mpg123-player "mpg123"
   "MPG123 executable for playing mp3 files.")
@@ -156,7 +154,7 @@ Clip is the result of parsing element <audio .../> as defined by Daisy 3."
     (setq first (emacspeak-daisy-time-string-to-frame begin))
     (setq last (emacspeak-daisy-time-string-to-frame end))
     (setf (emacspeak-daisy-book-audio-process emacspeak-daisy-this-book)
-          (start-process "mpg123"  nil 
+          (start-process "mpg123"  nil
                          emacspeak-daisy-mpg123-player
                          "-k"
                          (format "%s"  (1- first))
@@ -168,17 +166,30 @@ Clip is the result of parsing element <audio .../> as defined by Daisy 3."
   "Play text clip specified by clip.
 Clip is the result of parsing SMIL element <text .../> as used by Daisy 3."
   (declare (special emacspeak-daisy-this-book))
-  (unless
-      (string-equal "text" (xml-tag-name clip))
-    (error "Invalid audio clip."))
+  (unless (string-equal "text" (xml-tag-name clip))
+    (error "Invalid text clip."))
   (let* ((src (xml-tag-attr  clip "src"))
          (split (split-string src "#"))
          (relative (first split))
          (fragment (second split))
-         (path (emacspeak-daisy-resolve-uri relative
-                                            emacspeak-daisy-this-book)))
-    (emacspeak-w3-extract-node-by-id path fragment)))
+         (path (emacspeak-daisy-resolve-uri relative emacspeak-daisy-this-book)))
+    (emacspeak-we-xslt-filter
+     (format "//*[@id=\"%s\"]" fragment)
+     (concat "file:" path))))
+;;;###autoload
 
+(defun emacspeak-daisy-html ()
+  "Apply xslt transform specified by \\{emacspeak-daisy-xsl}
+to convert and view Daisy Books as a Web page."
+  (interactive)
+  (declare (special emacspeak-daisy-xsl emacspeak-daisy-this-book))
+  (emacspeak-xslt-view-file
+   emacspeak-daisy-xsl
+   (expand-file-name
+    (format "%s.xml" (emacspeak-daisy-book-basename emacspeak-daisy-this-book))
+    (emacspeak-daisy-book-base emacspeak-daisy-this-book))))
+
+;;;###autoload
 (defun emacspeak-daisy-play-page-range (start end )
   "Play pages in specified page range."
   (interactive
@@ -190,28 +201,29 @@ Clip is the result of parsing SMIL element <text .../> as used by Daisy 3."
                (concat
                 (emacspeak-daisy-book-basename emacspeak-daisy-this-book)
                 ".xml")
-	       emacspeak-daisy-this-book))
+               emacspeak-daisy-this-book))
         (result nil))
     (setq result
           (emacspeak-xslt-xml-url
-	   (expand-file-name "dtb-page-range.xsl"
-			     emacspeak-xslt-directory)
-	   path
-	   (list
-	    (cons "start"
-		  (format "'%s'"
-			  start ))
-	    (cons "end"
-		  (format "'%s'"
-			  end ))
-	    (cons "base"
-		  (format "'%s'"
-			  path)))))
-    (save-excursion
+           (expand-file-name "dtb-page-range.xsl"
+                             emacspeak-xslt-directory)
+           path
+           (list
+            (cons "start"
+                  (format "'%s'"
+                          start ))
+            (cons "end"
+                  (format "'%s'"
+                          end ))
+            (cons "base"
+                  (format "'%s'"
+                          path)))))
+    (save-current-buffer
       (set-buffer result)
-      (emacspeak-w3-preview-this-buffer))
+      (browse-url-of-buffer))
     (kill-buffer result)))
 
+;;;###autoload
 (defun emacspeak-daisy-stop-audio ()
   "Stop audio."
   (interactive)
@@ -221,7 +233,7 @@ Clip is the result of parsing SMIL element <text .../> as used by Daisy 3."
   (emacspeak-auditory-icon 'close-object))
 
 ;;}}}
-;;{{{ play smil content 
+;;{{{ play smil content
 
 (defun emacspeak-daisy-book-add-content (book src)
   "Parse SMIL content in src and store it as book contents.
@@ -229,7 +241,7 @@ Contents are indexed by src."
   (let ((smil
          (find-file-noselect
           (emacspeak-daisy-resolve-uri src book))))
-    (save-excursion
+    (save-current-buffer
       (set-buffer smil)
       (goto-char (point-min))
       (search-forward"<smil")
@@ -238,7 +250,7 @@ Contents are indexed by src."
        (gethash src (emacspeak-daisy-book-content book))
        (read-xml))
       (kill-buffer smil))))
-    
+
 (defun emacspeak-daisy-fetch-content (book src)
   "Return content particle from book,
 after fetching it  if necessary."
@@ -258,16 +270,13 @@ the clip."
         (seq (xml-tag-child  clip "seq")))
     (when (and (not audio) seq)
       (setq audio (xml-tag-child seq "audio")))
-    (when audio
-      (emacspeak-daisy-play-audio audio))
-    (when text
-      (emacspeak-daisy-play-text text))))
+    (when audio (emacspeak-daisy-play-audio audio))
+    (when text (emacspeak-daisy-play-text text))))
 
 (defun emacspeak-daisy-play-content (content)
   "Play SMIL content specified by content.
 Return buffer that holds the result of playing the content."
-  (declare (special emacspeak-daisy-base-uri
-                    emacspeak-daisy-this-book))
+  (declare (special emacspeak-daisy-this-book))
   (unless (eq major-mode 'emacspeak-daisy-mode)
     (error "Not in a digital audio book."))
   (unless
@@ -287,7 +296,7 @@ Return buffer that holds the result of playing the content."
     (emacspeak-daisy-play-smil clip)))
 
 ;;}}}
-;;{{{  table of handlers 
+;;{{{  table of handlers
 
 (defvar emacspeak-daisy-handler-table (make-hash-table )
   "Table that maps elements to handlers.")
@@ -305,23 +314,25 @@ Return buffer that holds the result of playing the content."
   (setf (gethash (intern element) emacspeak-daisy-handler-table) handler))
 
 ;;}}}
-;;{{{ Install handlers 
+;;{{{ Install handlers
 
 ;;; elements
-(defvar emacspeak-daisy-xml-elements 
+(defvar emacspeak-daisy-xml-elements
   (list
    "ncx"
    "head"
    "title"
    "docTitle"
+   "docAuthor"
    "text"
    "audio"
    "content"
-   "navStruct" ;;; old ncx 
+   "navStruct" ;;; old ncx
    "navObject" ;;; old ncx
    "navLabel"
    "navLisp"
    "navMap"
+   "navInfo"
    "navPoint"
    "navTarget")
   "Daisy XML elements.")
@@ -334,18 +345,17 @@ Return buffer that holds the result of playing the content."
                                      "emacspeak-daisy-%s-handler" e))))
 
 ;;}}}
-;;{{{ Define handlers 
+;;{{{ Define handlers
 
 (defsubst emacspeak-daisy-apply-handler (element)
   "Lookup and apply installed handler."
   (let* ((tag (xml-tag-name element))
          (handler  (emacspeak-daisy-get-handler tag)))
     (cond
-     ((and handler
-           (fboundp handler))(funcall handler element))
+     ((and handler (fboundp handler))
+      (funcall handler element))
      (t
-      (insert
-       (format "Handler for %s not implemented yet.\n" tag))))))
+      (insert (format "Handler for %s not implemented yet.\n" tag))))))
 
 (defun  emacspeak-daisy-ncx-handler (ncx)
   "Process top-level NCX element."
@@ -355,7 +365,7 @@ Return buffer that holds the result of playing the content."
   "Handle element <text>...</text>."
   (mapc #'insert (xml-tag-children element))
   (insert "\n"))
-   
+
 (defun emacspeak-daisy-head-handler (element)
   "Handle head element."
   (declare (special emacspeak-daisy-this-book))
@@ -382,7 +392,7 @@ Return buffer that holds the result of playing the content."
     (when audio
       (put-text-property start (point)
                          'audio audio))
-    
+
     (put-text-property start (point)
                        'content content)))
 (defun emacspeak-daisy-navLabel-handler (element)
@@ -396,19 +406,24 @@ Return buffer that holds the result of playing the content."
   (mapc #'emacspeak-daisy-apply-handler
         (xml-tag-children element )))
 
+(defun emacspeak-daisy-navInfo-handler (element)
+  "Handle navInfo element."
+  (mapc #'emacspeak-daisy-apply-handler
+        (xml-tag-children element )))
+
 (defun emacspeak-daisy-navPoint-handler (element)
   "Handle navPoint element."
   (let ((label (xml-tag-child element "navLabel"))
         (content (xml-tag-child element "content"))
         (nav-points (xml-children-by-name element "navPoint"))
         (start (point)))
+    (when label (print label))
     (when label (emacspeak-daisy-navLabel-handler label))
     (when content
-      (put-text-property start (point)
-                         'content content))
-    (mapc #'emacspeak-daisy-apply-handler nav-points)))
+      (put-text-property start (point) 'content content))
+    (message "navPoint Children: %s" (length nav-points))
+    (mapc #'emacspeak-daisy-navPoint-handler nav-points)))
 
-    
 (defun emacspeak-daisy-docTitle-handler (element)
   "Handle <doctitle>...</doctitle>"
   (let ((text (xml-tag-child  element "text"))
@@ -417,52 +432,57 @@ Return buffer that holds the result of playing the content."
     (emacspeak-daisy-text-handler   text)
     (put-text-property start (point)
                        'audio audio)))
-                             
-;;; Ignore navList for now 
+
+(defun emacspeak-daisy-docAuthor-handler (element)
+  "Handle <docAuthor>...</docAuthor>"
+  (let ((text (xml-tag-child  element "text"))
+        (audio (xml-tag-child element "audio"))
+        (start (point)))
+    (emacspeak-daisy-text-handler   text)
+    (put-text-property start (point)
+                       'audio audio)))
+
+;;; Ignore navList for now
 (emacspeak-daisy-set-handler "navList" 'ignore)
+                                        ; ignore pageList
+(emacspeak-daisy-set-handler "pageList" 'ignore)
 ;;}}}
 ;;{{{  emacspeak-daisy mode
 
 (declaim (special emacspeak-daisy-mode-map))
 
-(define-derived-mode emacspeak-daisy-mode text-mode 
+(define-derived-mode emacspeak-daisy-mode text-mode
   "Digital Talking Book\n"
   "A DAISY front-end for the Emacspeak desktop.
 
 Pre-requisites:
 
 0) mpg123 for playing mp3 files
-1) libxml and libxslt packages 
+1) libxml and libxslt packages
 2) xml-parse.el for parsing XML in Emacs Lisp.
 
 The Emacspeak DAISY front-end is launched by command
-emacspeak-daisy-open-book  bound to \\[emacspeak-daisy-open-book].  
+emacspeak-daisy-open-book  bound to \\[emacspeak-daisy-open-book].
 
 This command switches to a special buffer that has DAISY
-commands bounds to single keystrokes-- see the ke-binding
+commands bounds to single keystrokes-- see the key-binding
 list at the end of this description.  Use Emacs online help
 facility to look up help on these commands.
 
 emacspeak-daisy-mode provides the necessary functionality to
-navigate and listen to Daisy talking books. 
+navigate and listen to Daisy talking books.
 
 Here is a list of all emacspeak DAISY commands along with their key-bindings:
 
 \\{emacspeak-daisy-mode-map}"
-  (progn
-    (emacspeak-keymap-remove-emacspeak-edit-commands
-     emacspeak-daisy-mode-map)))
-
+  (progn))
+(define-key emacspeak-daisy-mode-map "h" 'emacspeak-daisy-html)
 (define-key emacspeak-daisy-mode-map "?" 'describe-mode)
 (define-key emacspeak-daisy-mode-map "m" 'emacspeak-daisy-mark-position-in-content-under-point)
-(define-key emacspeak-daisy-mode-map "s"
-  'emacspeak-daisy-stop-audio)
-(define-key emacspeak-daisy-mode-map "n"
-  'emacspeak-daisy-next-line)
-(define-key emacspeak-daisy-mode-map "p"
-  'emacspeak-daisy-previous-line)
-(define-key emacspeak-daisy-mode-map "o"
-  'emacspeak-daisy-define-outline-pattern)
+(define-key emacspeak-daisy-mode-map "s" 'emacspeak-daisy-stop-audio)
+(define-key emacspeak-daisy-mode-map "n" 'emacspeak-daisy-next-line)
+(define-key emacspeak-daisy-mode-map "p" 'emacspeak-daisy-previous-line)
+(define-key emacspeak-daisy-mode-map "o" 'emacspeak-daisy-define-outline-pattern)
 (define-key emacspeak-daisy-mode-map "S" 'emacspeak-daisy-save-bookmarks)
 (define-key emacspeak-daisy-mode-map "q" 'bury-buffer)
 (define-key emacspeak-daisy-mode-map " "
@@ -483,6 +503,14 @@ Here is a list of all emacspeak DAISY commands along with their key-bindings:
   "Customize this to the root of where books are organized."
   :type 'directory
   :group 'emacspeak-daisy)
+
+(defcustom emacspeak-daisy-xsl
+  (expand-file-name "daisyTransform.xsl" emacspeak-daisy-books-directory)
+  "Style sheet for transforming Daisy books to HTML. 
+Bookshare provides this with newer books."
+  :type 'file
+  :group 'emacspeak-daisy)
+
 (defcustom emacspeak-daisy-completion-extensions-to-ignore
   '(".xml" ".smil" ".bks"
     "~" ".opf" ".css" ".espeak.el")
@@ -490,25 +518,14 @@ Here is a list of all emacspeak DAISY commands along with their key-bindings:
 navigation file for a book. Include all extensions except `.ncx'
   for optimal performance."
   :type '(repeat :tag "Extensions"
-		 (string :tag "Suffix"))
+                 (string :tag "Suffix"))
   :group 'emacspeak-daisy)
 
 (defsubst emacspeak-daisy-read-file-name()
   "Read file name."
-;;; we do this based on signature of read-file-name
-  (let ((read-file-name-takes-predicate	;;; emacs 21.4
-         (= 7 (length
-               (car (append
-                     (symbol-function 'read-file-name) nil))))))
-    (if read-file-name-takes-predicate       
-	(read-file-name "Book Navigation File: "
-			emacspeak-daisy-books-directory
-			nil t  nil 
-			#'(lambda (f)
-			    (string-match "\\.ncx$" f)))
-      (read-file-name "Book Navigation File: "
-		      emacspeak-daisy-books-directory
-		      nil t  nil))))
+  (read-file-name "Book Navigation File: "
+                  emacspeak-daisy-books-directory
+                  nil t  nil))
 
 ;;;###autoload
 (defun emacspeak-daisy-open-book (filename)
@@ -532,7 +549,7 @@ navigation buffer that can be used to browse and read the book."
                           (file-name-nondirectory filename )))))
     (setf (emacspeak-daisy-book-content book)
           (make-hash-table :test #'equal))
-    (save-excursion
+    (save-current-buffer
       (set-buffer ncx)
       (goto-char (point-min))
       (search-forward"<ncx")
@@ -550,7 +567,7 @@ navigation buffer that can be used to browse and read the book."
     (switch-to-buffer buffer)
     (cd (emacspeak-daisy-book-base emacspeak-daisy-this-book))
     (emacspeak-speak-load-directory-settings)
-    (when (emacspeak-daisy-get-bookmarks 
+    (when (emacspeak-daisy-get-bookmarks
            (emacspeak-daisy-book-name emacspeak-daisy-this-book))
       (emacspeak-daisy-add-bookmarks-to-buffer
        (emacspeak-daisy-get-bookmarks
@@ -596,6 +613,7 @@ navigation buffer that can be used to browse and read the book."
         (setq start (next-single-property-change end 'bookmark))))
     bookmarks))
 
+;;;###autoload
 (defun emacspeak-daisy-save-bookmarks ()
   "Save bookmarks for current book."
   (interactive)
@@ -606,8 +624,8 @@ navigation buffer that can be used to browse and read the book."
                (emacspeak-daisy-book-base emacspeak-daisy-this-book)))
         (bookmarks (emacspeak-daisy-collect-bookmarks-in-buffer))
         (buffer (find-file-noselect
-                 (emacspeak-speak-get-directory-settings))))
-    (save-excursion
+                 (emacspeak-speak-get-directory-settings default-directory))))
+    (save-current-buffer
       (set-buffer buffer)
       (goto-char (point-max))
       (insert
@@ -625,40 +643,42 @@ navigation buffer that can be used to browse and read the book."
   "Applies specified list of bookmarks to navigation buffer."
   (unless (eq major-mode 'emacspeak-daisy-mode)
     (error "Not in emacspeak-daisy-mode."))
-  (ems-modify-buffer-safely
-   (save-excursion
-     (goto-char (point-min))
-     (let ((entry nil)
-           (start nil)
-           (end nil)
-           (bookmark nil))
-       (while bookmarks
-         (setq entry (pop bookmarks))
-         (setq start (car (first entry))
-               end (cdr (first entry))
-               bookmark (second entry))
-         (put-text-property start end
-                            'bookmark bookmark)
-         (put-text-property start end
-                            'face 'highlight))))))
+  (with-silent-modifications
+    (save-excursion
+      (goto-char (point-min))
+      (let ((entry nil)
+            (start nil)
+            (end nil)
+            (bookmark nil))
+        (while bookmarks
+          (setq entry (pop bookmarks))
+          (setq start (car (first entry))
+                end (cdr (first entry))
+                bookmark (second entry))
+          (put-text-property start end
+                             'bookmark bookmark)
+          (put-text-property start end
+                             'face 'highlight))))))
 
+;;;###autoload
 (defun emacspeak-daisy-mark-position-in-content-under-point ()
   "Mark current position in displayed content.
 No-op if content under point is not currently displayed."
   (interactive)
   (cond
    ((get-text-property (point) 'viewer)
-    (ems-modify-buffer-safely
-     (put-text-property (line-beginning-position) (line-end-position)
-                        'bookmark
-                        (save-excursion
-                          (set-buffer (get-text-property (point) 'viewer))
-                          (point)))
-     (put-text-property (line-beginning-position) (line-end-position)
-                        'face 'highlight))
+    (with-silent-modifications
+      (put-text-property (line-beginning-position) (line-end-position)
+                         'bookmark
+                         (save-current-buffer
+                           (set-buffer (get-text-property (point) 'viewer))
+                           (point)))
+      (put-text-property (line-beginning-position) (line-end-position)
+                         'face 'highlight))
     (message "Marked position."))
    (t (message "Content not currently displayed."))))
 
+;;;###autoload
 (defun emacspeak-daisy-play-content-under-point ()
   "Play SMIL content  under point."
   (interactive)
@@ -678,13 +698,14 @@ No-op if content under point is not currently displayed."
       (and bookmark (goto-char bookmark))
       (emacspeak-speak-mode-line))
      (content
-      (emacspeak-daisy-configure-w3-to-record-viewer
+      (emacspeak-daisy-configure-web-to-record-viewer
        (current-buffer) title outline-regexp
        start end bookmark)
       (emacspeak-auditory-icon 'open-object)
       (emacspeak-daisy-play-content  content))
      (t (error "No content under point.")))))
 
+;;;###autoload
 (defun emacspeak-daisy-play-audio-under-point ()
   "Play audio clip under point."
   (interactive)
@@ -694,6 +715,7 @@ No-op if content under point is not currently displayed."
       (emacspeak-daisy-play-audio clip))
      (t (error "No audio clip under point.")))))
 
+;;;###autoload
 (defun emacspeak-daisy-previous-line ()
   "Move to previous line."
   (interactive)
@@ -702,6 +724,7 @@ No-op if content under point is not currently displayed."
   (emacspeak-speak-line)
   (emacspeak-auditory-icon 'select-object))
 
+;;;###autoload
 (defun emacspeak-daisy-define-outline-pattern (regexp)
   "Define persistent outline regexp for this book."
   (interactive "sOutline regexp:")
@@ -709,8 +732,9 @@ No-op if content under point is not currently displayed."
   (unless (eq 'emacspeak-daisy-mode major-mode)
     (error "This command should be used in emacspeak-daisy-mode."))
   (setq outline-regexp regexp)
-  (let ((buffer (find-file-noselect (emacspeak-speak-get-directory-settings))))
-    (save-excursion
+  (let ((buffer (find-file-noselect
+                 (emacspeak-speak-get-directory-settings default-directory))))
+    (save-current-buffer
       (set-buffer buffer)
       (goto-char (point-max))
       (insert
@@ -722,6 +746,7 @@ No-op if content under point is not currently displayed."
       (emacspeak-auditory-icon 'save-object)
       (message "Saved outline pattern"))))
 
+;;;###autoload
 (defun emacspeak-daisy-next-line ()
   "Move to next line."
   (interactive)
@@ -733,32 +758,103 @@ No-op if content under point is not currently displayed."
 ;;}}}
 ;;{{{ Configure w3 post processor hook to record viewer buffer:
 
-(defun emacspeak-daisy-configure-w3-to-record-viewer (nav-center title outline 
-								 start  end bookmark)
+(defun emacspeak-daisy-configure-web-to-record-viewer (nav-center title outline
+                                                                  start  end bookmark)
   "Attaches an automatically generated post processor function
-that asks W3 to record the viewer in the navigation center when done.
+that asks the browser  to record the viewer in the navigation center when done.
 Also puts the displayed buffer in outline-minor-mode and gives it
                                                       the right title."
   (declare (special emacspeak-w3-post-process-hook))
   (setq emacspeak-w3-post-process-hook
-        (`
-         (lambda  nil
-	   (let ((buffer (current-buffer)))
+        `(lambda  nil
+           (let ((buffer (current-buffer)))
              (outline-minor-mode 1)
-             (setq outline-regexp (, outline))
+             (setq outline-regexp ,outline)
              (rename-buffer title 'uniquely)
-	     (save-excursion
-	       (set-buffer (, nav-center))
-	       (put-text-property (, start) (, end)
-				  'viewer  buffer))
+             (save-current-buffer
+               (set-buffer ,nav-center)
+               (put-text-property ,start ,end
+                                  'viewer  buffer))
              (cond
               (bookmark
                (goto-char bookmark)
                (emacspeak-speak-line))
-	      (t (emacspeak-speak-mode-line))))))))
+              (t (emacspeak-speak-mode-line)))))))
 
 ;;}}}
+;;{{{ w3 support update:
+;;; need to handle text/xml and application/xml
+(defun w3-fetch-callback (url)
+  (w3-nasty-disgusting-http-equiv-handling (current-buffer) url)
+  ;; Process any cookie and refresh headers.
+  (let (headers)
+    (ignore-errors
+      (save-restriction
+        (mail-narrow-to-head)
+        (goto-char (point-min))
+        (unless (save-excursion
+                  (search-forward ":" (line-end-position) t))
+          (forward-line))
+        (setq headers (mail-header-extract))
+        (let (refreshed)
+          (dolist (header headers)
+            ;; Act on multiple cookies if necessary, but only on a
+            ;; single refresh request in case there's more than one.
+            (case (car header)
+              (refresh (unless refreshed
+                         (w3-handle-refresh-header (cdr header))
+                         (setq refreshed t))))))))
+    (let ((handle (mm-dissect-buffer t))
+          (w3-explicit-coding-system
+           (or w3-explicit-coding-system
+               (w3-recall-explicit-coding-system url)))
+          (buff nil))
+      (message "Downloading of `%s' complete." url)
+      (url-mark-buffer-as-dead (current-buffer))
+      (unless headers
+        (setq headers (list (cons 'content-type
+                                  (mm-handle-media-type handle)))))
+      ;; Fixme: can handle be null?
+      (cond
+       ((or (equal (mm-handle-media-type handle) "text/html")
+            ;; Ultimately this should be handled by an XML parser, but
+            ;; this will mostly work for now:
+            (equal (mm-handle-media-type handle) "application/xhtml+xml")
+            (equal (mm-handle-media-type handle) "text/xml")
+            (equal (mm-handle-media-type handle) "application/xml"))
+        ;; Special case text/html if it comes through w3-fetch
+        (set-buffer (generate-new-buffer " *w3-html*"))
+        (mm-insert-part handle)
+        (w3-decode-charset handle)
+        (setq url-current-object (url-generic-parse-url url))
+        (w3-prepare-buffer)
+        (setq url-current-mime-headers headers)
+        (w3-notify-when-ready (current-buffer))
+        (mm-destroy-parts handle))
+       ((equal (car-safe (mm-handle-type handle))
+               "application/x-elisp-parsed-html")
+        ;; Also need to special-case pre-parsed representations of HTML.
+        ;; Fixme: will this need decoding?
+        (w3-prepare-tree (read (set-marker (make-marker) 1
+                                           (mm-handle-buffer handle)))))
+       ((mm-inlinable-p handle)
+        ;; We can view it inline!
+        (set-buffer (generate-new-buffer url))
+        (require 'mm-view)             ; make sure methods are defined
+        (mm-display-part handle)
+        (set-buffer-modified-p nil)
+        (w3-mode)
+        (if (equal "image" (mm-handle-media-supertype handle))
+            (setq cursor-type nil))
+        (setq url-current-mime-headers headers)
+        (w3-notify-when-ready (current-buffer)))
+       (t
+        ;; Must be an external viewer
+        (mm-display-part handle)
+        ;;(mm-destroy-parts handle)
+        )))))
 
+;;}}}
 (provide 'emacspeak-daisy)
 ;;{{{ end of file
 
