@@ -1,5 +1,5 @@
 ;;; emacspeak-desktop.el ---  Speech-enable desktop
-;;; $Id: emacspeak-desktop.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-desktop.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  desktop transformation routines
 ;;; Keywords: Emacspeak,  Audio Desktop, DESKTOP
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -51,11 +51,11 @@
 
 (defadvice desktop-clear (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)))
 (defadvice desktop-save (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)))
 
 (defadvice desktop-lazy-create-buffer (around emacspeak pre act
@@ -70,7 +70,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
