@@ -1,5 +1,5 @@
 ;;; emacspeak-dictation.el --- Speech enable dictation -- Dictation Interface
-;;; $Id: emacspeak-dictation.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-dictation.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to dictation
 ;;; Keywords: Emacspeak, Speak, Spoken Output, dictation
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -57,25 +57,26 @@
 ;;{{{  advice interactive commands 
 (defadvice dictation-toggle (after emacspeak pre act comp)
   "Provide an auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)))
 
 (defadvice dictation-filter (around emacspeak pre act comp)
   "Speak what you heard. "
   (let ((start nil)
         (dtk-stop-immediately nil))
-    (set-buffer dictation-buffer)
-    (setq start (point))
-    ad-do-it
-    (emacspeak-speak-region start (point))))
-        
+    (save-current-buffer
+      (set-buffer dictation-buffer)
+      (setq start (point))
+      ad-do-it
+      (emacspeak-speak-region start (point)))))
+
 ;;}}}
 (provide 'emacspeak-dictation )
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
