@@ -1,5 +1,5 @@
 ;;; emacspeak-dired.el --- Speech enable Dired Mode -- A powerful File Manager
-;;; $Id: emacspeak-dired.el 5260 2007-09-07 03:55:14Z tv.raman.tv $
+;;; $Id: emacspeak-dired.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enable dired
 ;;; Keywords: Emacspeak, Dired, Spoken Output
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-09-06 20:55:14 -0700 (Thu, 06 Sep 2007) $ |
+;;; $Date: 2008-07-19 16:09:43 -0700 (Sat, 19 Jul 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -67,15 +67,9 @@
    ))
 ;;}}}
 ;;{{{  configure dired
-
-(declaim (special dired-listing-switches ))
-;;; ensure we have -al in the listing switches
-(if (and  dired-listing-switches
-          (not (string-match "^-al" dired-listing-switches)))
-    (setq dired-listing-switches
-          (concat "-al"
-                  (substring dired-listing-switches 1)))
-  (setq dired-listing-switches "-al"))
+;;; Not touching dired-listing-switches 
+;;; Emacspeak in 1994 forcibly set this to  a safe value
+;;; Removing in 2013, since we've now had custom for 13+ years.
 
 (defvar emacspeak-dired-pronunciations-defined nil
   "Internal variable used to ensure we define dired
@@ -98,7 +92,7 @@ pronunciations only once.")
 (defun emacspeak-dired-speak-line ()
   "Speak the dired line intelligently."
   (declare (special emacspeak-speak-last-spoken-word-position))
-  (let ((filename (dired-get-filename t t ))
+  (let ((filename (dired-get-filename 'no-dir  t ))
         (personality (get-text-property (point) 'personality)))
     (cond
      (filename
@@ -115,7 +109,7 @@ pronunciations only once.")
                                              act comp)
   "Provide auditory feedback."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
       ad-do-it
       (emacspeak-auditory-icon 'task-done)
@@ -129,15 +123,14 @@ pronunciations only once.")
 
 (defadvice dired-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice dired-up-directory (after emacspeak pre act)
   "Produce an auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
-      (voice-lock-mode 1)
       (emacspeak-dired-label-fields)
       (emacspeak-auditory-icon 'open-object )
       (emacspeak-speak-mode-line))))
@@ -154,11 +147,10 @@ pronunciations only once.")
 (defadvice dired-find-file  (around  emacspeak pre act)
   "Produce an auditory icon."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((directory-p (file-directory-p (dired-get-filename t t ))))
       ad-do-it
       (when directory-p
-        (voice-lock-mode 1)
         (emacspeak-dired-label-fields))
       (emacspeak-auditory-icon 'open-object )))
    (t ad-do-it))
@@ -166,67 +158,67 @@ pronunciations only once.")
 
 (defadvice dired-tree-up (after emacspeak pre act)
   "Speak the filename."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-tree-down (after emacspeak pre act)
   "Speak the filename."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-next-line (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-previous-line (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-next-marked-file (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-prev-marked-file  (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-prev-subdir (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-next-subdir (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-next-dirline (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-prev-dirline (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-unmark-backward (after emacspeak pre act)
   "Speak the filename name."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-dired-speak-line)))
 
 ;;; Producing auditory icons:
@@ -239,19 +231,19 @@ pronunciations only once.")
 
 (defadvice dired-mark (after emacspeak pre act)
   "Produce an auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'mark-object )
     (emacspeak-dired-speak-line)))
 
 (defadvice dired-flag-file-deletion (after emacspeak pre act )
   "Produce an auditory icon indicating that a file was marked for deletion."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'delete-object )
     (emacspeak-dired-speak-line )))
 
 (defadvice dired-unmark (after emacspeak pre act)
   "Give speech feedback. Also provide an auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object )
     (emacspeak-dired-speak-line)))
 
@@ -260,7 +252,7 @@ pronunciations only once.")
 
 (defun emacspeak-dired-label-fields-on-current-line ()
   "Labels the fields on a dired line.
-Assumes that `dired-listing-switches' contains  -al"
+Assumes that `dired-listing-switches' contains  -l"
   (let ((start nil)
         (fields (list "permissions"
                       "links"
@@ -286,11 +278,12 @@ Assumes that `dired-listing-switches' contains  -al"
 (defun emacspeak-dired-label-fields ()
   "Labels the fields of the listing in the dired buffer.
 Currently is a no-op  unless
-unless `dired-listing-switches' contains -al"
+unless `dired-listing-switches' contains -l"
   (interactive)
   (declare (special dired-listing-switches))
-  (when (save-match-data
-          (string-match  "al" dired-listing-switches))
+  (when
+      (save-match-data
+        (string-match  "l" dired-listing-switches))
     (let ((read-only buffer-read-only))
       (unwind-protect
           (progn
@@ -341,13 +334,13 @@ options passed to command `file'."
 On a directory line, run du -s on the directory to speak its size."
   (interactive)
   (let ((filename (dired-get-filename nil t))
-        (size 0)
-        (dtk-stop-immediately nil))
+        (size 0))
     (cond
      ((and filename
            (file-directory-p filename))
       (emacspeak-auditory-icon 'progress)
-      (emacspeak-shell-command (format "du -s \'%s\'" filename )))
+      (emacspeak-shell-command (format "du -s \'%s\'"
+                                       filename )))
      (filename
       (setq size (nth 7 (file-attributes filename )))
                                         ; check for ange-ftp
@@ -411,8 +404,7 @@ On a directory line, run du -s on the directory to speak its size."
 
 ;;}}}
 ;;{{{  keys
-(eval-when (load)
-  (emacspeak-keymap-remove-emacspeak-edit-commands dired-mode-map))
+(eval-when (load))
 
 (defun emacspeak-dired-setup-keys ()
   "Add emacspeak keys to dired."
@@ -435,7 +427,7 @@ On a directory line, run du -s on the directory to speak its size."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
