@@ -1,5 +1,5 @@
 ;;; emacspeak-dismal.el --- Speech enable Dismal -- An Emacs Spreadsheet program
-;;; $Id: emacspeak-dismal.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-dismal.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: spread sheet extension
 ;;; Keywords:emacspeak, audio interface to emacs spread sheets
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -121,7 +121,7 @@ The `column header' is the entry in row 0."
   "Move forward by arg rows
  (the next row by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
+  (let ((dismal-ems-interactive-p  nil))
     (dis-forward-row rows)
     (emacspeak-dismal-row-summarize)))
 
@@ -129,7 +129,7 @@ The `column header' is the entry in row 0."
   "Move backward by arg rows
  (the previous row by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
+  (let ((dismal-ems-interactive-p  nil))
     (dis-backward-row rows)
     (emacspeak-dismal-row-summarize)))
 
@@ -137,7 +137,7 @@ The `column header' is the entry in row 0."
   "Move forward by arg columns
  (the next column by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
+  (let ((dismal-ems-interactive-p  nil))
     (dis-forward-column cols)
     (emacspeak-dismal-col-summarize)))
 
@@ -145,7 +145,7 @@ The `column header' is the entry in row 0."
   "Move backward by arg columns
  (the previous column by default)and summarize it."
   (interactive "p")
-  (let ((dismal-interactive-p nil))
+  (let ((dismal-ems-interactive-p  nil))
     (dis-backward-column cols)
     (emacspeak-dismal-col-summarize)))
 
@@ -188,8 +188,7 @@ emacspeak-dismal-row-summarizer-list"
     (setq emacspeak-dismal-row-summarizer-list
           (read-minibuffer "Specify summarizer as a vector:
 " "[")))
-  (let ((voice-lock-mode t)
-        (summary nil))
+  (let ((summary nil))
     (setq summary 
           (mapconcat
            (function
@@ -235,8 +234,7 @@ emacspeak-dismal-col-summarizer-list"
     (setq emacspeak-dismal-col-summarizer-list
           (read-minibuffer "Specify summarizer as a vector:
 " "[")))
-  (let ((voice-lock-mode t)
-        (summary nil))
+  (let ((summary nil))
     (setq summary 
           (mapconcat
            (function
@@ -346,8 +344,8 @@ Checked by emacspeak specific dis-mode-hooks entry.")
                      dismal-saved-variables)))))
 
 (declaim (special dismal-map))
-(eval-when (load)
-  (emacspeak-keymap-remove-emacspeak-edit-commands dismal-map))
+(eval-when (load))
+
 ;;; this assumes emacspeak-prefix is C-e
 ;;; and function-key-prefix is M-[
 (add-hook 'dis-mode-hooks
@@ -402,7 +400,7 @@ end up building a template page first."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
