@@ -1,5 +1,5 @@
 ;;; emacspeak-ediary.el --- Speech-enable ediary
-;;; $Id: emacspeak-ediary.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Id: emacspeak-ediary.el 8260 2013-03-28 15:21:49Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak speech-enabler for ediary 
 ;;; Keywords: Emacspeak, diary
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -40,7 +40,7 @@
 
 ;;{{{  Introduction:
 
-;;; ediary is a special mode for editting your.diary file.
+;;; ediary is a special mode for editing your.diary file.
 ;;; This module speech-enables ediary
 
 ;;}}}
@@ -56,12 +56,12 @@
 (defvar emacspeak-ediary-commands-that-speak-entry
   '(
     ediary-entry-earlier      ediary-modify-entry
-    ediary-time-block-longer        ediary-previous-entry       ediary-boe
-    ediary-point-on-entry-date-p   ediary-next-entry   ediary-block-longer
-    ediary-time-block-earlier     ediary-eoe     ediary-time-block-shorter
-    ediary-time-earlier        ediary-block-later        ediary-kill-entry
-    ediary-block-earlier      ediary-entry-later      ediary-block-shorter
-    ediary-time-later     ediary-time-block-later)
+                              ediary-time-block-longer        ediary-previous-entry       ediary-boe
+                              ediary-point-on-entry-date-p   ediary-next-entry   ediary-block-longer
+                              ediary-time-block-earlier     ediary-eoe     ediary-time-block-shorter
+                              ediary-time-earlier        ediary-block-later        ediary-kill-entry
+                              ediary-block-earlier      ediary-entry-later      ediary-block-shorter
+                              ediary-time-later     ediary-time-block-later)
   "Commands that should speak the entry when done.")
 
 (loop for f in emacspeak-ediary-commands-that-speak-entry
@@ -69,17 +69,17 @@
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Speak the entry."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-speak-line)
             (emacspeak-auditory-icon 'select-object)))))
-  
+
 ;;}}}
 (provide 'emacspeak-ediary)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
