@@ -1,5 +1,5 @@
 ;;; emacspeak-erc.el --- speech-enable erc irc client
-;;; $Id: emacspeak-erc.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-erc.el 8534 2013-11-13 01:43:12Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling erc.el
 ;;; Keywords: Emacspeak, erc
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -51,6 +51,7 @@
 ;;}}}
 ;;{{{ required modules
 (require 'emacspeak-preamble)
+(require 'erc)
 ;;}}}
 ;;{{{  variables
 
@@ -103,18 +104,18 @@ server."
 
 (defadvice erc-select (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 (defadvice erc-send-current-line (after emacspeak pre act
                                         comp)
   "Provide auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)))
 (defadvice erc-send-paragraph (after emacspeak pre act
                                      comp)
   "Provide auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'paragraph)))
 
 ;;}}}
@@ -153,10 +154,10 @@ spoken.")
          (setq start (point))
          (search-forward " ")
          (buffer-substring start (1- (point))))))))
-     
+
 (defun emacspeak-erc-add-name-to-monitor (name &optional
                                                quiten-pronunciation)
-  "Add people to moniter in this room.
+  "Add people to monitor in this room.
 Optional interactive prefix  arg defines a pronunciation that
   silences speaking of this perso's name."
   (interactive
@@ -241,8 +242,7 @@ set the current local value to the result.")
                     emacspeak-erc-my-nick))
   (let ( (buffer (ad-get-arg 1))
          (case-fold-search t))
-    (save-excursion
-      (set-buffer buffer)
+    (with-current-buffer  buffer
       (when (and emacspeak-erc-room-monitor
                  emacspeak-erc-monitor-my-messages)
         (let ((emacspeak-speak-messages nil)
@@ -261,7 +261,7 @@ set the current local value to the result.")
                     emacspeak-erc-my-nick))
   (let ( (buffer (ad-get-arg 1))
          (case-fold-search t))
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (when (and emacspeak-erc-room-monitor
                  emacspeak-erc-monitor-my-messages)
@@ -317,7 +317,7 @@ set the current local value to the result.")
   'emacspeak-erc-add-name-to-monitor)
 (define-key erc-mode-map "\C-c\C-d" 'emacspeak-erc-delete-name-from-monitor)
 ;;}}}
- 
+
 ;;{{{ cricket rules 
 (defvar emacspeak-erc-cricket-bowling-figures-pattern
   " [0-9]+-[0-9]+-[0-9]+-[0-9] "
@@ -392,7 +392,7 @@ set the current local value to the result.")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
