@@ -1,5 +1,5 @@
 ;;; emacspeak-gnus.el --- Speech enable GNUS -- Fluent spoken access to usenet
-;;; $Id: emacspeak-gnus.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-gnus.el 8535 2013-11-13 01:49:39Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable Gnus
 ;;; Keywords: Emacspeak, Gnus, Advice, Spoken Output, News
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -47,8 +47,15 @@
 ;;{{{ requires
 (require 'emacspeak-preamble)
 (require 'gnus)
+(require 'gnus-art)
 (require 'gnus-sum)
 
+;; This may not be needed. It seems emacs version of gnus had 
+;; gnus-article-buffer as far back as emacs 21.
+(unless (and (symbolp 'gnus-article-buffer)
+             (boundp 'gnus-article-buffer))
+  (defvar gnus-article-buffer "*Article*"))
+
 ;;}}}
 ;;{{{  Customizations:
 
@@ -77,12 +84,10 @@
   (declare (special gnus-summary-mode-map
                     gnus-group-mode-map
                     gnus-article-mode-map))
-  (when (boundp 'gnus-summary-mode-map)
-    (emacspeak-keymap-remove-emacspeak-edit-commands gnus-summary-mode-map))
+  (when (boundp 'gnus-summary-mode-map))
   (when (boundp 'gnus-article-mode-map)
-    (emacspeak-keymap-remove-emacspeak-edit-commands gnus-article-mode-map))
-  (when (boundp 'gnus-group-mode-map)
-    (emacspeak-keymap-remove-emacspeak-edit-commands gnus-group-mode-map))
+    )
+  (when (boundp 'gnus-group-mode-map))
   (define-key gnus-summary-mode-map "\C-t" 'gnus-summary-toggle-header)
   (define-key gnus-summary-mode-map "T" 'gnus-summary-hide-all-headers )
   (define-key gnus-summary-mode-map "t"
@@ -148,22 +153,24 @@ reading news."
 
 (defsubst emacspeak-gnus-speak-article-body ()
   (declare (special emacspeak-gnus-large-article
-                    voice-lock-mode dtk-punctuation-mode))
-  (save-excursion
-    (set-buffer  "*Article*")
+                    voice-lock-mode dtk-punctuation-mode
+                    gnus-article-buffer))
+  (with-current-buffer gnus-article-buffer
     (goto-char (point-min))
     (setq dtk-punctuation-mode 'some)
-    (voice-lock-mode 1)
     (emacspeak-dtk-sync)
     (cond
      ((< (count-lines (point-min) (point-max))
          emacspeak-gnus-large-article)
       (emacspeak-speak-buffer  ))
      (t (emacspeak-auditory-icon 'large-movement )
-        (let ((start (point)))
-          (move-to-window-line -1)
-          (end-of-line)
-          (emacspeak-speak-region start (point)))))))
+        (let ((start (point))
+              (window (get-buffer-window (current-buffer))))
+          (with-selected-window window
+            (save-excursion
+              (move-to-window-line -1)
+              (end-of-line)
+              (emacspeak-speak-region start (point)))))))))
 
 ;;}}}
 ;;{{{ Advise top-level gnus command
@@ -179,7 +186,7 @@ reading news."
 
 (defadvice gnus-group-suspend (after emacspeak pre act com)
   "Provide auditory contextual feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'close-object)))
 
@@ -188,7 +195,7 @@ reading news."
 
 (defadvice gnus-group-post-news (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-line)))
 
@@ -207,13 +214,13 @@ reading news."
 (defadvice gnus-group-select-group (before emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)))
 
 (defadvice gnus-group-first-unread-group (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
@@ -221,7 +228,7 @@ reading news."
   "Speak the first article line.
  Produce an auditory icon indicating 
 an object has been opened."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak (gnus-summary-article-subject))))
 
@@ -229,10 +236,10 @@ an object has been opened."
   "Speak the newsgroup line.
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'select-object))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more newsgroups ")
         (emacspeak-speak-line))))
@@ -242,10 +249,10 @@ an object has been opened."
   "Speak the newsgroup line.
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'select-object))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more newsgroups ")
         (emacspeak-speak-line))))
@@ -255,10 +262,10 @@ an object has been opened."
   "Speak the newsgroup line.
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
-    (when (interactive-p) 
+    (when (ems-interactive-p ) 
       (emacspeak-auditory-icon 'select-object))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more newsgroups")
         (emacspeak-speak-line)))))
@@ -267,10 +274,10 @@ an object has been opened."
   "Speak the newsgroup line.
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'select-object))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more newsgroups")
         (emacspeak-speak-line)))))
@@ -278,91 +285,91 @@ an object has been opened."
 (defadvice gnus-group-unsubscribe-current-group (after emacspeak pre act)
   "Produce an auditory icon indicating
 this group is being deselected."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-speak-line )))
 
 (defadvice gnus-group-catchup-current (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-line)))
 
 (defadvice gnus-group-yank-group (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-speak-line)))
 
 (defadvice gnus-group-get-new-news-this-group  (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice gnus-group-list-groups (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "Listing groups... done")))
 
 (defadvice gnus-topic-mode (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "toggled topic mode")))
 
 (defadvice gnus-article-fill-long-lines (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'modified-object)
     (dtk-speak "wrapped long lines")))
 
 (defadvice gnus-group-list-all-groups (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "Listing all groups... done")))
 
 (defadvice gnus-group-list-all-matching (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "Listing all matching groups... done")))
 
 (defadvice gnus-group-list-killed (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "Listing killed groups... done")))
 
 (defadvice gnus-group-list-matching (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "listing matching groups with unread articles... done")))
 
 (defadvice gnus-group-list-zombies (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (dtk-speak "Listing zombie groups... done")))
 
 (defadvice gnus-group-customize (before emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (message "Customizing group %s" (gnus-group-group-name))))
 
@@ -374,7 +381,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -387,7 +394,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -400,7 +407,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -413,7 +420,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -426,7 +433,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -437,7 +444,7 @@ this group is being deselected."
 (defadvice gnus-summary-unmark-as-processable (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-gnus-summary-speak-subject )))
 
@@ -446,7 +453,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -459,7 +466,7 @@ this group is being deselected."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles")
         (progn 
@@ -470,21 +477,21 @@ this group is being deselected."
 (defadvice gnus-summary-delete-article (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon  'delete-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-catchup-from-here (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon  'mark-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-catchup-to-here (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon  'mark-object)
     (emacspeak-gnus-summary-speak-subject )))
 
@@ -492,18 +499,18 @@ this group is being deselected."
   "Speak the modeline.
 Indicate change of selection with
   an auditory icon if possible."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice gnus-summary-prev-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-next-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-exit-no-update  (around emacspeak pre act)
@@ -512,7 +519,7 @@ Indicate change of selection with
   an auditory icon if possible."
   (let ((cur-group gnus-newsgroup-name ))
     ad-do-it
-    (when (interactive-p )
+    (when (ems-interactive-p  )
       (emacspeak-auditory-icon 'close-object)
       (if (eq cur-group (gnus-group-group-name))
           (dtk-speak "No more unread newsgroups")
@@ -526,7 +533,7 @@ Indicate change of selection with
   an auditory icon if possible."
   (let ((cur-group gnus-newsgroup-name ))
     ad-do-it
-    (when (interactive-p )
+    (when (ems-interactive-p  )
       (emacspeak-auditory-icon 'close-object)
       (if (eq cur-group (gnus-group-group-name))
           (dtk-speak "No more unread newsgroups")
@@ -539,7 +546,7 @@ Indicate change of selection with
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles ")
         (progn 
@@ -552,7 +559,7 @@ Indicate change of selection with
 Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles ")
         (progn 
@@ -565,7 +572,7 @@ Produce an auditory icon if possible."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more unread articles ")
         (progn 
@@ -578,7 +585,7 @@ Produce an auditory icon if possible."
 Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles ")
         (progn 
@@ -591,7 +598,7 @@ Produce an auditory icon if possible."
  Produce an auditory icon if possible."
   (let ((saved-point (point )))
     ad-do-it
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (if (= saved-point (point))
           (dtk-speak "No more articles ")
         (progn 
@@ -603,37 +610,35 @@ Produce an auditory icon if possible."
   "Speak the newsgroup line.
  Produce an auditory icon indicating 
 the previous group was closed."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-line )))
 
-  
-
 (defadvice gnus-summary-mark-as-unread-forward (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-mark-as-read-forward (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon'mark-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-mark-as-unread-backward (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-mark-as-read-backward (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'mark-object)
     (emacspeak-gnus-summary-speak-subject )))
 
@@ -641,57 +646,61 @@ the previous group was closed."
   "Speak the subject and speak the first screenful.
 Produce an auditory icon
 indicating the article is being opened."
-  (when (interactive-p)
+  (declare (special gnus-article-buffer))
+  (when (ems-interactive-p )
     (emacspeak-gnus-summary-speak-subject)
     (sit-for 2)
     (emacspeak-auditory-icon 'open-object)
-    (save-excursion
-      (set-buffer  "*Article*")
+    (with-current-buffer
+        gnus-article-buffer
       (emacspeak-dtk-sync)
       (let ((start  (point ))
             (window (get-buffer-window (current-buffer ))))
-        (forward-line (window-height window))
-        (emacspeak-speak-region start (point ))))))
+        (with-selected-window window
+          (save-excursion
+            (move-to-window-line -1)
+            (end-of-line)
+            (emacspeak-speak-region start (point ))))))))
 
 (defadvice gnus-summary-kill-same-subject (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-next-thread (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-prev-thread (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-up-thread (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon'select-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-down-thread (after emacspeak pre act)
   "Speak the line. 
 Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gnus-summary-speak-subject )))
 
 (defadvice gnus-summary-kill-thread (after emacspeak pre act)
   "Speak the line.
  Produce an auditory icon if possible."
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gnus-summary-speak-subject )))
 
@@ -711,105 +720,114 @@ emacspeak-gnus-large-article lines will be considered to be a large article.
 A large article is not spoken all at once;
 instead you hear only the first screenful.")
 
-           
-           
-
 (defadvice gnus-summary-show-article (after emacspeak pre act)
   "Start speaking the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-next-page (after emacspeak pre act)
   "Speak the next pageful "
+  (declare (special gnus-article-buffer))
   (dtk-stop)
   (emacspeak-auditory-icon 'scroll)
-  (save-excursion
-    (set-buffer  "*Article*")
+  (with-current-buffer
+      gnus-article-buffer
     (let ((start  (point ))
           (window (get-buffer-window (current-buffer ))))
-      (forward-line (window-height window))
-      (emacspeak-speak-region start (point )))))
+      (with-selected-window window
+        (save-excursion
+          (move-to-window-line -1)
+          (end-of-line)
+          (emacspeak-speak-region start (point )))))))
 
 (defadvice gnus-summary-prev-page (after emacspeak pre act)
   "Speak the previous  pageful "
+  (declare (special gnus-article-buffer))
   (dtk-stop)
   (emacspeak-auditory-icon 'scroll)
-  (save-excursion
-    (set-buffer  "*Article*")
+  (save-current-buffer
+    (set-buffer  gnus-article-buffer)
     (let ((start  (point ))
           (window (get-buffer-window (current-buffer ))))
-      (forward-line (-  (window-height window)))
-      (emacspeak-speak-region start (point )))))
+      (with-selected-window window
+        (save-excursion
+          (move-to-window-line -1)
+          (end-of-line)
+          (emacspeak-speak-region start (point )))))))
 
 (defadvice gnus-summary-beginning-of-article (after emacspeak pre act)
-  "Speak the first line. "(save-excursion
-                            (set-buffer "*Article*")
-                            (emacspeak-speak-line )))
+  "Speak the first line. "
+  (declare (special gnus-article-buffer))
+  (save-current-buffer
+    (set-buffer gnus-article-buffer)
+    (emacspeak-speak-line )))
 
 (defadvice gnus-summary-end-of-article
 
-  (after emacspeak pre act)
-  "Speak the first line. "(save-excursion
-                            (set-buffer "*Article*")
-                            (emacspeak-speak-line )))
+    (after emacspeak pre act)
+  "Speak the first line. "
+  (declare (special gnus-article-buffer))
+  (save-current-buffer
+    (set-buffer gnus-article-buffer)
+    (emacspeak-speak-line )))
 
 (defadvice gnus-summary-next-unread-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-prev-unread-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-next-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-prev-same-subject  (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-next-same-subject  (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-first-unread-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body)))
 
 (defadvice gnus-summary-goto-last-article (after emacspeak pre act)
   "Speak the article. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gnus-speak-article-body )))
 
 (defadvice gnus-article-show-summary  (after emacspeak pre act)
   "Speak the modeline.
 Indicate change of selection with
   an auditory icon if possible."
-  (when (interactive-p )
+  (when (ems-interactive-p  )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice gnus-article-next-page (after emacspeak pre act )
   "Speak the current window full of news"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-current-window )))
 
 (defadvice gnus-article-prev-page (after emacspeak pre act )
   "Speak the current window full"
-  (when    (interactive-p)
+  (when    (ems-interactive-p )
     (emacspeak-speak-current-window)))
 
 (defadvice gnus-article-next-button (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((end (next-single-property-change
                 (point) 'gnus-callback)))
       (emacspeak-auditory-icon 'large-movement)
@@ -818,19 +836,19 @@ Indicate change of selection with
 
 (defadvice gnus-article-press-button (before emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)))
 
 (defadvice gnus-article-goto-prev-page (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (sit-for 1)
     (emacspeak-speak-current-window)))
 
 (defadvice gnus-article-goto-next-page (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (sit-for 1)
     (emacspeak-speak-current-window)))
@@ -905,25 +923,15 @@ Helps to prevent words from being spelled instead of spoken."
  ;; face names are for gnus shipped with emacs 22 
  ;; rdc 102206
  '(
-   (gnus-cite-face-1 voice-bolden) ;; emacs 21
    (gnus-cite-1 voice-bolden-medium)
-   (gnus-cite-face-2 voice-lighten) ;; emacs 21
    (gnus-cite-2 voice-lighten) 
-   (gnus-cite-face-3 voice-lighten-extra) ;; emacs 21
    (gnus-cite-3 voice-lighten-extra)
-   (gnus-cite-face-4 voice-bolden-medium) ;; emacs 21
    (gnus-cite-4 voice-bolden)
-   (gnus-cite-face-5 voice-bolden) ;; emacs 21
    (gnus-cite-5 voice-bolden-medium)
-   (gnus-cite-face-6 voice-lighten) ;; emacs 21
    (gnus-cite-6 voice-lighten)
-   (gnus-cite-face-7 voice-lighten-extra) ;; emacs 21
    (gnus-cite-7 voice-lighten-extra)
-   (gnus-cite-face-8 voice-bolden-medium) ;; emacs 21
    (gnus-cite-8 voice-bolden)
-   (gnus-cite-face-9 voice-bolden) ;; emacs 21
    (gnus-cite-9 voice-bolden-medium)
-   (gnus-cite-face-10 voice-lighten) ;; emacs 21
    (gnus-cite-10 voice-lighten)
    (gnus-cite-11 voice-lighten-extra)
    (gnus-emphasis-highlight-words voice-lighten-extra)
@@ -931,54 +939,32 @@ Helps to prevent words from being spelled instead of spoken."
    (gnus-emphasis-strikethru voice-bolden-extra)
    (gnus-emphasis-italic voice-lighten)
    (gnus-emphasis-underline voice-brighten-extra)
-   (gnus-signature-face voice-animate) ;; emacs 21
    (gnus-signature voice-animate)
-   (gnus-header-content-face voice-bolden) ;; emacs 21
    (gnus-header-content voice-bolden)
-   (gnus-header-name-face voice-animate) ;; emacs 21
    (gnus-header-name voice-animate)
-   (gnus-header-from-face voice-bolden) ;; emacs 21
    (gnus-header-from voice-bolden)
-   (gnus-header-newsgroups-face voice-bolden) ;; emacs 21
    (gnus-header-newsgroups voice-bolden)
-   (gnus-header-subject-face voice-bolden) ;; emacs 21
    (gnus-header-subject voice-bolden)
    ;; ;; summary buffer personalities
    ;; since there are so many distinctions, most variations
    ;; on the same thing are given the same voice.  Any user that
    ;; uses low and high interest is sufficiently advanced to change
    ;; the voice to his own preferences
-   (gnus-summary-normal-read-face voice-bolden) ;; emacs 21
    (gnus-summary-normal-read voice-bolden)
-   (gnus-summary-high-read-face voice-bolden) ;; emacs 21
    (gnus-summary-high-read voice-bolden)
-   (gnus-summary-low-read-face voice-bolden) ;; emacs 21
    (gnus-summary-low-read voice-bolden)
-   (gnus-summary-normal-ticked-face voice-brighten) ;; emacs 21
    (gnus-summary-normal-ticked voice-brighten-extra)
-   (gnus-summary-high-ticked-face voice-brighten) ;; emacs 21
    (gnus-summary-high-ticked voice-brighten-extra)
-   (gnus-summary-low-ticked-face voice-brighten) ;; emacs 21
    (gnus-summary-low-ticked voice-brighten-extra)
-   (gnus-summary-normal-ancient-face voice-smoothen-extra) ;; emacs 21
    (gnus-summary-normal-ancient voice-smoothen-extra)
-   (gnus-summary-high-ancient-face voice-smoothen-extra) ;; emacs 21
    (gnus-summary-high-ancient voice-smoothen-extra)
-   (gnus-summary-low-ancient-face voice-smoothen-extra) ;; emacs 21
    (gnus-summary-low-ancient voice-smoothen-extra)
-   (gnus-summary-normal-undownloaded-face voice-bolden) ;; emacs 21
    (gnus-summary-normal-undownloaded voice-bolden-and-animate)
-   (gnus-summary-high-undownloaded-face voice-bolden-and-animate) ;; emacs 21
    (gnus-summary-high-undownloadedvoice-bolden-and-animate)
-   (gnus-summary-low-undownloaded-face voice-bolden) ;; emacs 21
    (gnus-summary-low-undownloaded voice-bolden-and-animate)
-   (gnus-summary-low-unread-face voice-bolden-extra) ;; emacs 21
    (gnus-summary-low-unread voice-bolden-medium)
-   (gnus-summary-high-unread-face voice-bolden) ;; emacs 21
    (gnus-summary-high-unread voice-brighten-extra)
-   (gnus-summary-selected-face voice-animate-extra) ;; emacs 21
    (gnus-summary-selected voice-animate-extra)
-   (gnus-summary-cancelled-face voice-bolden-extra) ;; emacs 21
    (gnus-summary-cancelled voice-bolden-extra)
 
    ;; group buffer personalities
@@ -986,69 +972,41 @@ Helps to prevent words from being spelled instead of spoken."
    ;; default voice.  I might ask if there is a call for different voices 
    ;; as they are only necessary if users have persistently visible groups
    ;; in the case of empty groups, and voices for the various levels.
-   (gnus-group-mail-1-empty-face default) ;; emacs 21
    (gnus-group-mail-1-empty voice-bolden-extra)
-   (gnus-group-mail-1-face default) ;; emacs 21
    (gnus-group-mail-1 default)
-   (gnus-group-mail-2-empty-face voice-smoothen-extra) ;; emacs 21
    (gnus-group-mail-2-empty voice-bolden-extra)
-   (gnus-group-mail-2-face voice-bolden) ;; emacs 21
    (gnus-group-mail-2 default)
-   (gnus-group-mail-3-empty-face voice-bolden) ;; emacs 21
    (gnus-group-mail-3-empty  voice-bolden-extra)
-   (gnus-group-mail-3-face voice-bolden) ;; emacs 21
    (gnus-group-mail-3 default)
-   (gnus-group-mail-low-empty-face voice-bolden) ;; emacs 21
    (gnus-group-mail-low-empty voice-bolden-extra)
-   (gnus-group-mail-low-face voice-bolden) ;; emacs 21
    (gnus-group-mail-low default)
-   (gnus-group-news-1-empty-face voice-bolden) ;; emacs 21
    (gnus-group-news-1-empty voice-bolden-extra)
-   (gnus-group-news-1-face voice-bolden) ;; emacs 21
    (gnus-group-news-1 default)
-   (gnus-group-news-2-empty-face voice-bolden) ;; emacs 21
    (gnus-group-news-2-empty voice-bolden-extra)
-   (gnus-group-news-2-face voice-bolden-extra) ;; emacs 21
    (gnus-group-news-2 default)
-   (gnus-group-news-3-empty-face voice-bolden) ;; emacs 21
    (gnus-group-news-3-empty voice-bolden-extra)
-   (gnus-group-news-3-face voice-bolden) ;; emacs 21
    (gnus-group-news-3 default)
-   (gnus-group-news-4-empty-face voice-bolden) ;; emacs 21
    (gnus-group-news-4-empty voice-bolden-extra)
-   (gnus-group-news-4-face voice-bolden) ;; emacs 21
    (gnus-group-news-4 default)
-   (gnus-group-news-5-empty-face voice-bolden) ;; emacs 21
    (gnus-group-news-5-empty voice-bolden-extra)
-   (gnus-group-news-5-face voice-bolden) ;; emacs 21
    (gnus-group-news-5 default)
-   (gnus-group-news-6-empty-face voice-bolden) ;; emacs 21
    (gnus-group-news-6-empty voice-bolden-extra)
-   (gnus-group-news-6-face voice-bolden-extra) ;; emacs 21
    (gnus-group-news-6 default)
-   (gnus-group-news-low-empty-face voice-bolden-extra) ;; emacs 21
    (gnus-group-news-low-empty voice-bolden-extra)
-   (gnus-group-news-low-face voice-bolden-extra) ;; emacs 21
    (gnus-group-news-low default)
    
    ;; server buffer personalities
 
-   (gnus-server-agent-face voice-bolden) ;; emacs 21
    (gnus-server-agent voice-bolden)
-   (gnus-server-closed-face voice-bolden-medium) ;; emacs 21
    (gnus-server-closed voice-bolden-medium)
-   (gnus-server-denied-face voice-bolden-extra) ;; emacs 21
    (gnus-server-denied voice-bolden-extra)
-   (gnus-server-offline-face voice-animate) ;; emacs 21
    (gnus-server-offline voice-animate)
-   (gnus-server-opened-face voice-lighten) ;; emacs 21
-   (gnus-server-opened voice-lighten)
-   ))
+   (gnus-server-opened voice-lighten)))
 ;;}}}
 (provide 'emacspeak-gnus)
 ;;{{{  end of file 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 ;;}}}
