@@ -1,5 +1,5 @@
 ;;; emacspeak-gomoku.el --- Speech enable the game of Gomoku
-;;; $Id: emacspeak-gomoku.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-gomoku.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to gomoku
 ;;; Keywords: Emacspeak, Speak, Spoken Output, gomoku
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -254,68 +254,68 @@
                                         ;       (format
                                         ;        "(defadvice %s  (after emacspeak pre act comp)
                                         ;              \"Provide auditory feedback\"
-                                        ;              (when (interactive-p)
+                                        ;              (when (ems-interactive-p )
                                         ;                (emacspeak-auditory-icon 'select-object)
                                         ;                (emacspeak-gomoku-speak-square)))\n\n"
                                         ;        command)))
 
 (defadvice gomoku-beginning-of-line  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-end-of-line  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-down  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-up  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-left  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-right  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-ne  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-nw  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-se  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
 (defadvice gomoku-move-sw  (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-gomoku-speak-square)))
 
@@ -342,7 +342,7 @@
 
 (defadvice gomoku (after emacspeak pre act comp)
   "Speech enable gomoku"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-gomoku-setup-keys)))
 ;;}}}
 ;;{{{ keybindings
@@ -350,10 +350,10 @@
 (defun emacspeak-gomoku-setup-keys ()
   "Add additional keybindings"
   (declare (special gomoku-mode-map))
-  (loop for key in (where-is-internal 'backward-char gomoku-mode-map)
+  (loop for key in (where-is-internal 'backward-char (list gomoku-mode-map))
         do
         (define-key gomoku-mode-map key 'gomoku-move-left))
-  (loop for key in (where-is-internal 'forward-char gomoku-mode-map)
+  (loop for key in (where-is-internal 'forward-char (list gomoku-mode-map))
         do
         (define-key gomoku-mode-map key 'gomoku-move-right))
   (define-key gomoku-mode-map "\t"
@@ -390,7 +390,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
