@@ -1,5 +1,5 @@
 ;;; emacspeak-gridtext.el --- Overlay Grids To filter columnar text
-;;; $Id: emacspeak-gridtext.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-gridtext.el 8535 2013-11-13 01:49:39Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for laying grids on text
 ;;; Keywords: Emacspeak, gridtext
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -85,7 +85,7 @@ future  use."
   (declare (special  major-mode))
   (or (buffer-file-name)
       (format "%s:%s" (buffer-name) major-mode)))
-   
+
 (defun emacspeak-gridtext-vector-region (start end grid)
   "Returns a vector containing the text bounded by start and
 end   as specified by grid."
@@ -128,7 +128,6 @@ end   as specified by grid."
               (forward-line 1))
         result-grid))))
 
-          
 ;;}}}
 ;;{{{  persistent store 
 
@@ -170,7 +169,7 @@ end   as specified by grid."
   (let ((buffer (find-file-noselect
                  (expand-file-name file
                                    emacspeak-resource-directory))))
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (erase-buffer)
       (loop for key being the hash-keys of
@@ -209,7 +208,6 @@ end   as specified by grid."
      (emacspeak-gridtext-generate-key) grid)
     (emacspeak-table-prepare-table-buffer grid-table buffer)))
 
-                         
 ;;}}}
 ;;{{{  keymaps 
 (defvar emacspeak-gridtext-keymap nil
@@ -226,7 +224,7 @@ end   as specified by grid."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
