@@ -1,5 +1,5 @@
 ;;; emacspeak-imenu.el --- Speech enable Imenu -- produce buffer-specific table of contents
-;;; $Id: emacspeak-imenu.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-imenu.el 8443 2013-10-23 23:48:27Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Auditory interface buffer indices
 ;;; Keywords: Emacspeak, Speak, Spoken Output, indices
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -39,8 +39,10 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 ;;{{{  Required modules
-
+(require 'cl)
+(declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
+(require 'imenu)
 ;;}}}
 ;;{{{  Introduction
 
@@ -93,7 +95,7 @@
 
 (defadvice imenu (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (ems-set-personality-temporarily (point) (1+ (point))
                                      voice-animate
                                      (emacspeak-speak-line))))
@@ -101,7 +103,7 @@
 (defadvice imenu-go-find-at-position (around emacspeak pre act comp)
   "Provide auditory feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (push-mark)
     ad-do-it
     (emacspeak-auditory-icon 'large-movement)
@@ -113,7 +115,7 @@
 
 (defadvice imenu-go--back (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (ems-set-personality-temporarily (point) (1+ (point))
                                      voice-animate
@@ -153,7 +155,7 @@
             (if (< guess target)
                 (setq target guess))))
     (goto-char target)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'large-movement)
       (if emacspeak-imenu-autospeak
           (emacspeak-imenu-speak-this-section)
@@ -188,7 +190,7 @@
             (if (> guess target)
                 (setq target guess))))
     (goto-char target)
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'large-movement)
       (if emacspeak-imenu-autospeak
           (emacspeak-imenu-speak-this-section)
@@ -226,7 +228,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
