@@ -1,5 +1,5 @@
 ;;; emacspeak-jde.el --- Speech enable JDE -- An integrated Java Development Environment
-;;; $Id: emacspeak-jde.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Id: emacspeak-jde.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to JDE
 ;;; Keywords: Emacspeak, Speak, Spoken Output, Java
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -67,24 +67,24 @@
                                         ;jde-java-font-lock-link-face
                                         ;jde-java-font-lock-doc-tag-face
                                         ;jde-java-font-lock-modifier-face
-                                        
+
 ;;}}}
 ;;{{{ Advice interactive commands:
 (defadvice jde-open-class-source (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice jde-open-source-for-symbol (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice jde-open-base-class-source (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 (defadvice jde-complete-popup-message (before emacspeak pre act comp)
@@ -102,27 +102,27 @@
 
 (defadvice jde-compile (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak "Compiling current java project")))
 
 (defadvice bsh (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (setq emacspeak-comint-autospeak nil)
     (emacspeak-speak-mode-line)))
 
 (defadvice jde-run (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (setq emacspeak-comint-autospeak nil)
     (emacspeak-speak-mode-line)))
 
 (defadvice jde-db (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
@@ -131,37 +131,37 @@
 
 (defadvice jde-debug (after emacspeak pre act comp)
   "Speak the line where we eventually stop. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice jde-bug-step-over (after emacspeak pre act comp)
   "Speak the line we stepped to "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice jde-bug-step-into (after emacspeak pre act comp)
   "Speak the line we stepped to "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice jde-bug-step-out (after emacspeak pre act comp)
   "Speak the line we stepped to "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice jde-bug-continue (after emacspeak pre act comp)
   "Speak the line we stop  to "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
 (defadvice jde-bug-exit (after emacspeak pre act comp)
   "Produce auditory icon indicating successful exit "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-line)))
 
@@ -172,18 +172,18 @@
 (defadvice jde-bug-toggle-breakpoint (after emacspeak pre
                                             act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "toggled breakpoint.")))
 
 (defadvice jde-bug-set-breakpoint (after emacspeak pre act comp)
   "Speak the line we set the break point at "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'mark-object)))
 
 (defadvice jde-bug-clear-breakpoint (after emacspeak pre act comp)
   "Speak the line we nuked the breakpoint  "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'deselect-object)
     (emacspeak-speak-line)))
 
@@ -196,9 +196,9 @@
       (beginning-of-line)
       (setq  start (point))
       (end-of-line)
-      (ems-modify-buffer-safely
-       (put-text-property start (point)
-                          'auditory-icon 'mark-object)))))
+      (with-silent-modifications
+        (put-text-property start (point)
+                           'auditory-icon 'mark-object)))))
 
 (defadvice jde-bug-remove-breakpoint-highlight (after emacspeak pre act comp)
   "Clear auditory annotation"
@@ -207,20 +207,20 @@
       (beginning-of-line)
       (setq  start (point))
       (end-of-line)
-      (ems-modify-buffer-safely
-       (remove-text-properties
-        start (point)
-        (list 'auditory-icon 'mark-object))))))
+      (with-silent-modifications
+        (remove-text-properties
+         start (point)
+         (list 'auditory-icon 'mark-object))))))
 
 (defadvice jde-bug-up-stack (after emacspeak pre act comp)
   "Speak the line we stepped to "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice jde-bug-down-stack (after emacspeak pre act comp)
   "Speak the line we stepped to "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
@@ -238,48 +238,47 @@
       (eval
        `(defadvice ,command (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-speak-line)
             (emacspeak-auditory-icon 'select-object)))))
 
 (defadvice jde-db-run (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)))
 
 (defadvice jde-debug-cont (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)
     (message "Continuing execution.")))
 (defadvice jde-debug-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (message "Quit debugger.")))
 (defadvice jde-debug-set-breakpoint (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'mark-object)))
 
 (defadvice jde-debug-toggle-breakpoint (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'button)))
 (defadvice jde-debug-clear-breakpoints (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (message "Cleared all break points.")))
 
-    
 ;;}}}
 ;;{{{ advice jde-xref
 (defadvice jde-xref-first-caller(after emacspeak pre act comp)
   "Speak line we jumped to."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-line)))
 
@@ -287,16 +286,13 @@
   "Speak line we jumped to.
 If we are on the last call, do nothing."
   (cond
-   ( (and (interactive-p)
+   ( (and (ems-interactive-p )
           (car jde-xref-stack))
      ad-do-it
      (emacspeak-auditory-icon 'large-movement)
      (emacspeak-speak-line))
    (t ad-do-it))
   ad-return-value)
-  
-   
-  
 
 ;;}}}
 ;;{{{ Advice EFC widgets:
@@ -306,16 +302,26 @@ If we are on the last call, do nothing."
   (emacspeak-auditory-icon 'open-object)
   (dtk-speak
    (ad-get-arg 0)))
-            
-            
 
 ;;}}}
+;;{{{ camel case deletion
+
+(defadvice jde-kill-camel-tok (before emacspeak pre act )
+  "Speak word before killing it."
+  (when (ems-interactive-p  )
+    (dtk-speak
+     (buffer-substring
+      (point)
+      (save-excursion (jde-end-of-camel-tok))))))
+
+;;}}}
+
 (provide 'emacspeak-jde )
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
