@@ -1,5 +1,5 @@
 ;;; emacspeak-m-player.el --- Control mplayer from Emacs
-;;; $Id: emacspeak-m-player.el 5370 2007-11-21 16:14:32Z tv.raman.tv $
+;;; $Id: emacspeak-m-player.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Controlling mplayer from emacs 
 ;;; Keywords: Emacspeak, m-player streaming media 
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-11-21 08:14:32 -0800 (Wed, 21 Nov 2007) $ |
+;;; $Date: 2008-06-29 17:58:19 -0700 (Sun, 29 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -61,50 +61,132 @@
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
-(require 'desktop)
+(require 'emacspeak-webutils)
 (require 'dired)
 (require 'comint)
 
 ;;}}}
 ;;{{{ define a derived mode for m-player interaction 
+(defvar emacspeak-media-shortcuts-directory 
+  (expand-file-name "realaudio/" emacspeak-directory)
+  "*Directory where we organize  mp3  libraries and media shortcuts. ")
 
 (defvar emacspeak-m-player-process nil
   "Process handle to m-player." )
+(defsubst emacspeak-m-player-dispatch (command)
+  "Dispatch command to m-player."
+  (declare (special emacspeak-m-player-process))
+  (with-current-buffer (process-buffer emacspeak-m-player-process)
+    (erase-buffer)
+    (process-send-string
+     emacspeak-m-player-process
+     (format "pausing_keep %s\n" command))
+    (accept-process-output emacspeak-m-player-process 0.1)
+    (unless (zerop (buffer-size))
+      (buffer-substring-no-properties (point-min) (1-  (point-max))))))
+(defvar emacspeak-m-player-current-directory nil
+  "Records current directory of media being played.
+This is set to nil when playing Internet  streams.")
 
-(define-prefix-command 'emacspeak-m-player-prefix-command
-  'emacspeak-m-player-mode-map)
+(defvar emacspeak-m-player-info-ring (make-ring 20)
+  "Stores info cache entries each time we quit m-player.")
+
+(defvar emacspeak-m-player-info-cache nil
+  "Cache currently playing info.")
+
+(defun emacspeak-m-player-current-info ()
+  "Return filename ,  position and directory of current track as a list."
+  (declare (special emacspeak-m-player-info-cache))
+  (let ((file (emacspeak-m-player-dispatch "get_file_name\n"))
+        (pos (emacspeak-m-player-dispatch "get_percent_pos\n")))
+    (when (and file pos)
+      (setq
+       file
+       (substring (second (split-string file "=")) 1 -1)
+       pos (second (split-string pos "="))))
+    (setq emacspeak-m-player-info-cache
+          (list file pos emacspeak-m-player-current-directory))))
+
+(defun emacspeak-m-player-speak-current-info ()
+  "Speak cached  info about currently playing file."
+  (interactive)
+  (declare (special emacspeak-m-player-info-cache))
+  (message
+   "%s%% in %s"
+   (second emacspeak-m-player-info-cache)
+   (first emacspeak-m-player-info-cache)))
+
+(defsubst emacspeak-m-player-mode-line ()
+  "Meaningful mode-line."
+  (let ((info (emacspeak-m-player-current-info)))
+    (format "%s: %s%%"
+            (first info)
+            (second info))))
+
+(defun emacspeak-m-player-speak-mode-line ()
+  "Speak mode line"
+  (interactive)
+  (tts-with-punctuations
+   'all
+   (dtk-speak (emacspeak-m-player-mode-line))))
 
 (define-derived-mode emacspeak-m-player-mode comint-mode 
   "M-Player Interaction"
   "Major mode for m-player interaction. \n\n
 \\{emacspeak-m-player-mode-map}"
-  (setq emacspeak-m-player-process (get-buffer-process (current-buffer))))
+  (progn
+    (setq buffer-undo-list t)
+    (ansi-color-for-comint-mode-on)
+    (setq emacspeak-m-player-process (get-buffer-process (current-buffer)))))
 
 ;;}}}
 ;;{{{ emacspeak-m-player
+
 ;;;###autoload
 
 (defgroup emacspeak-m-player nil
   "Emacspeak media player settings."
   :group 'emacspeak)
-(defcustom emacspeak-m-player-height 1
-  "Height of MPlayer window."
-  :type 'number
-  :group 'emacspeak-m-player)
+
 (defcustom emacspeak-m-player-program "mplayer"
   "Media player program."
   :type 'string
+  :set  #'(lambda (sym val)
+            (set-default sym
+                         (executable-find val)))
   :group 'emacspeak-m-player)
-(defvar emacspeak-m-player-default-options
-  (list "-slave"  "-nortc""-softvol" "100" )
-  "Default options for MPlayer.")
 
+(defvar emacspeak-m-player-default-options
+  (list "-slave"  "-nortc""-softvol" "-softvol-max" "200" "-quiet")
+  "Default options for MPlayer.")
 (defcustom emacspeak-m-player-options 
   (copy-sequence emacspeak-m-player-default-options)
   "Options passed to mplayer."
   :type  '(repeat
            (string :tag "option"))
   :group 'emacspeak-m-player)
+;;;###autoload
+(defcustom emacspeak-media-location-bindings  nil
+  "*Map specific key sequences to launching MPlayer accelerators 
+on a specific directory."
+  :group 'emacspeak-m-player
+  :type '(repeat :tag "Emacspeak Media Locations"
+                 (cons  :tag "KeyBinding"
+                        (string :tag "Key")
+                        (directory :tag "Directory")))
+  :set #'(lambda (sym val)
+           (mapc
+            (lambda (binding)
+              (let ((key (car binding))
+                    (directory (cdr binding )))
+                (when (string-match "\\[.+]" key)
+                  (setq key (car (read-from-string key))))
+                (emacspeak-m-player-bind-accelerator directory key)))
+            val)
+           (set-default sym val)))
+(defvar emacspeak-media-directory-regexp
+  "\\(mp3\\)\\|\\(audio\\)"
+  "Pattern matching locations where we store media.")
 
 ;;;###autoload
 (defun emacspeak-multimedia  ()
@@ -114,28 +196,19 @@
   (cond
    ((and emacspeak-m-player-process
          (eq 'run (process-status emacspeak-m-player-process)))
-    (call-interactively 'emacspeak-m-player-command)   )
+    (with-current-buffer (process-buffer emacspeak-m-player-process)
+      (call-interactively 'emacspeak-m-player-command)))
    (t  (call-interactively 'emacspeak-m-player))))
 
-(defun emacspeak-m-player-command (command-char)
+(defun emacspeak-m-player-command (key)
   "Invoke MPlayer commands."
-  (interactive
-   (list
-    (read-char "MPlayer Command: ")))
-  (declare (special emacspeak-m-player-process
-		    emacspeak-m-player-height))
+  (interactive (list (read-key-sequence "MPlayer Key: ")))
+  (declare (special emacspeak-m-player-process))
   (cond
-   ((=  command-char ?\;)
-    (pop-to-buffer
-     (process-buffer emacspeak-m-player-process))
-    (set-window-text-height nil emacspeak-m-player-height)
-    (set-window-dedicated-p (selected-window) t)
+   ((and (stringp key) (string= ";" key))
+    (pop-to-buffer (process-buffer emacspeak-m-player-process))
     (emacspeak-speak-mode-line))
-   (t
-    (save-window-excursion
-      (call-interactively
-       (lookup-key emacspeak-m-player-mode-map
-                   (format "%c" command-char)))))))
+   (t (call-interactively (lookup-key emacspeak-m-player-mode-map key)))))
 
 (defvar  emacspeak-m-player-playlist-pattern
   (concat
@@ -148,9 +221,76 @@
   "Check if specified resource matches a playlist type."
   (declare (special emacspeak-m-player-playlist-pattern))
   (string-match emacspeak-m-player-playlist-pattern resource))
+;;;###autoload
+(defvar emacspeak-media-extensions
+  (concat
+   (regexp-opt
+    (list ".wma"
+          ".wmv"
+          ".flv"
+          ".m4a"
+          ".m4b"
+          ".flac"
+          ".ogg"
+          ".mp3"
+          ".MP3"
+          ".mp4")
+    'parens)
+   "$")
+  "Extensions that match media files.")
 
 ;;;###autoload
-(defun emacspeak-m-player (resource &optional play-list noselect)
+(defun emacspeak-m-player-bind-accelerator (directory key)
+  "Binds key to invoke m-player  on specified directory."
+  (interactive
+   (list
+    (read-directory-name"Media Directory: ")
+    (read-key-sequence "Key: ")))
+  (let ((command
+         (eval 
+          `(defun 
+               ,(intern (format "emacspeak-m-player-accelerator-%s" (gensym)))
+               ()
+             (interactive)
+             (emacspeak-m-player-accelerator ,directory)))))
+    (global-set-key key command)))
+
+;;;###autoload
+(defun emacspeak-m-player-accelerator (directory)
+  "Launch MPlayer on specified directory and switch to it."
+  (let ((emacspeak-media-shortcuts-directory (expand-file-name directory)))
+    (call-interactively 'emacspeak-multimedia)
+    (switch-to-buffer (process-buffer emacspeak-m-player-process))
+    (emacspeak-auditory-icon 'select-object)
+    (emacspeak-speak-mode-line)))
+(defsubst emacspeak-m-player-guess-directory ()
+  "Guess default directory."
+  (if (string-match "\\(mp3\\)\\|\\(audio\\)"  default-directory)
+      default-directory
+    emacspeak-media-shortcuts-directory))
+;;;###autoload 
+(defun emacspeak-m-player-url (url)
+  "Call emacspeak-m-player with specified URL."
+  (interactive "sURL: ")
+  (emacspeak-m-player url))
+;;;###autoload
+(defun emacspeak-m-player-resume ()
+  "Resume M-Player where it was stopped if possible.
+Only works for local media sources, not Internet streams."
+  (interactive)
+  (cond
+   ((and emacspeak-m-player-info-cache
+         emacspeak-m-player-current-directory
+         (not (eq 'run (process-status emacspeak-m-player-process))))
+    (emacspeak-m-player
+     (expand-file-name (car emacspeak-m-player-info-cache)
+                       emacspeak-m-player-current-directory))
+    (sit-for 0.5)
+    (emacspeak-m-player-seek-absolute (second emacspeak-m-player-info-cache)))
+   (t ( message "Cannot resume previously stopped track."))))
+
+;;;###autoload
+(defun emacspeak-m-player (resource &optional play-list)
   "Play specified resource using m-player.
 Optional prefix argument play-list interprets resource as a play-list.
 Resource is a media resource or playlist containing media resources.
@@ -160,35 +300,42 @@ The player is placed in a buffer in emacspeak-m-player-mode."
     (let ((completion-ignore-case t)
           (emacspeak-speak-messages nil)
           (read-file-name-completion-ignore-case t)
-          (minibuffer-history emacspeak-realaudio-history))
-      (emacspeak-pronounce-define-local-pronunciation
-       emacspeak-realaudio-shortcuts-directory " shortcuts/ ")
-      (read-file-name "MP3 Resource: "
-                      (if
-                          (string-match
-                           "mp3" (expand-file-name default-directory))
-                          default-directory
-                        emacspeak-realaudio-shortcuts-directory)
-                      (when (eq major-mode 'dired-mode)
-                        (dired-get-filename))))
-    current-prefix-arg
-    'noselect))
-  (declare (special emacspeak-realaudio-history emacspeak-realaudio-shortcuts-directory
-		    emacspeak-m-player-height emacspeak-m-player-process
+          (ido-work-directory-list
+           (remove-if-not 
+            #'(lambda (d)
+                (string-match  emacspeak-media-directory-regexp  d))
+            ido-work-directory-list)))
+      (read-file-name
+       "MP3 Resource: "
+       (emacspeak-m-player-guess-directory)
+       (when (eq major-mode 'dired-mode) (dired-get-filename))))
+    current-prefix-arg))
+  (declare (special emacspeak-media-extensions default-directory
+                    emacspeak-media-directory-regexp
+                    emacspeak-m-player-current-directory
+                    emacspeak-media-shortcuts-directory emacspeak-m-player-process
                     emacspeak-m-player-program emacspeak-m-player-options))
   (unless (string-match "^[a-z]+:"  resource)
-    (setq resource (expand-file-name resource)))
+    (setq resource (expand-file-name resource))
+    (setq emacspeak-m-player-current-directory (file-name-directory resource))
+    (setq default-directory emacspeak-m-player-current-directory))
   (when (and emacspeak-m-player-process
-             (eq 'run (process-status
-                       emacspeak-m-player-process))
+             (eq 'run (process-status emacspeak-m-player-process))
              (y-or-n-p "Stop currently playing music? "))
     (emacspeak-m-player-quit)
     (setq emacspeak-m-player-process nil))
-  (let ((process-connection-type nil)
+  (let ((buffer "*M-Player*")
+        (process-connection-type nil)
         (playlist-p
          (or play-list
              (emacspeak-m-player-playlist-p resource)))
         (options (copy-sequence emacspeak-m-player-options)))
+    (when (getenv "ALSA_DEFAULT")
+      (setq options
+            (nconc options
+                   (list "-ao"
+                         (format "alsa:device=%s"
+                                 (getenv "ALSA_DEFAULT"))))))
     (setq options
           (cond
            (playlist-p
@@ -199,49 +346,97 @@ The player is placed in a buffer in emacspeak-m-player-mode."
              (directory-files
               (expand-file-name resource)
               'full
-              "\\(ogg$\\)\\|\\(mp3$\\)\\|\\(MP3$\\)")))
+              emacspeak-media-extensions)))
            (t
-            (nconc
-             options
-             (list resource)))))
-    (setq emacspeak-m-player-process
-          (get-buffer-process
-           (apply 'make-comint
-                  "m-player" emacspeak-m-player-program
-                  nil
-                  options)))
-    (save-excursion
-      (set-buffer (process-buffer emacspeak-m-player-process))
-      (emacspeak-m-player-mode)
-      (setq buffer-undo-list t)
-      (ansi-color-for-comint-mode-on))
-    (unless noselect
-      (pop-to-buffer (process-buffer emacspeak-m-player-process))
-      (set-window-text-height nil emacspeak-m-player-height)
-      (set-window-dedicated-p (selected-window) t))))
+            (nconc options (list resource)))))
+    (save-current-buffer
+      (setq emacspeak-m-player-process
+            (apply 'start-process "M PLayer" buffer
+                   emacspeak-m-player-program options))
+      (set-buffer buffer)
+      (emacspeak-m-player-mode))))
+
+;;;###autoload
+(defun emacspeak-m-player-shuffle ()
+  "Launch M-Player with shuffle turned on."
+  (interactive)
+  (declare (special emacspeak-m-player-options))
+  (let ((emacspeak-m-player-options (append emacspeak-m-player-options (list "-shuffle"))))
+    (call-interactively 'emacspeak-m-player)))
+
+;;;###autoload
+
+(defun emacspeak-m-player-load (resource  &optional append)
+  "Load specified resource into a running  m-player.
+Interactive prefix arg appends the new resource to what is playing."
+  (interactive
+   (list
+    (let ((completion-ignore-case t)
+          (emacspeak-speak-messages nil)
+          (read-file-name-completion-ignore-case t))
+      (read-file-name
+       "MP3 Resource: "
+       (if
+           (string-match "\\(mp3\\)\\|\\(audio\\)"
+                         (expand-file-name default-directory))
+           default-directory
+         emacspeak-media-shortcuts-directory)
+       (when (eq major-mode 'dired-mode)
+         (dired-get-filename))))
+    current-prefix-arg))
+  (declare (special emacspeak-media-extensions
+                    emacspeak-media-shortcuts-directory))
+  (unless (string-match "^[a-z]+:"  resource)
+    (setq resource (expand-file-name resource)))
+  (emacspeak-m-player-dispatch 
+   (format "loadfile %s %s" resource
+           (if append 1 ""))))
+
+;;}}}
+;;{{{ Table of slave commands:
+
+(defvar emacspeak-m-player-command-list nil
+  "Cache of MPlayer slave commands.")
+
+(defun emacspeak-m-player-command-list ()
+  "Return MPlayer slave command table, populating it if
+necessary."
+  (declare (special emacspeak-m-player-command-list))
+  (cond
+   (emacspeak-m-player-command-list emacspeak-m-player-command-list)
+   (t
+    (let ((commands
+           (split-string 
+            (shell-command-to-string
+             (format "%s -input cmdlist"
+                     emacspeak-m-player-program))
+            "\n" 'omit-nulls)))
+      (setq emacspeak-m-player-command-list
+            (loop  for c in commands
+                   collect
+                   (split-string c " " 'omit-nulls)))))))
 
 ;;}}}
 ;;{{{ commands 
 
-(defsubst emacspeak-m-player-dispatch (command)
-  "Dispatch command to m-player."
-  (declare (special emacspeak-m-player-process))
-  (save-excursion
-    (set-buffer (process-buffer emacspeak-m-player-process))
-    (erase-buffer))
-  (process-send-string
-   emacspeak-m-player-process
-   (format "%s\n" command)))
+(defsubst emacspeak-m-player-current-filename ()
+  "Return filename of currently playing track."
+  (second
+   (split-string
+    (emacspeak-m-player-dispatch "get_file_name\n")
+    "=")))
 
 (defun emacspeak-m-player-scale-speed (factor)
   "Scale speed by specified factor."
   (interactive "nFactor:")
   (emacspeak-m-player-dispatch
    (format "speed_mult %f" factor)))
+
 (defun emacspeak-m-player-slower ()
   "Slow down playback."
   (interactive)
   (emacspeak-m-player-scale-speed 0.9091))
+
 (defun emacspeak-m-player-faster ()
   "Speed up  playback."
   (interactive)
@@ -263,7 +458,7 @@ The player is placed in a buffer in emacspeak-m-player-mode."
   (emacspeak-m-player-dispatch
    "speed_set 1.0"))
 
-(defun emacspeak-m-player-play-tree-step (step)
+(defun emacspeak-m-player-play-tracks-jump (step)
   "Move within the play tree."
   (interactive"nSkip Tracks:")
   (emacspeak-m-player-dispatch
@@ -272,12 +467,12 @@ The player is placed in a buffer in emacspeak-m-player-mode."
 (defun emacspeak-m-player-previous-track ()
   "Move to previous track."
   (interactive)
-  (emacspeak-m-player-play-tree-step -1))
+  (emacspeak-m-player-play-tracks-jump -1))
 
 (defun emacspeak-m-player-next-track ()
   "Move to next track."
   (interactive)
-  (emacspeak-m-player-play-tree-step 1))
+  (emacspeak-m-player-play-tracks-jump 1))
 
 (defun emacspeak-m-player-play-tree-up (step)
   "Move within the play tree."
@@ -354,20 +549,28 @@ The player is placed in a buffer in emacspeak-m-player-mode."
 (defun emacspeak-m-player-pause ()
   "Pause or unpause media player."
   (interactive)
-  (emacspeak-m-player-dispatch
-   "pause"))
+  (emacspeak-m-player-current-info)
+  (emacspeak-m-player-dispatch "pause"))
 
 (defun emacspeak-m-player-quit ()
   "Quit media player."
   (interactive)
-  (when (eq (process-status emacspeak-m-player-process) 'run)
-    (let ((buffer (process-buffer emacspeak-m-player-process)))
-    (emacspeak-m-player-dispatch "quit")
-    (and (buffer-live-p buffer)
-         (kill-buffer buffer))))
-  (unless (eq (process-status emacspeak-m-player-process) 'exit)
-    (delete-process  emacspeak-m-player-process))
-  (emacspeak-speak-mode-line))
+  (declare (special emacspeak-m-player-info-ring
+                    emacspeak-m-player-info-cache))
+  (let ((kill-buffer-query-functions nil))
+    (when (eq (process-status emacspeak-m-player-process) 'run)
+      (let ((buffer (process-buffer emacspeak-m-player-process)))
+        (emacspeak-m-player-current-info)
+        (when emacspeak-m-player-info-cache
+          (ring-insert emacspeak-m-player-info-ring emacspeak-m-player-info-cache))
+        (emacspeak-m-player-dispatch "quit")
+        (emacspeak-auditory-icon 'close-object)
+        (and (buffer-live-p buffer)
+             (kill-buffer buffer))))
+    (unless (eq (process-status emacspeak-m-player-process) 'exit)
+      (delete-process  emacspeak-m-player-process))
+    (emacspeak-speak-mode-line)))
+
 ;;;###autoload
 (defun emacspeak-m-player-volume-up ()
   "Increase volume."
@@ -379,22 +582,51 @@ The player is placed in a buffer in emacspeak-m-player-mode."
   "Decrease volume."
   (interactive)
   (emacspeak-m-player-dispatch "volume -1"))
-;;;###autload
+;;;###autoload
 (defun emacspeak-m-player-volume-change (offset)
   "Change volume.
 A value of <number> changes volume by specified offset.
 A string of the form `<number> 1' sets volume as an absolute."
   (interactive"sChange Volume By:")
   (emacspeak-m-player-dispatch
-   (format "volume %s"
-           offset)))
-   
+   (format "volume %s" offset)))
 
+;;;###autoload
+(defun emacspeak-m-player-balance ()
+  "Set left/right balance."
+  (interactive)
+  (emacspeak-m-player-dispatch
+   (format "balance %s"
+           (read-from-minibuffer "Balance: "))))
+
+;;;###autoload
+(defun emacspeak-m-player-slave-command ()
+  "Dispatch slave command read from minibuffer."
+  (interactive)
+  (with-current-buffer (process-buffer emacspeak-m-player-process)
+    (let* ((command (completing-read "Slave Command: " (emacspeak-m-player-command-list)))
+           (args
+            (when (cdr (assoc command emacspeak-m-player-command-list))
+              (read-from-minibuffer
+               (mapconcat #'identity
+                          (cdr (assoc command emacspeak-m-player-command-list))
+                          " ")))))
+      (message 
+       (emacspeak-m-player-dispatch (format "%s %s" command args))))))
+
+;;;###autoload
+(defun emacspeak-m-player-get-length ()
+  "Display length of track in seconds."
+  (interactive)
+  (emacspeak-m-player-dispatch "get_time_length")
+  (accept-process-output))
 (defun emacspeak-m-player-display-position ()
   "Display current position in track and its length."
   (interactive)
   (emacspeak-m-player-dispatch
-   "get_percent_pos\nget_time_length\n"))
+   "get_time_pos\nget_percent_pos\nget_time_length\nget_file_name\n")
+  (when (ems-interactive-p )
+    (emacspeak-auditory-icon 'select-object)))
 
 (defun emacspeak-m-player-load-file(f)
   "Load specified file."
@@ -504,24 +736,26 @@ The Mplayer equalizer provides 10 bands, G0 -- G9, see the
         emacspeak-m-player-default-options)
   (message "Reset options."))
 
-  
 ;;}}}
 ;;{{{ keys
+
 (declaim (special emacspeak-m-player-mode-map))
 (loop for k in 
       '(
-        ("\C-m" emacspeak-m-player)
-        (":" emacspeak-m-player)
+        ("\C-m" emacspeak-m-player-load)
         ("e" emacspeak-m-player-add-equalizer)
-	("o" other-window)
-        ("O" emacspeak-m-player-customize-options)
+        ("o" emacspeak-m-player-customize-options)
         ("O" emacspeak-m-player-reset-options)
         ("f" emacspeak-m-player-add-filter)
-        ("b" bury-buffer)
-        ("l" emacspeak-m-player-load-file)
-        ("L" emacspeak-m-player-load-playlist)
+        ("b" emacspeak-m-player-balance)
+        ("l" emacspeak-m-player-get-length)
+        ("L" emacspeak-m-player-load-file)
+        ("\M-l" emacspeak-m-player-load-playlist)
         ("?" emacspeak-m-player-display-position)
-        ("t" emacspeak-m-player-play-tree-step)
+        ("w" emacspeak-m-player-speak-current-info)
+        ("m" emacspeak-m-player-speak-mode-line)
+        ("\C-em" emacspeak-m-player-speak-mode-line)
+        ("t" emacspeak-m-player-play-tracks-jump)
         ("p" emacspeak-m-player-previous-track)
         ("n" emacspeak-m-player-next-track)
         ("," emacspeak-m-player-backward-10s)
@@ -536,6 +770,7 @@ The Mplayer equalizer provides 10 bands, G0 -- G9, see the
         ([next] emacspeak-m-player-forward-10min)
         ([home] emacspeak-m-player-beginning-of-track)
         ([end] emacspeak-m-player-end-of-track)
+        ("k"emacspeak-m-player-bind-accelerator)
         ("s" emacspeak-m-player-scale-speed)
         ("[" emacspeak-m-player-slower)
         ("]" emacspeak-m-player-faster)
@@ -545,22 +780,65 @@ The Mplayer equalizer provides 10 bands, G0 -- G9, see the
         ("r" emacspeak-m-player-seek-relative)
         ("g" emacspeak-m-player-seek-absolute)
         (" " emacspeak-m-player-pause)
-        ("q" emacspeak-m-player-quit)
+        ("q" bury-buffer)
         ("v" emacspeak-m-player-volume-change)
+        ("c" emacspeak-m-player-slave-command)
         ("-" emacspeak-m-player-volume-down)
         ("=" emacspeak-m-player-volume-up)
         ("+" emacspeak-m-player-volume-up)
+        ("Q" emacspeak-m-player-quit)
         )
       do
       (emacspeak-keymap-update  emacspeak-m-player-mode-map k))
 
+;;}}}
+;;{{{ YouTube Player
+
+(defcustom emacspeak-m-player-youtube-dl
+  "/usr/local/bin/youtube-dl"
+  "YouTube download tool"
+  :type 'string
+  :group 'emacspeak-m-player)
+
+;;;###autoload
+
+(defun emacspeak-m-player-youtube-player (url)
+  "Use youtube-dl and mplayer to stream YouTube content."
+  (interactive
+   (list
+    (emacspeak-webutils-read-this-url)))
+  (declare (special emacspeak-m-player-youtube-dl))
+  (unless (file-executable-p emacspeak-m-player-youtube-dl)
+    (error "Please install youtube-dl first."))
+  (emacspeak-m-player
+   (substring
+    (shell-command-to-string
+     (format "%s -g '%s'"
+             emacspeak-m-player-youtube-dl
+             url))
+    0
+    -1)))
+
+;;}}}
+;;{{{ pause/resume if needed
+
+;;;###autoload
+(defun emacspeak-m-player-pause-or-resume ()
+  "Pause/resume if m-player is running. For use  in
+emacspeak-silence-hook."
+  (declare (special emacspeak-m-player-process))
+  (when (and emacspeak-m-player-process
+             (eq 'run (process-status emacspeak-m-player-process)))
+    (emacspeak-m-player-pause)))
+(add-hook 'emacspeak-silence-hook 'emacspeak-m-player-pause-or-resume)
+
 ;;}}}
 (provide 'emacspeak-m-player)
 ;;{{{ end of file 
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
