@@ -1,6 +1,6 @@
 ;;; emacspeak-newsticker.el --- Speech-enable newsticker
-;;; $Id: emacspeak-newsticker.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-newsticker.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for NEWSTICKER 
 ;;; Keywords: Emacspeak, newsticker 
 ;;{{{  LCD Archive entry:
@@ -8,15 +8,15 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
+;;;  $Revision: 4074 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -50,27 +50,19 @@
 
 ;;; Code:
 (require 'emacspeak-preamble)
-(require 'backquote)
 ;;}}}
 ;;{{{ define personalities 
-(def-voice-font emacspeak-newsticker-new-item-personality
-  voice-brighten
-  'newsticker-new-item-face
-  "Personality for new items.")
-(def-voice-font emacspeak-newsticker-old-item-personality
-  voice-monotone
-  'newsticker-old-item-face
-  "Personality for old items.")
-
-(def-voice-font emacspeak-newsticker-feed-personality
-  voice-animate
-  'newsticker-feed-face
-  "Personality for news feed.")
+(voice-setup-add-map
+ '(
+   (newsticker-new-item-face voice-brighten)
+   (newsticker-old-item-face voice-monotone)
+   (newsticker-feed-face voice-animate)
+   ))
 ;;}}}
 ;;{{{ advice functions
 
 (defadvice newsticker--cache-remove (around emacspeak pre act
-					    comp)
+                                            comp)
   "Silence messages temporarily to avoid chatter."
   (let ((emacspeak-speak-messages nil))
     ad-do-it
@@ -98,15 +90,16 @@
 (loop for f in
       '(newsticker-next-item newsticker-previous-item
                              newsticker-next-new-item
-			     newsticker-previous-new-item)
+                             newsticker-previous-new-item
+                             newsticker-previous-feed newsticker-next-feed
+                             )
       do
       (eval
-       (`
-        (defadvice (, f) (after emacspeak pre act comp)
+       `(defadvice ,f (after emacspeak pre act comp)
           "Provide spoken feedback."
-          (when (interactive-p)
-	    (emacspeak-auditory-icon 'large-movement)
-	    (emacspeak-newsticker-summarize-item))))))
+          (when (ems-interactive-p )
+            (emacspeak-auditory-icon 'large-movement)
+            (emacspeak-newsticker-summarize-item)))))
 
 ;;}}}
 ;;{{{  silence auto activity
@@ -118,16 +111,16 @@
       do
       (eval
        `(defadvice  ,f (around emacspeak pre act comp)
-	  "Silence messages."
-	  (let ((emacspeak-speak-messages nil))
-	    ad-do-it))))
+          "Silence messages."
+          (let ((emacspeak-speak-messages nil))
+            ad-do-it))))
 ;;}}}
 (provide 'emacspeak-newsticker)
 ;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
