@@ -1,5 +1,5 @@
 ;;; emacspeak-ocr.el --- ocr Front-end for emacspeak desktop
-;;; $Id: emacspeak-ocr.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-ocr.el 8262 2013-03-28 15:52:57Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak front-end for OCR
 ;;; Keywords: Emacspeak, ocr
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4448 $ |
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -76,19 +76,19 @@ OCR engine for optical character recognition."
   :group 'emacspeak-ocr)
 
 (defcustom emacspeak-ocr-scan-image-options 
-  "--format tiff --resolution 400"
+  "--resolution 300 --mode lineart --format=tiff"
   "Command line options to pass to image acquisition program."
   :type 'string 
   :group 'emacspeak-ocr)
 
-(defcustom emacspeak-ocr-compress-image "tiffcp"
+(defcustom emacspeak-ocr-compress-image nil
   "Command used to compress the scanned tiff file."
   :type '(choice
           (const :tag "None" nil)
           (string :tag "Command"))
   :group 'emacspeak-ocr)
 
-(defcustom emacspeak-ocr-image-extension ".tiff"
+(defcustom emacspeak-ocr-image-extension ".tif"
   "Filename extension used for acquired image."
   :type 'string
   :group 'emacspeak-ocr)
@@ -261,7 +261,7 @@ The Emacspeak OCR front-end is launched by command
 emacspeak-ocr bound to \\[emacspeak-ocr].  
 
 This command switches to a special buffer that has OCR
-commands bounds to single keystrokes-- see the ke-binding
+commands bounds to single keystrokes-- see the key-binding
 list at the end of this description.  Use Emacs online help
 facility to look up help on these commands.
 
@@ -287,9 +287,7 @@ See \\{emacspeak-ocr-mode-map}.
           emacspeak-ocr-last-page-number 0
           emacspeak-ocr-page-positions
           (make-vector 25 nil))
-    (emacspeak-ocr-update-mode-line)
-    (emacspeak-keymap-remove-emacspeak-edit-commands
-     emacspeak-ocr-mode-map)))
+    (emacspeak-ocr-update-mode-line)))
 
 (define-key emacspeak-ocr-mode-map "?" 'describe-mode)
 (define-key emacspeak-ocr-mode-map "c" 'emacspeak-ocr-customize)
@@ -299,6 +297,7 @@ See \\{emacspeak-ocr-mode-map}.
 (define-key emacspeak-ocr-mode-map "i" 'emacspeak-ocr-scan-image)
 (define-key emacspeak-ocr-mode-map "j" 'emacspeak-ocr-scan-photo)
 (define-key emacspeak-ocr-mode-map "o" 'emacspeak-ocr-recognize-image)
+(define-key emacspeak-ocr-mode-map "f" 'emacspeak-ocr-flipflop-and-recognize-image)
 (define-key emacspeak-ocr-mode-map "n" 'emacspeak-ocr-name-document)
 (define-key emacspeak-ocr-mode-map "d" 'emacspeak-ocr-open-working-directory)
 (define-key emacspeak-ocr-mode-map "[" 'emacspeak-ocr-backward-page)
@@ -414,7 +413,7 @@ Pick a short but meaningful name."
         (when emacspeak-ocr-keep-uncompressed-image
           (format "rm -f temp%s"
                   emacspeak-ocr-image-extension))))
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (setq emacspeak-ocr-last-page-number
               (1+ emacspeak-ocr-last-page-number)))
       (message "Acquired  image to file %s"
@@ -451,7 +450,7 @@ The scanned image is converted to JPEG."
                   pnm)
         (format "rm -f temp.pnm"))))
     (when (and metadata
-               (interactive-p))
+               (ems-interactive-p ))
       (setq metadata
             (read-from-minibuffer "Enter picture description: "))
       (let ((tempfile (format "temp%s.jpg" (gensym))))
@@ -552,6 +551,54 @@ Prompts for image file if file corresponding to the expected
                           'emacspeak-ocr-process-sentinel)
     (message "Launched OCR engine.")))
 
+(defvar emacspeak-ocr-image-flipflop
+  (executable-find "mogrify")
+  "Executable used to transform images.")
+
+(defun emacspeak-ocr-flipflop-and-recognize-image ()
+  "Run OCR engine on current image after flip-flopping it.
+Useful if you've scanned a page upside down and are using an engine that does not automatically flip the image for you.
+You need the imagemagik family of tools --- we use mogrify to transform the image.
+Prompts for image file if file corresponding to the expected
+`current page' is not found."
+  (interactive)
+  (declare (special emacspeak-ocr-engine
+                    emacspeak-ocr-image-flipflop
+                    emacspeak-ocr-engine-options
+                    emacspeak-ocr-process
+                    emacspeak-ocr-last-page-number
+                    emacspeak-ocr-page-positions
+                    emacspeak-ocr-image-extension))
+  (let ((inhibit-read-only t)
+        (image-name
+         (if (file-exists-p (emacspeak-ocr-get-image-name emacspeak-ocr-image-extension))
+             (emacspeak-ocr-get-image-name emacspeak-ocr-image-extension)
+           (expand-file-name 
+            (read-file-name "Image file to recognize: ")))))
+    (goto-char (point-max))
+    (emacspeak-auditory-icon 'select-object)
+    (setq emacspeak-ocr-last-page-number
+          (1+ emacspeak-ocr-last-page-number))
+    (aset emacspeak-ocr-page-positions
+          emacspeak-ocr-last-page-number
+          (+ 3 (point)))
+    (insert
+     (format "\n%c\nPage %s\n" 12
+             emacspeak-ocr-last-page-number))
+    (shell-command
+     (format "%s -flip -flop %s"
+             emacspeak-ocr-image-flipflop image-name))
+    (setq emacspeak-ocr-process
+          (apply 'start-process 
+                 "ocr"
+                 (current-buffer)
+                 emacspeak-ocr-engine
+                 image-name
+                 emacspeak-ocr-engine-options))
+    (set-process-sentinel emacspeak-ocr-process
+                          'emacspeak-ocr-process-sentinel)
+    (message "Launched OCR engine.")))
+
 ;;;###autoload
 (defun emacspeak-ocr-scan-and-recognize ()
   "Scan in a page and run OCR engine on it.
@@ -699,7 +746,7 @@ Setting persists for current Emacs session."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
