@@ -1,5 +1,5 @@
 ;;; emacspeak-pronounce.el --- Implements Emacspeak pronunciation dictionaries
-;;; $Id: emacspeak-pronounce.el 5261 2007-09-07 10:25:25Z tv.raman.tv $
+;;; $Id: emacspeak-pronounce.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak pronunciation dictionaries
 ;;; Keywords:emacspeak, audio interface to emacs customized pronunciation
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-09-07 03:25:25 -0700 (Fri, 07 Sep 2007) $ |
+;;; $Date: 2008-02-19 16:55:48 -0800 (Tue, 19 Feb 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
@@ -64,9 +64,8 @@
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
-(eval-when-compile (require 'wid-edit)
-                   (require 'calendar)
-                   (require 'emacspeak-personality))
+(eval-when-compile (require 'calendar))
+
 (require 'voice-setup)
 (require 'thingatpt)
 (eval-when (compile)
@@ -102,6 +101,8 @@ Values are alists containing string.pronunciation pairs.")
   (when (stringp key)
     (setq key (intern key )))
   (gethash key emacspeak-pronounce-dictionaries))
+
+;;;###autoload
 (defun emacspeak-pronounce-add-dictionary-entry  (key string pronunciation)
   "Add dictionary entry.
 This adds pronunciation pair
@@ -109,7 +110,7 @@ STRING.PRONUNCIATION to the   dictionary.
 Argument KEY specifies a dictionary key e.g. directory, mode etc."
   (declare (special emacspeak-pronounce-dictionaries ))
   (let* ((dict  (emacspeak-pronounce-get-dictionary key))
-	 (entry (and dict (assoc string dict))))
+         (entry (and dict (assoc string dict))))
     (cond
      ((and dict entry)
       (setcdr entry pronunciation))
@@ -118,7 +119,7 @@ Argument KEY specifies a dictionary key e.g. directory, mode etc."
       (emacspeak-pronounce-set-dictionary key dict ))
      (t
       (emacspeak-pronounce-set-dictionary key
-					  (list (cons string pronunciation)))))))
+                                          (list (cons string pronunciation)))))))
 
 (defun emacspeak-pronounce-remove-buffer-local-dictionary-entry (string)
   "Remove pronunciation entry."
@@ -127,7 +128,6 @@ Argument KEY specifies a dictionary key e.g. directory, mode etc."
     (remhash    string
                 emacspeak-pronounce-pronunciation-table)))
 
-  
 (defun emacspeak-pronounce-add-buffer-local-dictionary-entry  (string pronunciation)
   "Add specified pronunciation for current buffer.
 Arguments STRING and PRONUNCIATION specify what is being defined."
@@ -144,7 +144,7 @@ Arguments STRING and PRONUNCIATION specify what is being defined."
           (emacspeak-pronounce-compose-pronunciation-table))))
   (puthash    string pronunciation
               emacspeak-pronounce-pronunciation-table)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Added  local pronunciation in buffer %s"
              (buffer-name))))
 
@@ -180,9 +180,10 @@ modes."
   (let* ((table (make-hash-table :test #'equal))
          (filename (buffer-file-name buffer))
          (directory (and filename (file-name-directory  filename)))
-         (mode  (save-excursion
-                  (set-buffer buffer)
-                  major-mode))
+         (mode
+          (save-current-buffer
+            (set-buffer buffer)
+            major-mode))
          (mode-supers (emacspeak-pronounce-get-supers mode))
          (file-alist (and filename (emacspeak-pronounce-get-dictionary filename)))
          (dir-alist (and directory (emacspeak-pronounce-get-dictionary directory)))
@@ -215,7 +216,8 @@ modes."
 
 ;;; c++ mode inherits from C mode
 (emacspeak-pronounce-add-super  'c-mode 'c++-mode)
-
+;;; shell inherits from comint:
+(emacspeak-pronounce-add-super 'comint-mode 'shell-mode)
 ;;; latex-mode and latex2e-mode inherit from plain-tex-mode
 
 (emacspeak-pronounce-add-super  'plain-tex-mode 'latex-mode)
@@ -226,6 +228,12 @@ modes."
 (emacspeak-pronounce-add-super 'text-mode 'plain-tex-mode)
 ;;;xsl inherits from xml
 (emacspeak-pronounce-add-super 'xml-mode 'xsl-mode)
+
+;;; VM, w3m, w3
+(emacspeak-pronounce-add-super 'text-mode 'w3m-mode)
+(emacspeak-pronounce-add-super 'text-mode 'w3-mode)
+(emacspeak-pronounce-add-super 'text-mode 'vm-presentation-mode)
+
 ;;}}}
 ;;{{{  Composing and applying dictionaries:
 
@@ -281,7 +289,7 @@ applied."
                     (file-name-nondirectory emacspeak-pronounce-dictionaries-file )))
          (buffer nil ))
     (setq buffer (find-file-noselect filename))
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (auto-fill-mode nil)
       (erase-buffer)
@@ -342,14 +350,15 @@ Optional argument FILENAME specifies the dictionary file."
   (interactive)
   (declare (special emacspeak-pronounce-yank-word-point
                     emacspeak-pronounce-current-buffer))
-  (let ((string (save-excursion
-                  (set-buffer emacspeak-pronounce-current-buffer)
-                  (goto-char emacspeak-pronounce-yank-word-point)
-                  (buffer-substring-no-properties
-                   (point)
-                   (save-excursion
-                     (forward-word 1)
-                     (setq emacspeak-pronounce-yank-word-point (point)))))))
+  (let ((string
+         (save-current-buffer
+           (set-buffer emacspeak-pronounce-current-buffer)
+           (goto-char emacspeak-pronounce-yank-word-point)
+           (buffer-substring-no-properties
+            (point)
+            (save-excursion
+              (forward-word 1)
+              (setq emacspeak-pronounce-yank-word-point (point)))))))
     (insert string)
     (dtk-speak string)))
 
@@ -398,7 +407,7 @@ Returns a pair of the form (key-type . key)."
           (completing-read
            "Define pronunciation that is specific to: "
            emacspeak-pronounce-pronunciation-keys nil t ) )))
-    (when (interactive-p)               ;cleanup minibuffer history
+    (when (ems-interactive-p )               ;cleanup minibuffer history
       (pop minibuffer-history))
     (cond
      ((eq key-type 'buffer)
@@ -532,7 +541,7 @@ Activates pronunciation dictionaries if not already active."
    (t                                   ;turn it on
     (setq emacspeak-pronounce-pronunciation-table
           (emacspeak-pronounce-compose-pronunciation-table))))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'on)
     (message
      "Refreshed pronunciations for this buffer")))
@@ -542,17 +551,18 @@ Activates pronunciation dictionaries if not already active."
 
 (defcustom emacspeak-pronounce-internet-smileys-pronunciations 
   '((":-)" . " smile ")
+    (";)" . " half-wink ")
     (":)" . " grin ")
     (":-(" . " frown ") 
     (":(" . " sigh ")
     (":-I" .  " shrug ")
     (":->" . " sarcastic smile ")
     (">:->" . " devillish smile ")
-    (">;->" . " lews smile ")
+    (">;->" . " lewd smile ")
     (";-)" . " wink "))
   "Pronunciation dictionary used in all instant messenger and IRC chat
 modes.
-See http://oz.uc.edu/~solkode/smileys.html for a full list."
+See http://www.charm.net/~kmarsh/smiley.html. "
   :link '(url-link :tag "Smileys Dictionary "
                    "http://oz.uc.edu/~solkode/smileys.html")
   :type '(repeat
@@ -609,7 +619,7 @@ for the specified mode."
 ;;{{{  dictionary editor 
 
 (defun emacspeak-pronounce-edit-generate-pronunciation-editor  (key)
-  "Generate a widget-enabled edit buffer for editting the
+  "Generate a widget-enabled edit buffer for editing the
 pronunciation dictionary for the specified key."
   (declare (special emacspeak-pronounce-dictionaries))
   (unless emacspeak-pronounce-pronunciation-table
@@ -621,12 +631,11 @@ pronunciation dictionary for the specified key."
         (inhibit-read-only t))
     (when (get-buffer buffer-name) (kill-buffer buffer-name))
     (setq buffer (get-buffer-create buffer-name))
-    (save-excursion
+    (save-current-buffer
       (set-buffer  buffer)
-      (voice-lock-mode t)
       (widget-insert "\n")
       (widget-insert
-       (format "Editting pronunciation dictionary for %s\n\n" key))
+       (format "Editing pronunciation dictionary for %s\n\n" key))
       (widget-create 'repeat
                      :help-echo "Edit Pronunciations"
                      :tag "Pronunciations"
@@ -739,7 +748,7 @@ specified pronunciation dictionary key."
                 (+ 1900 (third fields)))
                (t (third fields)))))
        'personality voice-punctuations-some))))
-                   
+
 ;;}}}
 ;;{{{ phone numbers
 
@@ -767,6 +776,17 @@ specified pronunciation dictionary key."
      (format "%s %s, %s. "
              area-code prefix-code suffix-code)
      'personality voice-punctuations-some)))
+(defvar emacspeak-pronounce-sha-checksum-pattern 
+  "[0-9a-f]\\{40\\}"
+  "Regexp pattern that matches 40-digit SHA  check-sum.")
+
+(defun emacspeak-pronounce-sha-checksum (sha)
+  "Return pronunciation for 40 digit SHA hash. Useful for working with Git among other things."
+  (when
+      (and
+       (= 40 (length sha))
+       (string-match "[0-9a-f]+" sha))
+    (format "sha: %s " (substring sha 0 5))))
 
 ;;}}}
 
@@ -777,7 +797,7 @@ specified pronunciation dictionary key."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
