@@ -1,23 +1,23 @@
 ;;; emacspeak-remote.el --- Enables running remote Emacspeak sessions
-;;; $Id: emacspeak-remote.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-remote.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description: Auditory interface to remote speech server
 ;;; Keywords: Emacspeak, Speak, Spoken Output, remote server
-;;{{{  LCD Archive entry: 
+;;{{{  LCD Archive entry:
 
 ;;; LCD Archive Entry:
-;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
+;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2008-07-25 16:05:19 -0700 (Fri, 25 Jul 2008) $ |
+;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2004, T. V. Raman
-;;; All Rights Reserved. 
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
 ;;;
@@ -53,7 +53,7 @@
 (defgroup emacspeak-remote nil
   "Emacspeak remote group."
   :group 'emacspeak-remote)
-
+;;;###autoload
 (defcustom emacspeak-remote-hooks nil
   "List of hook functions that are run after
 emacspeak is set to run as a remote application.
@@ -84,41 +84,35 @@ a local  Emacspeak terminal buffer.")
 (add-hook 'emacspeak-remote-hooks 'emacspeak-remote-default-hook)
 ;;}}}
 ;;{{{ Helper for guessing host where we came from:
-
-;;; To get this to work,
-;;; put the following into your .login (csh)
-;;; or translate it to bash syntax and place it in your
-;;; .profile:
-
-					;/bin/rm -f  ~/.emacspeak/.current-remote-hostname
-					;set remote=`who am i`
-					;if ( $;remote == 6 ) then
-					;eval 	set remote=$remote[6]
-					;echo -n  "$remote" > ~/.emacspeak/.current-remote-hostname
-					;endif
+;;; see etc/last-log.pl
 
 ;;;Remote hostname guessing
 ;;;
 (declaim (special emacspeak-resource-directory))
 
 (defvar emacspeak-remote-hostname
-  (concat emacspeak-resource-directory
-          "/"
-          ".current-remote-hostname")
+  (expand-file-name  ".current-remote-hostname"
+                     emacspeak-resource-directory)
   "Filename containing the name of the host we connected from")
 
+;;;###autoload
+(defun emacspeak-remote-edit-current-remote-hostname  ()
+  "Interactively set up where we came from.
+Value is persisted for use with ssh servers."
+  (interactive)
+  (declare (special emacspeak-remote-hostname))
+  (when (file-exists-p   emacspeak-remote-hostname )
+    (find-file emacspeak-remote-hostname)))
+;;; Todo: parse out hostname if the file has user@host:port
 (defun emacspeak-remote-get-current-remote-hostname  ()
   "Return the name of the remote hostname from where we connected if known"
   (declare (special emacspeak-remote-hostname))
   (when (file-exists-p   emacspeak-remote-hostname )
-    (let ((buffer (find-file-noselect
-                   emacspeak-remote-hostname))
+    (let ((buffer (find-file-noselect emacspeak-remote-hostname))
           (result nil))
       (save-excursion
         (set-buffer buffer)
-        (setq result (buffer-substring
-                      (point-min)
-                      (1- (point-max)))))
+        (setq result (buffer-substring (point-min) (1- (point-max)))))
       (kill-buffer buffer )
       result)))
 
@@ -137,93 +131,121 @@ the host we just logged in from."
   "2222"
   "Default used when prompting for a port to connect to.")
 
-(defvar emacspeak-remote-use-telnet-to-connect nil
-  "*If set to t, then use a telnet subprocess
-to connect to the remote host that is running the speech
-server. Default is to use Emacs' built-in open-network-stream.")
+;;;###autoload
+
 ;;;###autoload
 (defun emacspeak-remote-quick-connect-to-server()
   "Connect to remote server.
-Does not prompt for host or port, but quietly uses the
-guesses that appear as defaults when prompting.
-Use this once you are sure the guesses are usually correct."
+Does not prompt for host or port, but quietly uses the guesses
+that appear as defaults when prompting. Use this once you are
+sure the guesses are usually correct."
   (interactive)
   (emacspeak-remote-connect-to-server
    (emacspeak-remote-get-current-remote-hostname)
    (string-to-number  emacspeak-remote-default-port-to-connect)))
 
 ;;;###autoload
-(defun emacspeak-remote-ssh-to-server(login)
+(defun emacspeak-remote-home()
+  "Open ssh session to where we came from.
+Uses value returned by `emacspeak-remote-get-current-remote-hostname'."
+  (interactive)
+  (unless (require 'ssh)
+    (error "You do not have module ssh.el installed."))
+  (let
+      ((spec (emacspeak-remote-get-current-remote-hostname))
+       fields host port user)
+    (setq fields (split-string spec "[@:]"))
+    (setq
+     user  (first fields)
+     host (second fields)
+     port (third fields))
+    (ssh
+     (format "%s -p %s -l %s"
+             host port user)
+     (format "Remote-%s"
+             host))))
+
+;;;###autoload
+(defun emacspeak-remote-ssh-to-server(login host port)
   "Open ssh session to where we came from."
   (interactive
    (list
     (read-from-minibuffer "Login: "
-                          (user-login-name))))
+                          (user-login-name))
+    (read-from-minibuffer "Host: ")
+    (read-from-minibuffer "Port: "
+                          "22")))
   (unless (require 'ssh)
     (error "You do not have module ssh.el installed."))
-  (ssh  
-   (format "%s -l %s"
-           (emacspeak-remote-get-current-remote-hostname)
-           login)
+  (ssh
+   (format "%s -p %s -l %s"
+           host port login)
    "remote-ssh"))
-           
-   
+
+;;;###autoload
+(defcustom emacspeak-remote-default-ssh-server
+  nil
+  "Default ssh server to use for remote speech server."
+  :type '(choice
+          (const  :tag "Ignore" nil)
+          (string  :tag "SSH Server"))
+  :group 'emacspeak-remote)
+
+;;;###autoload
+(defun emacspeak-remote-quick-connect-via-ssh ()
+  "Connect via ssh to remote Emacspeak server.
+Server is specified via custom option `emacspeak-remote-default-ssh-server'."
+  (interactive)
+  (declare (special emacspeak-remote-default-ssh-server))
+  (when emacspeak-remote-default-ssh-server
+    (setq dtk-program emacspeak-remote-default-ssh-server)
+    (dtk-select-server emacspeak-remote-default-ssh-server)
+    (dtk-initialize)))
+
 ;;;###autoload
 (defun  emacspeak-remote-connect-to-server (host port)
-  "Connect to and start using remote speech server running on host host
-and listening on port port.  Host is the hostname of the remote
-server, typically the desktop machine.  Port is the tcp port that that
-host is listening on for speech requests."
+  "Connect to and start using remote speech server running on
+host host and listening on port port. Host is the hostname of the
+remote server, typically the desktop machine. Port is the tcp
+port that that host is listening on for speech requests."
   (interactive
-   (progn (tts-restart)
-	  (list
-	   (completing-read "Remote host: "
-			    emacspeak-eterm-remote-hosts-table ;completion table
-			    nil				;predicate
-			    nil				;must-match
-			    (emacspeak-remote-get-current-remote-hostname) ;initial input
-			    ))
-	  (read-minibuffer "Remote port: "
-			   emacspeak-remote-default-port-to-connect)))
-  (declare (special dtk-speaker-process
-                    emacspeak-remote-use-telnet-to-connect
-                    emacspeak-remote-default-port-to-connect
+   (list
+    (completing-read "Remote host: "
+                     emacspeak-eterm-remote-hosts-table ;completion table
+                     nil                ;predicate
+                     nil                ;must-match
+                     (emacspeak-remote-get-current-remote-hostname) ;initial input
+                     )
+    (read-from-minibuffer "Remote port:" dtk-local-server-port)))
+  (declare (special dtk-speaker-process dtk-program 
+                    dtk-local-server-port
                     emacspeak-eterm-remote-hosts-table))
-  (let* ((process-connection-type nil)  ;dont waste a pty
+  (let* ((dtk-program dtk-local-engine)
+         (process-connection-type nil)  ;dont waste a pty
          (old-process dtk-speaker-process)
          (new-process
-          (if emacspeak-remote-use-telnet-to-connect
-              (start-process  "remote-speaker" nil
-                              "telnet"
-                              host port)
-            (open-network-stream "remote-speaker" nil
-                                 host port))))
+          (open-network-stream "remote-speaker" nil host port)))
     (unless (intern-soft host emacspeak-eterm-remote-hosts-table)
       (emacspeak-eterm-cache-remote-host host))
+    (accept-process-output)
     (cond
      ((or (eq 'run (process-status new-process))
           (eq 'open (process-status new-process)))
       (setq dtk-speaker-process new-process)
-      (setq emacspeak-remote-default-port-to-connect
-            (format "%s" port ))
+      (setq emacspeak-remote-default-port-to-connect (format "%s" port ))
       (delete-process old-process)
       (run-hooks 'emacspeak-remote-hooks)
-      (sit-for 5)
-      (message "Connecting to server on host %s  port %s"
-               host port )
-      (sit-for 5))
-     (t (error "Failed to connect to speech server on host %s port %s"
-               host port )))))
-
-(emacspeak-fix-interactive-command-if-necessary 'emacspeak-remote-connect-to-server)
+      (emacspeak-tts-startup-hook)
+      (message "Connecting to server on host %s  port %s" host port ))
+     (t (error "Failed to connect to speech server on host %s port %s" host port )))))
 
 ;;}}}
 (provide 'emacspeak-remote )
-;;{{{ end of file 
+;;{{{ end of file
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
-;;; end: 
+;;; byte-compile-dynamic: nil
+;;; end:
 
 ;;}}}
