@@ -1,5 +1,5 @@
 ;;; emacspeak-setup.el --- Setup Emacspeak environment --loaded to start Emacspeak
-;;; $Id: emacspeak-setup.el 5377 2007-11-23 01:17:25Z tv.raman.tv $
+;;; $Id: emacspeak-setup.el 8573 2013-11-23 16:32:11Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  File for setting up and starting Emacspeak
 ;;; Keywords: Emacspeak, Setup, Spoken Output
@@ -7,7 +7,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-11-22 17:17:25 -0800 (Thu, 22 Nov 2007) $ |
+;;; $Date: 2008-06-06 19:00:23 -0700 (Fri, 06 Jun 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
@@ -15,7 +15,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -55,12 +55,6 @@
 ;;}}}
 ;;{{{  Define locations
 
-(defvar emacspeak-unibyte t
-  "Emacspeak will force emacs to unibyte unless this
-variable is set to nil.
-To use emacspeak with emacs running in multibyte mode, this
-variable should be set to nil *before*
-emacspeak is compiled or started.")
 ;;;###autoload
 (defvar emacspeak-directory
   (expand-file-name "../" (file-name-directory load-file-name))
@@ -104,60 +98,64 @@ pronunciation dictionaries are stored. ")
 
 ;;;###autoload
 (defconst emacspeak-version
-  (eval-when-compile
-    (format
-     "26.0 %s"
-     (cond
-      ((file-exists-p emacspeak-readme-file)
-       (let ((buffer (find-file-noselect emacspeak-readme-file))
-             (revision nil))
-         (save-excursion
-           (set-buffer buffer)
-           (goto-char (point-min))
-           (setq revision
-                 (format "Revision %s"
-                         (or
-                          (nth 2 (split-string
-                                  (buffer-substring-no-properties
-                                   (line-beginning-position)
-                                   (line-end-position))))
-                          "unknown"))))
-         (kill-buffer buffer)
-         revision))
-      (t ""))))
+  (format
+   "38.0 %s"
+   (cond
+    ((file-exists-p emacspeak-readme-file)
+     (let ((buffer (find-file-noselect emacspeak-readme-file))
+           (revision nil))
+       (save-current-buffer
+         (set-buffer buffer)
+         (goto-char (point-min))
+         (setq revision
+               (format "Revision %s"
+                       (or
+                        (nth 2 (split-string
+                                (buffer-substring-no-properties
+                                 (line-beginning-position)
+                                 (line-end-position))))
+                        "unknown"))))
+       (kill-buffer buffer)
+       revision))
+    (t "")))
   "Version number for Emacspeak.")
 
 ;;;###autoload
 (defconst emacspeak-codename
-  "FastDog"
+  "BigDog"
   "Code name of present release.")
 
 ;;}}}
 ;;{{{ speech rate
 
+;;;###autoload
 (defcustom outloud-default-speech-rate 50
   "Default speech rate for outloud."
   :group 'tts
   :type 'integer)
 
+;;;###autoload
+(defcustom mac-default-speech-rate 225
+  "Default speech rate for mac."
+  :group 'tts
+  :type 'integer)
+
+;;;###autoload
 (defcustom multispeech-default-speech-rate 225
   "Default speech rate for multispeech."
   :group 'tts
   :type 'integer)
-
+;;;###autoload
 (defcustom dectalk-default-speech-rate 225
   "*Default speech rate at which TTS is started. "
   :group 'tts
   :type 'integer)
-
-(defcustom espeak-default-speech-rate 170
+;;;###autoload
+(defcustom espeak-default-speech-rate 175
   "Default speech rate for eSpeak."
   :group 'tts
   :type 'integer)
 
-(defvar tts-default-speech-rate dectalk-default-speech-rate
-  "Setup on a per engine basis.")
-
 ;;}}}
 ;;{{{ Hooks
 
@@ -167,28 +165,34 @@ pronunciation dictionaries are stored. ")
 (load-library "emacspeak")
 
 (defvar dtk-startup-hook nil)
+;;;###autoload
 (defun emacspeak-tts-startup-hook ()
   "Default hook function run after TTS is started."
+  (declare (special tts-default-speech-rate))
   (tts-configure-synthesis-setup)
   (dtk-set-rate tts-default-speech-rate t)
   (dtk-interp-sync))
 
-(add-hook 'dtk-startup-hook
-          'emacspeak-tts-startup-hook)
+(add-hook 'dtk-startup-hook 'emacspeak-tts-startup-hook)
 
 (defvar emacspeak-startup-hook nil)
 (defun emacspeak-setup-header-line ()
   "Set up Emacspeak to show a default header line."
   (declare (special emacspeak-use-header-line
-                    default-header-line-format
-                    emacspeak-default-header-line-format))
+                    header-line-format
+                    emacspeak-header-line-format))
   (when emacspeak-use-header-line
-    (setq default-header-line-format
-          emacspeak-default-header-line-format)))
+    (setq header-line-format
+          emacspeak-header-line-format)))
+
+(defun emacspeak-tvr-startup-hook ()
+  "Emacspeak startup hook that I use."
+  (load-library "emacspeak-alsaplayer")
+  (load-library "emacspeak-webspace")
+  (load-library "emacspeak-dbus"))
+
 (add-hook 'emacspeak-startup-hook 'emacspeak-setup-header-line)
-          
-;;; Use (add-hook 'emacspeak-startup-hook ...)
-;;; to add your personal settings.
+(add-hook 'emacspeak-startup-hook 'emacspeak-tvr-startup-hook)
 
 ;;}}}
 (emacspeak)
