@@ -1,6 +1,6 @@
 ;;; emacspeak-sounds.el --- Defines Emacspeak auditory icons
-;;; $Id: emacspeak-sounds.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $
+;;; $Id: emacspeak-sounds.el 8395 2013-08-21 15:20:06Z tv.raman.tv $
+;;; $Author: tv.raman.tv $
 ;;; Description:  Module for adding sound cues to emacspeak
 ;;; Keywords:emacspeak, audio interface to emacs, auditory icons
 ;;{{{  LCD Archive entry:
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ |
+;;; $Date: 2007-09-01 15:30:13 -0700 (Sat, 01 Sep 2007) $ |
+;;;  $Revision: 4670 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -63,13 +63,11 @@
 ;;{{{ required modules
 
 ;;; Code:
-(require 'cl)
+(eval-when-compile (require 'cl))
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
 (eval-when (compile)
-  (require 'dtk-speak)
-  (require 'emacspeak-load-path)
-  (require 'emacspeak-aumix))
+  (require 'dtk-speak))
 
 ;;}}}
 ;;{{{  state of auditory icons
@@ -83,19 +81,21 @@ use `emacspeak-toggle-auditory-icons' bound to
 (make-variable-buffer-local 'emacspeak-use-auditory-icons)
 
 ;;}}}
-;;{{{ Record if using midi 
+;;{{{ Setup Audio 
 ;;;###autoload
-(defsubst emacspeak-using-midi-p ()
-  "Predicate to test if we are using midi."
-  (declare (special emacspeak-auditory-icon-function))
-  (or (eq emacspeak-auditory-icon-function
-          'emacspeak-play-midi-icon)
-      (eq emacspeak-auditory-icon-function 'emacspeak-queue-midi-icon)))
+(defun emacspeak-audio-setup ()
+  "Call appropriate audio environment set command."
+  (interactive)
+  (cond
+   ((executable-find "amixer")
+    (call-interactively 'amixer))
+   (t (call-interactively 'emacspeak-aumix)))
+  (emacspeak-auditory-icon 'close-object))
 
 ;;}}}
-;;{{{  Setup sound themes 
+;;{{{  Setup sound themes
 
-(defvar emacspeak-sounds-icon-list 
+(defvar emacspeak-sounds-icon-list
   '(
     alarm
     alert-user
@@ -141,7 +141,7 @@ use `emacspeak-toggle-auditory-icons' bound to
     yank-object
     yes-answer
     )
-  "List of valid auditory icon names. 
+  "List of valid auditory icon names.
 If we add new icons we should declare them here. ")
 
 (defsubst emacspeak-sounds-icon-list ()
@@ -167,7 +167,8 @@ If we add new icons we should declare them here. ")
         file-ext ))
 
 (defgroup emacspeak-sounds nil
-  "Emacspeak auditory icons.")
+  "Emacspeak auditory icons."
+  :group 'emacspeak)
 
 ;;;###autoload
 (defcustom emacspeak-sounds-default-theme
@@ -179,7 +180,9 @@ If we add new icons we should declare them here. ")
 ;;;###autoload
 (defcustom emacspeak-play-program
   (cond
-   ((getenv "EMACSPEAK_PLAY_PROGRAM"))
+   ((getenv "EMACSPEAK_PLAY_PROGRAM")
+    (getenv "EMACSPEAK_PLAY_PROGRAM"))
+   ((file-exists-p "/usr/bin/aplay") "/usr/bin/aplay")
    ((file-exists-p "/usr/bin/play") "/usr/bin/play")
    ((file-exists-p "/usr/bin/audioplay") "/usr/bin/audioplay")
    ((file-exists-p "/usr/demo/SOUND/play") "/usr/demo/SOUND/play")
@@ -188,7 +191,7 @@ If we add new icons we should declare them here. ")
   :group 'emacspeak-sounds
   :type 'string)
 
-(defvar emacspeak-sounds-current-theme 
+(defvar emacspeak-sounds-current-theme
   emacspeak-sounds-default-theme
   "Name of current theme for auditory icons.
 Do not set this by hand;
@@ -224,7 +227,7 @@ Do not set this by hand;
    (list
     (expand-file-name
      (read-directory-name "Theme: "
-			  emacspeak-sounds-directory))))
+                          emacspeak-sounds-directory))))
   (declare (special emacspeak-sounds-current-theme
                     emacspeak-sounds-themes-table))
   (setq theme (expand-file-name theme emacspeak-sounds-directory))
@@ -236,11 +239,6 @@ Do not set this by hand;
   (emacspeak-sounds-define-theme-if-necessary theme)
   (emacspeak-auditory-icon 'select-object))
 
-           
-
-               
-                      
-;;;###autoload
 (defsubst emacspeak-get-sound-filename (sound-name)
   "Retrieve name of sound file that produces  auditory icon SOUND-NAME."
   (declare (special emacspeak-sounds-themes-table
@@ -253,7 +251,7 @@ Do not set this by hand;
           emacspeak-sounds-current-theme)))
     (if  (file-exists-p f)
         f
-      emacspeak-default-sound)))  
+      emacspeak-default-sound)))
 
 ;;}}}
 ;;{{{  queue an auditory icon
@@ -275,8 +273,8 @@ Do not set this by hand;
   (when emacspeak-use-auditory-icons
     (play-sound
      (list 'sound :file
-	   (format "%s"
-		   (emacspeak-get-sound-filename sound-name ))))))
+           (format "%s"
+                   (emacspeak-get-sound-filename sound-name ))))))
 
 ;;}}}
 ;;{{{  serve an auditory icon
@@ -296,12 +294,8 @@ See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-audit
 ;;}}}
 ;;{{{  Play an icon
 
-(defcustom emacspeak-play-args ""
-  "Set this to -i  if using the play program that ships on sunos/solaris.
-Note: on sparc20's there is a sunos bug that causes the machine to crash if
-you attempt to play sound when /dev/audio is busy.
-It's imperative that you use the -i flag to play on
-sparc20's."
+(defcustom emacspeak-play-args "-n"
+  "Set this to nil if using paplay from pulseaudio."
   :type 'string
   :group 'emacspeak-sounds)
 
@@ -310,41 +304,32 @@ sparc20's."
 Sound is produced only if `emacspeak-use-auditory-icons' is true.
 See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-auditory-icons ]."
   (declare (special  emacspeak-use-auditory-icons
-                     emacspeak-play-args emacspeak-play-program))
+                     emacspeak-play-program
+                     emacspeak-play-args))
   (and emacspeak-use-auditory-icons
        (let ((process-connection-type nil))
-         (start-process
-          "play" nil emacspeak-play-program
-                                        ;emacspeak-play-args ;breaks sox
-          (emacspeak-get-sound-filename sound-name )))))
-
-;;}}}
-;;{{{  queue a midi icon
-
-(defun emacspeak-queue-midi-icon (midi-name)
-  "Queue midi icon midi-NAME."
-  (apply 'dtk-queue-note
-         (emacspeak-get-midi-note midi-name)))
-
-;;;###autoload
-(defun emacspeak-play-midi-icon (midi-name)
-  "Play midi icon midi-NAME."
-  (apply 'dtk-force-note
-         (emacspeak-get-midi-note midi-name)))
+         (condition-case err
+             (start-process
+              emacspeak-play-program nil emacspeak-play-program
+              emacspeak-play-args
+              (emacspeak-get-sound-filename sound-name)
+              "&")
+           (error
+            (message (error-message-string err)))))))
 
 ;;}}}
 ;;{{{  setup play function
 
-(defcustom emacspeak-auditory-icon-function 'emacspeak-serve-auditory-icon
+(defcustom emacspeak-auditory-icon-function 'emacspeak-play-auditory-icon
   "*Function that plays auditory icons."
   :group 'emacspeak-sounds
   :type '(choice
           (const emacspeak-play-auditory-icon)
           (const emacspeak-serve-auditory-icon)
           (const emacspeak-native-auditory-icon)
-	  (const emacspeak-queue-auditory-icon)
-          (const emacspeak-play-midi-icon)))
-;;;###autoload 
+          (const emacspeak-queue-auditory-icon)))
+
+;;;###autoload
 (defun emacspeak-auditory-icon (icon)
   "Play an auditory ICON."
   (declare (special emacspeak-auditory-icon-function
@@ -352,145 +337,6 @@ See command `emacspeak-toggle-auditory-icons' bound to \\[emacspeak-toggle-audit
   (when emacspeak-use-auditory-icons
     (funcall emacspeak-auditory-icon-function icon)))
 
-;;}}}
-;;{{{  Map names to midi
-
-(defvar emacspeak-midi-table
-  (make-hash-table )
-  "Association between symbols and midi notes.
-When producing midi icons, other modules should use names defined here.")
-
-(defvar emacspeak-default-midi-note '(100 100 .1)
-  "Default note to play if requested icon not found.")
-
-(defun emacspeak-define-midi (midi-name midi-note)
-  "Define a midi  icon named midi-NAME.
-midi-note is a list specifying
-(instrument note duration) e.g.
-(60 60 .1)
-is a .1ms note on instrument 60."
-  (declare (special emacspeak-midi-table))
-  (setf (gethash  midi-name emacspeak-midi-table) midi-note ))
-
-(defsubst emacspeak-get-midi-note (midi-name)
-  "Retrieve midi note that produces midi icon midi-name."
-  (declare (special emacspeak-midi-table emacspeak-default-midi-note))
-  (or  (gethash midi-name emacspeak-midi-table)
-       emacspeak-default-midi-note))
-
-(defsubst emacspeak-list-midi-icons ()
-  "Return the  list of midi icons that are currently defined."
-  (declare (special emacspeak-midi-table))
-  (loop for k being the hash-keys of emacspeak-midi-table
-        collect k))
-
-;;}}}
-;;{{{  Names of midi icons
-
-(emacspeak-define-midi 'close-object
-                       '(117 20 .3))  
-(emacspeak-define-midi 'open-object
-                       '(52 75 .5))
-(emacspeak-define-midi 'delete-object
-                       '(8 85 .5 ))
-(emacspeak-define-midi 'save-object
-                       '(15 50 .1 ))
-(emacspeak-define-midi 'modified-object
-                       '(13 60 .1))
-(emacspeak-define-midi 'unmodified-object
-                       '(13 40 .1))
-(emacspeak-define-midi 'mark-object
-                       '(1 60 .1))
-
-(emacspeak-define-midi 'center
-                       '(76 60 .1))
-(emacspeak-define-midi 'right
-                       '(75 60 .1))
-(emacspeak-define-midi 'left
-                       '(65 60 .1))
-(emacspeak-define-midi 'full
-                       '(9 60 .1))
-(emacspeak-define-midi 'fill-object
-                       '(90 60 .25))
-(emacspeak-define-midi 'select-object
-                       '(13 30 .25 ))
-(emacspeak-define-midi 'button
-                       '(117 80 .1))
-(emacspeak-define-midi 'news
-                       '(100 60 .5))
-(emacspeak-define-midi 'ellipses
-                       '(9 35 .1))
-(emacspeak-define-midi 'deselect-object
-                       '(1 80 .1))
-(emacspeak-define-midi 'quit
-                       '(9 25 .1))
-(emacspeak-define-midi 'task-done
-                       '(126 60 .1))
-(emacspeak-define-midi 'scroll
-                       '(122 60 .75 70))
-(emacspeak-define-midi 'help
-                       '(14 60 .5))
-(emacspeak-define-midi   'ask-question
-                         '(14 80 .5))
-(emacspeak-define-midi 'yes-answer
-                       '(112 60 .1))
-(emacspeak-define-midi 'no-answer
-                       '(112 40 .1 ))
-(emacspeak-define-midi 'ask-short-question
-                       '(112 60 .1))
-(emacspeak-define-midi 'n-answer
-                       '(112 50 .1))
-(emacspeak-define-midi 'y-answer
-                       '(112 80 .1))
-(emacspeak-define-midi 'large-movement
-                       '(97 70 .25 90))
-(emacspeak-define-midi 'yank-object
-                       '(96 60 .1))
-(emacspeak-define-midi 'search-hit
-                       '(9 80 .1))
-(emacspeak-define-midi 'search-miss
-                       '(13 60 .1))
-(emacspeak-define-midi 'warn-user
-                       '(55 60 .1))
-(emacspeak-define-midi 'progress
-                       '(9 80 .1))
-(emacspeak-define-midi 'alarm
-                       '(102 60 1))
-(emacspeak-define-midi 'alert-user
-                       '(55 75 .1))
-;; document objects
-(emacspeak-define-midi 'paragraph
-                       '(56 60 .1))
-(emacspeak-define-midi 'section
-                       '(56 65 .1))
-(emacspeak-define-midi 'item
-                       '(9 70 .1 ))
-(emacspeak-define-midi  'on
-                        '(9 35 .1))
-(emacspeak-define-midi 'off
-                       '(127 50 .5))
-(emacspeak-define-midi 'new-mail
-                       '(14 60 .5 70))
-
-;;;blank lines etc 
-
-(emacspeak-define-midi 'horizontal-rule
-                       '(9 60 .25))
-
-(emacspeak-define-midi 'decorative-rule
-                       '(9 70 .25))
-
-(emacspeak-define-midi 'unspeakable-rule
-                       '(9 80 .25))
-
-(emacspeak-define-midi 'empty-line
-                       '(9 10 .1))
-
-(emacspeak-define-midi 'blank-line
-                       '(9 20 .1))
-(emacspeak-define-midi 'window-resize
-                       '(107 20 .3))
-
 ;;}}}
 ;;{{{  toggle auditory icons
 
@@ -517,21 +363,19 @@ Optional interactive PREFIX arg toggles global value."
   (when emacspeak-use-auditory-icons
     (emacspeak-auditory-icon 'on)))
 
-(defvar emacspeak-sounds-auditory-icon-players  
-  '(
-    ("emacspeak-serve-auditory-icon" . "emacspeak-serve-auditory-icon")
-    ("emacspeak-play-auditory-icon" . "emacspeak-play-auditory-icon")
-    ("emacspeak-native-auditory-icon" . "emacspeak-native-auditory-icon")
-    ("emacspeak-play-midi-icon" . "emacspeak-play-midi-icon"))
+(defvar emacspeak-sounds-auditory-icon-players
+  '("emacspeak-serve-auditory-icon"
+    "emacspeak-play-auditory-icon"
+    "emacspeak-native-auditory-icon")
   "Table of auditory icon players used  when selecting a player.")
 
 (defun emacspeak-select-auditory-icon-player ()
   "Pick a player for producing auditory icons."
   (declare (special emacspeak-sounds-auditory-icon-players))
-  (read 
+  (read
    (completing-read "Select auditory icon player: "
                     emacspeak-sounds-auditory-icon-players
-                    nil nil 
+                    nil nil
                     "emacspeak-")))
 ;;;###autoload
 (defun  emacspeak-set-auditory-icon-player (player)
@@ -539,22 +383,13 @@ Optional interactive PREFIX arg toggles global value."
 Recommended choices:
 
 emacspeak-serve-auditory-icon for  the wave device.
-emacspeak-queue-auditory-icon when using software TTS.
-emacspeak-play-midi-icon for midi device. "
+emacspeak-queue-auditory-icon when using software TTS."
   (interactive
    (list
     (emacspeak-select-auditory-icon-player )))
-  (declare (special emacspeak-aumix-midi-available-p
-                    emacspeak-auditory-icon-function))
-  (cond
-   ((and (not emacspeak-aumix-midi-available-p)
-         (memq player
-               '(emacspeak-play-midi-icon emacspeak-queue-midi-icon)))
-    (message
-     "Cannot use midi icons in your current environment."))
-   (t (setq emacspeak-auditory-icon-function player)))
-  (when (interactive-p)
-    (emacspeak-auditory-icon 'select-object)))
+  (declare (special emacspeak-auditory-icon-function))
+  (setq emacspeak-auditory-icon-function player))  (when (ems-interactive-p )
+                                                     (emacspeak-auditory-icon 'select-object))
 
 ;;}}}
 ;;{{{ Show all icons
@@ -563,10 +398,10 @@ emacspeak-play-midi-icon for midi device. "
   "Plays all defined icons and speaks their names."
   (interactive)
   (mapcar
-   '(lambda (f)
-      (emacspeak-auditory-icon f)
-      (dtk-speak (format "%s" f))
-      (sleep-for 2))
+   #'(lambda (f)
+       (emacspeak-auditory-icon f)
+       (dtk-speak (format "%s" f))
+       (sleep-for 2))
    (emacspeak-sounds-icon-list)))
 
 ;;}}}
@@ -599,7 +434,7 @@ audio player."
   :type '(choice
           :tag "Command to reset sound modules: "
           (const nil :tag "None")
-	  (string :tag "Command "))
+          (string :tag "Command "))
   :group 'emacspeak-sounds)
 ;;;###autoload
 (defun emacspeak-sounds-reset-sound  ()
@@ -615,7 +450,7 @@ audio player."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
