@@ -1,5 +1,5 @@
 ;;; emacspeak-speedbar.el --- Speech enable speedbar -- Tool for context-sensitive navigation
-;;; $Id: emacspeak-speedbar.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-speedbar.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to speedbar
 ;;; Keywords: Emacspeak, Speedbar
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-21 10:50:41 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2007, T. V. Raman
+;;; Copyright (c) 1995 -- 2011, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -105,14 +105,14 @@
 
 (defadvice speedbar-close-frame (after emacspeak pre act comp)
   "Cue buffer that becomes active"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice speedbar-next (around emacspeak pre act comp)
   "Provide reasonable spoken feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
       ad-do-it
       (emacspeak-speedbar-speak-line)
@@ -122,7 +122,7 @@
 (defadvice speedbar-prev (around emacspeak pre act comp)
   "Provide reasonable spoken feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((emacspeak-speak-messages nil))
       ad-do-it
       (emacspeak-speedbar-speak-line)
@@ -131,7 +131,7 @@
   ad-return-value)
 (defadvice speedbar-edit-line (after emacspeak pre act comp)
   "Speak line you jumped to"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice speedbar-tag-find (after emacspeak pre act comp)
@@ -146,13 +146,13 @@
 (defadvice speedbar-expand-line (after emacspeak pre act
                                        comp)
   "Speak the line we just expanded"
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-speedbar-speak-line)
     (emacspeak-auditory-icon 'open-object)))
 
 (defadvice speedbar-contract-line (after emacspeak pre act comp)
   "Speak the line we just contracted"
-  (when (interactive-p) 
+  (when (ems-interactive-p ) 
     (emacspeak-speedbar-speak-line)
     (emacspeak-auditory-icon 'close-object)))
 
@@ -160,7 +160,7 @@
   " Auditory icon and speech feedback indicate result of the
 action"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     ad-do-it
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speedbar-speak-line))
@@ -170,14 +170,14 @@ action"
 (defadvice speedbar-restricted-next (after emacspeak pre act
                                            comp)
   "Provide spoken feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speedbar-speak-line)))
 
 (defadvice speedbar-restricted-prev (after emacspeak pre act
                                            comp)
   "Provide spoken feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speedbar-speak-line)))
 
@@ -209,8 +209,6 @@ An automatically updating speedbar consumes resources.")
                (setq start (point))
                (end-of-line)
                (buffer-substring start (point)))))))
-  
-  
 
 (defun emacspeak-speedbar-click ()
   "Does the equivalent of the mouse click from the keyboard"
@@ -240,8 +238,7 @@ An automatically updating speedbar consumes resources.")
 ;;{{{  hooks
 (declaim (special speedbar-key-map))
 (eval-when (load)
-  
-  (emacspeak-keymap-remove-emacspeak-edit-commands speedbar-key-map))
+  )
 (defun emacspeak-speedbar-enter-hook ()
   "Actions taken when we enter the Speedbar"
   (declare (special speedbar-key-map
@@ -336,7 +333,7 @@ An automatically updating speedbar consumes resources.")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
