@@ -1,5 +1,5 @@
 ;;; emacspeak-swbuff.el --- speech-enable swbuff mode
-;;; $Id: emacspeak-swbuff.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-swbuff.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling swbuff 
 ;;; Keywords: Emacspeak, swbuff
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -52,14 +52,14 @@
 (defadvice swbuff-switch-to-previous-buffer (after emacspeak pre act
                                                    comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-current-buffer-name)))
 
 (defadvice swbuff-switch-to-next-buffer (after emacspeak pre act
                                                comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-current-buffer-name)))
 
@@ -69,7 +69,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
