@@ -1,5 +1,5 @@
 ;;; emacspeak-table-ui.el --- Emacspeak's current notion of an ideal table UI
-;;; $Id: emacspeak-table-ui.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-table-ui.el 8538 2013-11-13 16:26:16Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-26 15:46:49 -0700 (Thu, 26 Jun 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1995 by T. V. Raman
 ;;; All Rights Reserved.
 ;;;
@@ -108,7 +108,7 @@
         ("k" emacspeak-table-copy-to-clipboard)
         ("T" emacspeak-table-goto-top)
         ("B" emacspeak-table-goto-bottom)
-        ("L" emacspeak-table-goto-left)
+        ("A" emacspeak-table-goto-left)
         ("E" emacspeak-table-goto-right))
       do
       (emacspeak-keymap-update emacspeak-table-keymap binding))
@@ -208,8 +208,7 @@ specifies the filter"
   "Bring visual display in sync with internal representation"
   (declare (special emacspeak-table positions))
   (let ((row (emacspeak-table-current-row emacspeak-table))
-        (column (emacspeak-table-current-column
-                 emacspeak-table))
+        (column (emacspeak-table-current-column emacspeak-table))
         (width (frame-width)))
     (goto-char
      (or
@@ -246,7 +245,7 @@ specifies the filter"
   (interactive)
   (declare (special emacspeak-table ))
   (and (boundp 'emacspeak-table)
-       (dtk-speak (emacspeak-table-current-element emacspeak-table))))
+       (dtk-speak-and-echo (emacspeak-table-current-element emacspeak-table))))
 
 (defun emacspeak-table-speak-row-header-and-element ()
   "Speak  row header and table element"
@@ -257,14 +256,11 @@ specifies the filter"
        (let ((head (format "%s"
                            (emacspeak-table-row-header-element emacspeak-table
                                                                (emacspeak-table-current-row emacspeak-table )))))
-         (put-text-property 0 (length head)
-                            'personality
-                            emacspeak-table-row-header-personality head)
-         (dtk-speak
+         (put-text-property 0 (length head) 'face 'italic head)
+         (dtk-speak-and-echo
           (concat head
                   (format " %s"
-                          (emacspeak-table-current-element
-                           emacspeak-table)))))))
+                          (emacspeak-table-current-element emacspeak-table)))))))
 
 (defun emacspeak-table-speak-column-header-and-element ()
   "Speak  column header and table element"
@@ -276,13 +272,11 @@ specifies the filter"
                            (emacspeak-table-column-header-element emacspeak-table
                                                                   (emacspeak-table-current-column emacspeak-table )))))
          (put-text-property 0 (length head)
-                            'personality
-                            emacspeak-table-column-header-personality head)
-         (dtk-speak
+                            'face 'italic head)
+         (dtk-speak-and-echo
           (concat head
                   (format " %s"
-                          (emacspeak-table-current-element
-                           emacspeak-table)))))))
+                          (emacspeak-table-current-element emacspeak-table)))))))
 
 (defun emacspeak-table-speak-both-headers-and-element ()
   "Speak  both row and column header and table element"
@@ -298,13 +292,13 @@ specifies the filter"
                                (emacspeak-table-row-header-element emacspeak-table
                                                                    (emacspeak-table-current-row emacspeak-table )))))
          (put-text-property 0 (length row-head)
-                            'personality
-                            emacspeak-table-row-header-personality
+                            'face
+                            'italic
                             row-head)
          (put-text-property 0 (length column-head)
                             'personality
                             emacspeak-table-column-header-personality column-head)
-         (dtk-speak
+         (dtk-speak-and-echo
           (concat row-head" "  column-head
                   (format " %s"
                           (emacspeak-table-current-element
@@ -324,8 +318,7 @@ specifies the filter"
                                 emacspeak-table row))))
          (and row-head-p
               (put-text-property 0 (length row-head)
-                                 'personality
-                                 emacspeak-table-row-header-personality
+                                 'face 'italic
                                  row-head))
          (and col-head-p
               (put-text-property 0 (length column-head)
@@ -350,9 +343,8 @@ specifies the filter"
 Optional prefix arg prompts for a new filter."
   (interactive "P")
   (declare (special emacspeak-table-speak-row-filter
-                    voice-animate
-                    voice-smoothen
                     emacspeak-table))
+  (and emacspeak-table-speak-row-filter(push emacspeak-table-speak-row-filter minibuffer-default))
   (unless (and  emacspeak-table-speak-row-filter
                 (listp emacspeak-table-speak-row-filter)
                 (not prefix))
@@ -365,34 +357,53 @@ Optional prefix arg prompts for a new filter."
     (emacspeak-table-ui-filter-set
      (emacspeak-table-ui-generate-key)
      emacspeak-table-speak-row-filter))
-  (let ((voice-lock-mode t))
-    (dtk-speak
-     (mapconcat
-      #'(lambda (token)
-          (let ((value nil))
-            (cond
-             ((stringp token) token)
-             ((numberp token)
-              (setq value
-                    (emacspeak-table-get-entry-with-headers
-                     (emacspeak-table-current-row emacspeak-table)
-                     token))
-              (put-text-property 0 (length value)
-                                 'personality voice-smoothen  value)
-              value)
-             ((and (listp token)
-                   (numberp (first token))
-                   (numberp (second token )))
-              (setq value
-                    (emacspeak-table-get-entry-with-headers
-                     (first token)
-                     (second token)))
-              (put-text-property 0 (length value)
-                                 'personality voice-smoothen value)
-              value)
-             (t  (format "%s" token)))))
-      emacspeak-table-speak-row-filter
-      " "))))
+  (dtk-speak-and-echo
+   (mapconcat
+    #'(lambda (token)
+        (let ((value nil))
+          (cond
+           ((stringp token) token)
+           ((numberp token)
+            (setq value
+                  (emacspeak-table-get-entry-with-headers
+                   (emacspeak-table-current-row emacspeak-table)
+                   token))
+            (put-text-property 0 (length value)
+                               'face 'bold  value)
+            value)
+           ((and (listp token)
+                 (numberp (first token))
+                 (numberp (second token )))
+            (setq value
+                  (emacspeak-table-get-entry-with-headers
+                   (first token)
+                   (second token)))
+            (put-text-property 0 (length value)
+                               'face 'bold value)
+            value)
+           ((and
+             (symbolp (first token))
+             (fboundp  (first token)))
+            (setq value
+                  (funcall
+                   (first token)
+                   (cond
+                    ((and (= 2 (length token))
+                          (numberp (second token)))
+                     (emacspeak-table-get-entry-with-headers
+                      (emacspeak-table-current-row emacspeak-table)
+                      (second token)))
+                    ((and (= 3 (length token))
+                          (numberp (second token))
+                          (numberp (third token)))
+                     (emacspeak-table-get-entry-with-headers
+                      (second token) (third token))))))
+            (put-text-property 0 (length value)
+                               'face 'bold  value)
+            value)
+           (t  (format "%s" token)))))
+    emacspeak-table-speak-row-filter
+    " ")))
 
 (defvar emacspeak-table-speak-column-filter nil
   "Template specifying how a column is filtered before it is spoken.")
@@ -410,7 +421,7 @@ Optional prefix arg prompts for a new filter."
                 (not prefix))
     (setq emacspeak-table-speak-column-filter
           (read-minibuffer "Specify column filter as a list: " "(")))
-  (dtk-speak
+  (dtk-speak-and-echo
    (mapconcat
     #'(lambda (token)
         (cond
@@ -425,6 +436,9 @@ Optional prefix arg prompts for a new filter."
           (emacspeak-table-get-entry-with-headers
            (first token)
            (second token)))
+         ((and (symbolp (first token))
+               (fboundp  (first token)))
+          (eval token))
          (t  (format "%s" token))))
     emacspeak-table-speak-column-filter
     " ")))
@@ -465,7 +479,7 @@ Optional prefix arg prompts for a new filter."
                                                       &optional filename)
   "Prepare tabular data."
   (declare (special emacspeak-table positions ))
-  (save-excursion
+  (save-current-buffer
     (set-buffer buffer)
     (let ((i 0)
           (j 0)
@@ -536,55 +550,33 @@ the documentation on the table browser."
   (let ((fields nil)
         (this-field nil)
         (start (line-beginning-position)))
-    (save-excursion
-      (goto-char start)
-      (while (not (eolp))
-        (ems-csv-forward-field)
-        (setq this-field
-              (cond
-               ((= (preceding-char) ?\")
-                (buffer-substring-no-properties (1+ start)
-                                                (1- (point))))
-               (t (buffer-substring-no-properties start  (point)))))
-        (push this-field fields)
-        (when (= (char-after) ?,)
-          (forward-char 1))
-        (setq start (point))))
+                                        ;(save-excursion
+    (goto-char start)
+    (while (not (eolp))
+      (ems-csv-forward-field)
+      (setq this-field
+            (cond
+             ((= (preceding-char) ?\")
+              (buffer-substring-no-properties (1+ start)
+                                              (1- (point))))
+             (t (buffer-substring-no-properties start  (point)))))
+      (push this-field fields)
+      (when (= (char-after) ?,)
+        (forward-char 1))
+      (setq start (point)))
+                                        ;)
+    (when (= (preceding-char) ?,)
+      (push "" fields))
     (nreverse fields)))
-        
+
 ;;;###autoload
 (defun emacspeak-table-find-csv-file (filename)
   "Process a csv (comma separated values) file.
 The processed  data and presented using emacspeak table navigation. "
   (interactive "FFind CSV file: ")
-  (let ((scratch (get-buffer-create "*csv-scratch*"))
-        (table nil)
-        (elements nil)
-        (this-row nil)
-        (fields nil)
-        (buffer (get-buffer-create
-                 (format "*%s-table*"
-                         (file-name-nondirectory filename)))))
-    (save-excursion
-      (set-buffer scratch)
-      (fundamental-mode)
-      (setq buffer-undo-list t)
-      (erase-buffer)
-      (insert-file-contents filename)
-      (flush-lines "^ *$")
-      (goto-char (point-min))
-      (setq elements
-            (make-vector (count-lines (point-min) (point-max))
-                         nil))
-      (loop for i from 0 to (1- (length elements))
-            do
-            (setq fields (ems-csv-get-fields))
-            (aset elements i (apply 'vector fields))
-            (forward-line 1))
-      (setq table (emacspeak-table-make-table elements)))
-    (kill-buffer scratch)
-    (emacspeak-table-prepare-table-buffer table buffer filename )
-    (emacspeak-table-speak-current-element)))
+  (let  ((buffer (find-file-noselect filename)))
+    (emacspeak-table-view-csv-buffer buffer)
+    (kill-buffer buffer)))
 
 ;;;###autoload
 (defun emacspeak-table-view-csv-buffer (&optional buffer-name)
@@ -595,36 +587,31 @@ The processed  data and presented using emacspeak table navigation. "
       (setq buffer-name (current-buffer)))
   (let ((scratch (get-buffer-create "*csv-scratch*"))
         (table nil)
+        (elements nil)
+        (fields nil)
         (buffer (get-buffer-create
                  (format "*%s-table*" buffer-name))))
-    (save-excursion
+    (save-current-buffer
       (set-buffer scratch)
       (setq buffer-undo-list t)
       (erase-buffer)
       (insert-buffer buffer-name)
       (goto-char (point-min))
       (flush-lines "^ *$")
-      (insert "[\n")
-      (while (re-search-forward "^" nil t)
-        (replace-match "["))
       (goto-char (point-min))
-      (while (re-search-forward "," nil t)
-        (replace-match " "))
-      (goto-char (point-min))
-      (forward-line 1)
-      (while (and (not (eobp))
-                  (re-search-forward "$" nil t))
-        (replace-match "]")
-        (forward-line 1))
-      (goto-char (point-min))
-      (when (search-forward "[]" nil t)
-        (replace-match ""))
-      (goto-char (point-max))
-      (insert "]\n")
-      (goto-char (point-min))
-      (setq table (emacspeak-table-make-table (read scratch))))
+      (setq elements
+            (make-vector (count-lines (point-min) (point-max))
+                         nil))
+      (loop for i from 0 to (1- (length elements))
+            do
+            (setq fields (ems-csv-get-fields))
+            (aset elements i (apply 'vector fields))
+            (forward-line 1))
+      (setq table (emacspeak-table-make-table elements))  
+      )
     (kill-buffer scratch)
-    (emacspeak-table-prepare-table-buffer table buffer)))
+    (emacspeak-table-prepare-table-buffer table buffer)
+    (emacspeak-auditory-icon 'open-object)))
 
 ;;}}}
 ;;{{{ Processing a region of tabular data
@@ -655,7 +642,7 @@ the documentation on the table browser."
         (row-start 1)
         (column-start 1)
         (text (buffer-substring start end)))
-    (save-excursion
+    (save-current-buffer
       (when (= 10 (string-to-char (substring text -1)))
         (setq text (substring text 0 -1)))
       (set-buffer workspace)
@@ -668,7 +655,7 @@ the documentation on the table browser."
                     (point-min)
                     (point-max)))))
     (kill-buffer workspace)
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (let ((inhibit-read-only t))
         (erase-buffer)
@@ -742,6 +729,8 @@ browsing table elements"
   'emacspeak-table-speak-current-element
   "Function to call when automatically speaking table elements.")
 
+(make-variable-buffer-local 'emacspeak-table-speak-element)
+;;;###autoload
 (defun emacspeak-table-next-row (&optional count)
   "Move to the next row if possible"
   (interactive "p")
@@ -753,7 +742,7 @@ browsing table elements"
    (t (emacspeak-table-move-down emacspeak-table count )
       (emacspeak-table-synchronize-display)
       (funcall emacspeak-table-speak-element))))
-
+;;;###autoload
 (defun emacspeak-table-previous-row (&optional count)
   "Move to the previous row if possible"
   (interactive "p")
@@ -765,7 +754,7 @@ browsing table elements"
    (t (emacspeak-table-move-up emacspeak-table count )
       (emacspeak-table-synchronize-display)
       (funcall emacspeak-table-speak-element))))
-
+;;;###autoload
 (defun emacspeak-table-next-column (&optional count)
   "Move to the next column if possible"
   (interactive "p")
@@ -777,7 +766,7 @@ browsing table elements"
    (t(emacspeak-table-move-right emacspeak-table count )
      (emacspeak-table-synchronize-display)
      (funcall emacspeak-table-speak-element))))
-
+;;;###autoload
 (defun emacspeak-table-previous-column (&optional count)
   "Move to the previous column  if possible"
   (interactive "p")
@@ -956,7 +945,7 @@ match, makes the matching row or column current."
   (declare (special emacspeak-table ))
   (when (boundp 'emacspeak-table)
     (kill-new  (emacspeak-table-current-element emacspeak-table))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'delete-object)
       (message "Copied element to kill ring"))))
 
@@ -967,7 +956,7 @@ match, makes the matching row or column current."
   (when  (boundp 'emacspeak-table)
     (set-register register (emacspeak-table-current-element
                             emacspeak-table))
-    (when (interactive-p)
+    (when (ems-interactive-p )
       (emacspeak-auditory-icon 'select-object)
       (message "Copied element to register %c" register))))
 
@@ -1041,6 +1030,17 @@ table markup.")
                                   (emacspeak-table-markup-get-table
                                    'latex2e-mode))
 
+(emacspeak-table-markup-set-table
+ 'org-mode
+ (emacspeak-table-make-markup
+  :table-start ""
+  :table-end ""
+  :row-start "|"
+  :row-end "|\n"
+  :col-start ""
+  :col-end ""
+  :col-separator "|"))
+
 (emacspeak-table-markup-set-table 'fundamental-mode
                                   (emacspeak-table-make-markup
                                    :table-start ""
@@ -1100,8 +1100,7 @@ markup to use."
         (col-end nil)
         (col-separator nil))
     (cond
-     (read-only
-      (error "Cannot paste into read only buffer."))
+     (read-only (error "Cannot paste into read only buffer."))
      (t (setq markup  (emacspeak-table-markup-get-table mode))
         (setq table-start (emacspeak-table-markup-table-start markup)
               table-end (emacspeak-table-markup-table-end markup)
@@ -1168,7 +1167,7 @@ markup to use."
     (emacspeak-table-prepare-table-buffer
      (emacspeak-table-make-table  sorted-table)
      buffer)
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (setq emacspeak-table-speak-row-filter row-filter))
     (emacspeak-speak-mode-line)))
@@ -1222,7 +1221,7 @@ future  use."
   (let ((buffer (find-file-noselect
                  (expand-file-name file
                                    emacspeak-resource-directory))))
-    (save-excursion
+    (save-current-buffer
       (set-buffer buffer)
       (erase-buffer)
       (loop for key being the hash-keys of
