@@ -1,6 +1,6 @@
 ;;; emacspeak-tabulate.el --- Interpret tabulated information as a table
-;;; $Id: emacspeak-tabulate.el,v 23.505 2005/11/25 16:30:50 raman Exp $
-;;; $Author: raman $ 
+;;; $Id: emacspeak-tabulate.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
+;;; $Author: tv.raman.tv $ 
 ;;; Description:  Utility to help emacspeak identify tabulated information
 ;;; Keywords: Emacspeak, Tabulated Data,  Visual layout gives structure
 ;;{{{  LCD Archive entry: 
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu 
 ;;; A speech interface to Emacs |
-;;; $Date: 2005/11/25 16:30:50 $ |
-;;;  $Revision: 23.505 $ | 
+;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2004, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -128,29 +128,29 @@ Fields are assumed to be delimited by whitespace. "
             (setq interval
                   (ems-intersect-intervals (car try)
                                            (ems-make-interval first last )))
-	    (when interval (push interval  new-guesses))
-	    (pop try )
+            (when interval (push interval  new-guesses))
+            (pop try )
             (setq first nil
                   last nil
                   interval nil ))
           (end-of-line)
-	  (setf guesses (nreverse new-guesses) 
-		new-guesses nil))
+          (setf guesses (nreverse new-guesses) 
+                new-guesses nil))
         guesses ))))
 
 (defsubst ems-tabulate-process-column (tl tr br bl mark-headers start)
   (let ((header ( buffer-substring  tl tr))
         (personality-table (emacspeak-possible-voices)))
-    (emacspeak-voicify-rectangle
+    (emacspeak-voiceify-rectangle
      tl br 
      (read (completing-read
-	    (format "Personality for column %s from  %s through %s"
-		    header (- tl start) (- tr start))
-	    personality-table  nil t )))
+            (format "Personality for column %s from  %s through %s"
+                    header (- tl start) (- tr start))
+            personality-table  nil t )))
     (and mark-headers
-	 (emacspeak-put-text-property-on-rectangle
-	  tl br
-	  'field-name header ))))
+         (emacspeak-put-text-property-on-rectangle
+          tl br
+          'field-name header ))))
 
 ;;;  White space contains a list of intervals giving position of inter
 ;;;  columnal space. All calculations are done in terms of buffer
@@ -171,45 +171,44 @@ in the white-space."
         (tr nil)
         (br nil)
         (bl nil))
-    (ems-modify-buffer-safely
-     (progn
-       (message   "Detected %s rows and  %s columns."
-		  (count-lines start end)
-		  (+ 1 (length white-space )))
-       (sit-for 1.5)
-       (save-excursion
-         (goto-char end)
-         (beginning-of-line)
-         (setq bl  (point))
-         (setq tl  start )
-					;(goto-char tl )
-         (setq width   (ems-interval-start (car white-space)))
-         (setq tr (+ tl width)
-               br (+ bl width))
-         (ems-tabulate-process-column tl tr br bl mark-fields start)
-         (while white-space
-					;move to beginning of next column
-           (goto-char (+ start (ems-interval-end (car white-space))))
-           (setq tl (point))
-					; width of space between columns 
-           (setq width (- tl tr))
-           (setq bl (+ br width))
-           (setq white-space (cdr white-space))
-					;Now detect right edges of this column 
-           (cond
-            (white-space
-					;white-space holds column positions, not buffer positions
-             (setq width (- (ems-interval-start (car white-space ))
-                            (- tl start)))
-             (setq tr (+ tl width)
-                   br (+ bl width)))
-            (t (goto-char start)
-               (end-of-line)
-               (setq tr (point)
-                     br end)))
-           (ems-tabulate-process-column tl tr br bl
-					mark-fields start)))))))
-           
+    (with-silent-modifications
+      (progn
+        (message   "Detected %s rows and  %s columns."
+                   (count-lines start end)
+                   (+ 1 (length white-space )))
+        (sit-for 1.5)
+        (save-excursion
+          (goto-char end)
+          (beginning-of-line)
+          (setq bl  (point))
+          (setq tl  start )
+                                        ;(goto-char tl )
+          (setq width   (ems-interval-start (car white-space)))
+          (setq tr (+ tl width)
+                br (+ bl width))
+          (ems-tabulate-process-column tl tr br bl mark-fields start)
+          (while white-space
+                                        ;move to beginning of next column
+            (goto-char (+ start (ems-interval-end (car white-space))))
+            (setq tl (point))
+                                        ; width of space between columns 
+            (setq width (- tl tr))
+            (setq bl (+ br width))
+            (setq white-space (cdr white-space))
+                                        ;Now detect right edges of this column 
+            (cond
+             (white-space
+                                        ;white-space holds column positions, not buffer positions
+              (setq width (- (ems-interval-start (car white-space ))
+                             (- tl start)))
+              (setq tr (+ tl width)
+                    br (+ bl width)))
+             (t (goto-char start)
+                (end-of-line)
+                (setq tr (point)
+                      br end)))
+            (ems-tabulate-process-column tl tr br bl
+                                         mark-fields start)))))))
 
 ;;}}}
 ;;{{{ Parse a region of tabular data
@@ -268,7 +267,7 @@ in the white-space."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
