@@ -1,5 +1,5 @@
 ;;; emacspeak-view.el --- Speech enable View mode -- Efficient browsing of read-only content
-;;; $Id: emacspeak-view.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-view.el 8260 2013-03-28 15:21:49Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; DescriptionEmacspeak extensions for view
 ;;; Keywords:emacspeak, audio interface to emacs, view-mode
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-06-21 14:58:40 -0700 (Sat, 21 Jun 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1996 by T. V. Raman 
 ;;; All Rights Reserved. 
 ;;;
@@ -75,7 +75,7 @@
 
 (defadvice view-mode (after emacspeak pre act comp)
   "Announce what happened"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-load-directory-settings)
     (outline-minor-mode 1)
@@ -87,82 +87,82 @@
 
 (defadvice View-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice View-exit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice View-leave (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line)))
 
 (defadvice View-search-regexp-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line ))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice View-search-regexp-backward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line ))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice View-search-last-regexp-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line ))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice View-search-last-regexp-backward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line ))
     (emacspeak-auditory-icon 'search-hit)))
 
 (defadvice view-exit (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice View-scroll-one-more-line (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-line)))
 
 (defadvice View-scroll-line-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-line)))
 
 (defadvice View-scroll-line-backward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-line)))
 (defadvice View-scroll-page-forward-set-page-size (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((start (point )))
       (emacspeak-auditory-icon 'scroll)
       (dtk-speak (emacspeak-get-window-contents)))))
 
 (defadvice View-scroll-page-backward-set-page-size (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((start (point )))
       (emacspeak-auditory-icon 'scroll)
       (dtk-speak (emacspeak-get-window-contents)))))
@@ -170,7 +170,7 @@
 (defadvice View-scroll-half-page-forward (around emacspeak pre act comp)
   "Read newly scrolled contents"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((start (point)))
       ad-do-it
       (emacspeak-auditory-icon 'scroll)
@@ -184,7 +184,7 @@
 (defadvice View-scroll-half-page-backward (around emacspeak pre act comp)
   "Read newly scrolled contents"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((start (point)))
       ad-do-it
       (emacspeak-auditory-icon 'scroll)
@@ -198,7 +198,7 @@
 
 (defadvice View-scroll-lines-forward-set-scroll-size (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((start (point )))
       (emacspeak-auditory-icon 'scroll)
       (save-excursion
@@ -207,14 +207,14 @@
 
 (defadvice View-scroll-lines-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-scroll-lines-backward (around  emacspeak pre act comp)
   "provide auditory feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((buffer (current-buffer)))
       ad-do-it
       (cond
@@ -228,18 +228,17 @@
 
 (defadvice View-back-to-mark ( after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (let ((emacspeak-show-point t))
       (emacspeak-speak-line))))
 
 (defadvice View-goto-line (after emacspeak pre act comp)
   "Provide spoken feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((line-number
            (format "line %s"
-                   (ad-get-arg 0 )))
-          (voice-lock-mode t))
+                   (ad-get-arg 0 ))))
       (put-text-property 0 (length line-number)
                          'personality voice-annotate line-number)
       (emacspeak-auditory-icon 'large-movement)
@@ -248,31 +247,31 @@
                (thing-at-point 'line))))))
 (defadvice View-scroll-to-buffer-end (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'large-movement)))
 
 (defadvice View-goto-percent (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-revert-buffer-scroll-page-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-scroll-page-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
 (defadvice View-scroll-page-backward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (dtk-speak (emacspeak-get-window-contents))))
 
@@ -289,7 +288,7 @@ keybindings for view mode")
         'delete-char
         'completion-kill-region
         )
-  "Editting commands that emacspeak should rebind in view mode")
+  "Editing commands that emacspeak should rebind in view mode")
 
 (defun emacspeak-view-optimize-view-keys()
   "optimize keybindings for emacspeak in view mode"
@@ -300,12 +299,19 @@ keybindings for view mode")
     (setq emacspeak-view-keys-optimized t)
     (loop for edit-command in emacspeak-view-edit-commands
           do
-          (let ((edit-keys (where-is-internal edit-command view-mode-map)))
+          (let ((edit-keys (where-is-internal edit-command (list view-mode-map))))
             (loop for key in edit-keys 
                   do
                   (let ((command (lookup-key emacspeak-keymap key)))
                     (when command
-                      (define-key view-mode-map key command))))))))
+                      (define-key view-mode-map key command))))))
+    (loop for k in
+          '(
+            ("[" backward-paragraph)
+            ("]" forward-paragraph)
+            )
+          do
+          (define-key view-mode-map (first k) (second k)))))
 
 (defun emacspeak-view-setup-keys()
   "Setup emacspeak convenience keys"
@@ -342,7 +348,7 @@ keybindings for view mode")
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
