@@ -1,5 +1,5 @@
 ;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-vm.el 8358 2013-05-29 01:41:54Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
@@ -8,7 +8,7 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-07-31 10:49:44 -0700 (Thu, 31 Jul 2008) $ |
 ;;;  $Revision: 4557 $ |
 ;;; Location undetermined
 ;;;
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -68,12 +68,11 @@ Note that some badly formed mime messages  cause trouble."
   "Setup function placed on vm-mode-hook by Emacspeak."
   (declare (special  dtk-punctuation-mode emacspeak-vm-voice-lock-messages
                      dtk-allcaps-beep))
-  (setq dtk-punctuation-mode 'some)
+  (setq dtk-punctuation-mode 'all)
   (when dtk-allcaps-beep
     (dtk-toggle-allcaps-beep))
   (emacspeak-dtk-sync)
-  (when emacspeak-vm-voice-lock-messages
-    (voice-lock-mode 1)))
+  (when emacspeak-vm-voice-lock-messages))
 
 ;;}}}
 ;;{{{ inline helpers
@@ -157,29 +156,29 @@ Note that some badly formed mime messages  cause trouble."
   (condition-case nil
       (emacspeak-hide-all-blocks-in-buffer)
     (error nil))
-  (emacspeak-auditory-icon 'large-movement)
   (emacspeak-speak-rest-of-buffer))
 
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
   (declare (special vm-message-pointer
+                    smtpmail-local-domain
                     emacspeak-vm-headers-strip-octals
                     emacspeak-vm-user-full-name emacspeak-vm-user-login-name))
   (when vm-message-pointer
-    (dtk-stop)
-    (let*  ((dtk-stop-immediately t )
-            (message (car vm-message-pointer ))
+    (let*  ((message (car vm-message-pointer ))
             (number (emacspeak-vm-number-of  message))
-            (from(or (vm-su-full-name message)
-                     (vm-su-from message )))
+            (from
+             (or (vm-su-full-name message) (vm-su-from message )))
             (subject (vm-su-subject message ))
-            (to(or (vm-su-to-names message)
-                   (vm-su-to message )))
-            (self-p (or
-                     (string-match emacspeak-vm-user-full-name to)
-                     (string-match  (user-login-name) to)))
-            (lines (vm-su-line-count message))
-            (summary nil))
+            (to
+             (or (vm-su-to-names message) (vm-su-to message )))
+            (self-p
+             (or (string-match emacspeak-vm-user-full-name to)
+                 (string-match  (user-login-name) to)
+                 (string-match (format "%s@%s" (user-login-name)
+                                       smtpmail-local-domain)
+                               to)))
+            (lines (vm-su-line-count message)))
       (dtk-speak
        (vm-decode-mime-encoded-words-in-string
         (format "%s %s %s   %s %s "
@@ -189,13 +188,15 @@ Note that some badly formed mime messages  cause trouble."
                 (if (and to (< (length to) 80))
                     (format "to %s" to) "")
                 (if lines (format "%s lines" lines) ""))))
+      (goto-char (point-min))
+      (search-forward  (format "%c%c" 10 10) nil)
       (cond
        ((and self-p
              (= 0 self-p)                    ) ;mail to me and others
         (emacspeak-auditory-icon 'item))
-       (self-p                          ;mail to others including me
+       (self-p                       ;mail to others including me
         (emacspeak-auditory-icon 'mark-object))
-       (t                            ;got it because of a mailing list
+       (t                       ;got it because of a mailing list
         (emacspeak-auditory-icon 'select-object ))))))
 
 (defun emacspeak-vm-speak-labels ()
@@ -214,34 +215,31 @@ Note that some badly formed mime messages  cause trouble."
                     vm-virtual-folder-definition
                     vm-ml-message-new
                     vm-ml-message-number vm-ml-highest-message-number ))
-  (dtk-stop)
-  (emacspeak-dtk-sync)
-  (let ((dtk-stop-immediately nil ))
-    (when (buffer-modified-p )
-      (dtk-tone 700 70))
-    (cond
-     (vm-virtual-folder-definition
-      (dtk-speak
-       (format "Message %s of %s from virtual folder %s"
+  (when (buffer-modified-p )
+    (dtk-tone 700 70))
+  (cond
+   (vm-virtual-folder-definition
+    (dtk-speak
+     (format "Message %s of %s from virtual folder %s"
+             vm-ml-message-number vm-ml-highest-message-number
+             (car vm-virtual-folder-definition))))
+   (t (dtk-speak
+       (format "Message %s of %s,    %s %s %s  %s"
                vm-ml-message-number vm-ml-highest-message-number
-               (car vm-virtual-folder-definition))))
-     (t (dtk-speak
-         (format "Message %s of %s,    %s %s %s  %s"
-                 vm-ml-message-number vm-ml-highest-message-number
-                 (if vm-ml-message-new "new" "")
-                 (if vm-ml-message-unread "unread" "")
-                 (if vm-ml-message-read "read" "")
-                 (mapconcat
-                  (function (lambda(item)
-                              (let ((var (car item))
-                                    (value (cadr item )))
-                                (cond
-                                 ((and (boundp var) (eval var ))
-                                  (if (symbolp value)
-                                      (eval value)
-                                    value))
-                                 (t "")))))
-                  (cdr vm-ml-message-attributes-alist)   " ")))))))
+               (if vm-ml-message-new "new" "")
+               (if vm-ml-message-unread "unread" "")
+               (if vm-ml-message-read "read" "")
+               (mapconcat
+                (function (lambda(item)
+                            (let ((var (car item))
+                                  (value (cadr item )))
+                              (cond
+                               ((and (boundp var) (eval var ))
+                                (if (symbolp value)
+                                    (eval value)
+                                  value))
+                               (t "")))))
+                (cdr vm-ml-message-attributes-alist)   " "))))))
 
 ;;}}}
 ;;{{{  Moving between messages
@@ -263,7 +261,7 @@ that has been forwarded multiple times."
 (defadvice vm-scroll-forward (after emacspeak pre act)
   "Produce auditory feedback.
 Then speak the screenful. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (save-excursion
       (let ((start  (point ))
@@ -274,7 +272,7 @@ Then speak the screenful. "
 (defadvice vm-scroll-backward (after emacspeak pre act)
   "Produce auditory feedback.
 Then speak the screenful. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (save-excursion
       (let ((start  (point ))
@@ -289,8 +287,7 @@ Then speak the screenful. "
 (declaim (special vm-mode-map))
 (eval-when (load)
   (load-library "vm-vars")
-  (emacspeak-keymap-remove-emacspeak-edit-commands
-   vm-mode-map))
+  )
 
 (declaim (special vm-mode-map))
 (define-key vm-mode-map "\M-\C-m" 'widget-button-press)
@@ -306,18 +303,18 @@ Then speak the screenful. "
 
 (defadvice vm-delete-message (after emacspeak pre act)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (message "Message discarded.")))
 
 (defadvice vm-undelete-message (after emacspeak pre act)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Message recovered.")))
 
 (defadvice vm-kill-subject (after emacspeak pre act)
   "Provide auditory feedback. "
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (call-interactively 'vm-next-message)))
 
@@ -326,7 +323,7 @@ Then speak the screenful. "
 
 (defadvice vm-forward-message (around emacspeak pre act)
   "Provide aural feedback."
-  (if (interactive-p)
+  (if (ems-interactive-p )
       (let ((dtk-stop-immediately nil))
         (message "Forwarding message")
         ad-do-it
@@ -336,39 +333,39 @@ Then speak the screenful. "
 
 (defadvice vm-reply (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line)))
 
 (defadvice vm-followup (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Folluwing up")
     (emacspeak-speak-mode-line)))
 
 (defadvice vm-reply-include-text (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-speak-mode-line )))
 
 (defadvice vm-followup-include-text (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Following up")
     (emacspeak-speak-mode-line )))
 (defadvice vm-mail-send (after emacspeak pre act comp)
   "Provide auditory context"
-  (when  (interactive-p)
+  (when  (ems-interactive-p )
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice vm-mail-send-and-exit (after emacspeak pre act comp)
   "Provide auditory context"
-  (when  (interactive-p)
+  (when  (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice vm-mail (after emacspeak pre act)
   "Provide aural feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (let ((dtk-stop-immediately nil))
       (message "Composing a message")
       (emacspeak-speak-line ))))
@@ -378,10 +375,9 @@ Then speak the screenful. "
 
 (defadvice vm-quit (after emacspeak pre act )
   "Provide an auditory icon if requested"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
-    (message "%s"
-             (emacspeak-speak-mode-line))))
+    (emacspeak-speak-mode-line)))
 
 ;;}}}
 ;;{{{ catching up on folders
@@ -415,7 +411,7 @@ Then speak the screenful. "
   "Provide auditory feedback"
   (declare (special vm-message-pointer))
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (cond
@@ -430,7 +426,7 @@ Then speak the screenful. "
   "Provide auditory feedback"
   (declare (special vm-message-pointer))
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point)))
       ad-do-it
       (cond
@@ -456,7 +452,7 @@ Then speak the screenful. "
   "Provide auditory feedback.
 Leave point at front of decoded attachment."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((orig (point )))
       ad-do-it
       (goto-char orig)
@@ -523,7 +519,7 @@ Leave point at front of decoded attachment."
 ;;{{{ advice button motion
 (defadvice vm-next-button (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-speak-text-range  'w3-hyperlink-info)))
 
@@ -729,7 +725,7 @@ text using wvText."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
