@@ -1,10 +1,10 @@
 ;;; emacspeak-w3m.el --- speech-enables w3m-el
-;;;$Id: emacspeak-w3m.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;;$Id: emacspeak-w3m.el 8500 2013-11-02 01:54:49Z tv.raman.tv $
 ;;{{{ Copyright
 
 ;;; This file is not part of Emacs, but the same terms and
 ;;; conditions apply.
-;; Copyright (C) 2001,2002  Dimitri V. Paduchih
+;; Copyright (C) 2001,2002,2011  Dimitri V. Paduchih
 
 ;; Initial version: Author: Dimitri Paduchih <paduch@imm.uran.ru>
 ;;;author: T. V. Raman (integration with Emacspeak, and sections marked TVR)
@@ -43,6 +43,7 @@
 (eval-when-compile
   (condition-case nil
       (require 'w3m)
+    (require 'w3m-util)
     (error nil)))
 (eval-when (load)
   (require 'w3m-util)
@@ -85,9 +86,15 @@ instead of the modeline."
 (define-key w3m-mode-map "l" 'emacspeak-webutils-play-media-at-point)
 (define-key w3m-mode-map "\C-t" 'emacspeak-webutils-transcode-current-url-via-google)
 (define-key w3m-mode-map "\M-t" 'emacspeak-webutils-transcode-via-google)
-(define-key w3m-mode-map "\C-c\C-g" 'emacspeak-webutils-google-on-this-site)
-(define-key w3m-mode-map "\C-c\C-x" 'emacspeak-webutils-google-extract-from-cache)
-(define-key w3m-mode-map "\C-c\C-l" 'emacspeak-webutils-google-similar-to-this-page)
+                                        ; Moved keybindings to avoid conflict with emacs org mode
+                                        ; Avoid use of C-g on request of Raman due to concerns of misuse/confusion
+                                        ; because C-g used for emacs quit 
+                                        ; Moved google related operations to C-cg prefix, with exception of 
+                                        ; google transcode operations, which are left as they were on C-t 
+                                        ; and M-t. TX
+(define-key w3m-mode-map "\C-cgg" 'emacspeak-webutils-google-on-this-site)
+(define-key w3m-mode-map "\C-cgx" 'emacspeak-webutils-google-extract-from-cache)
+(define-key w3m-mode-map "\C-cgl" 'emacspeak-webutils-google-similar-to-this-page)
 (define-key w3m-mode-map (kbd "<C-return>") 'emacspeak-webutils-open-in-other-browser)
 
 ;;}}}
@@ -125,7 +132,7 @@ instead of the modeline."
                        newstring)
     newstring))
 
-(defsubst emacspeak-w3m-url-at-point ()
+(defun emacspeak-w3m-url-at-point ()
   "Return the url at point in w3m."
   (or (w3m-anchor (point)) (w3m-image (point))))
 
@@ -150,12 +157,28 @@ instead of the modeline."
 (defun emacspeak-w3m-anchor-text (&optional default)
   "Return string containing text of anchor under point."
   (if (get-text-property (point) 'w3m-anchor-sequence)
-      (buffer-substring
-       (previous-single-property-change
-        (1+ (point)) 'w3m-anchor-sequence nil (point-min))
-       (next-single-property-change
-        (point) 'w3m-anchor-sequence nil (point-max)))
-    (or default "")))
+      (let* ((anchor-index  (get-text-property (point) 'w3m-anchor-sequence))
+             (start (text-property-any (point-min) (+ 1 (point)) 'w3m-anchor-sequence anchor-index))
+             (pos (next-single-property-change start 'w3m-anchor-sequence nil (point-max)))
+             (value-at-start anchor-index)
+             (value-at-pos nil)
+             anchor-text)
+        (save-excursion
+          (goto-char start)
+          (loop do
+                (when (and (integerp value-at-start) (not value-at-pos))
+                  (push (buffer-substring start pos) anchor-text)
+                  (push " " anchor-text)
+                  (put-text-property 0 1 'personality
+                                     (get-text-property 0 'personality  (cadr anchor-text))
+                                     (car anchor-text)))
+                (setq start pos
+                      value-at-start value-at-pos
+                      pos (next-single-property-change pos 'w3m-anchor-sequence nil (point-max)))
+                (setq value-at-pos (get-text-property pos 'w3m-anchor-sequence))
+                (when (or (eq start (point-max)) (and (integerp value-at-pos) (not (eq value-at-pos anchor-index))))
+                  (return (apply 'concat  (nreverse anchor-text)))))))
+    default))
 
 (defun emacspeak-w3m-speak-cursor-anchor ()
   (dtk-speak (emacspeak-w3m-anchor-text "Not found")))
@@ -278,7 +301,7 @@ instead of the modeline."
 ;; (defadvice w3m-goto-url (around emacspeak pre act)
 ;;   "Speech-enable W3M."
 ;;   (cond
-;;    ((interactive-p)
+;;    ((ems-interactive-p )
 ;;     (emacspeak-auditory-icon 'select-object)
 ;;     (let ((emacspeak-speak-messages nil))
 ;;       ad-do-it))
@@ -287,7 +310,7 @@ instead of the modeline."
 ;; (defadvice w3m-redisplay-this-page (around emacspeak pre act)
 ;;   "Speech-enable W3M."
 ;;   (cond
-;;    ((interactive-p)
+;;    ((ems-interactive-p )
 ;;     (emacspeak-auditory-icon 'select-object)
 ;;     (let ((emacspeak-speak-messages nil))
 ;;       ad-do-it))
@@ -296,7 +319,7 @@ instead of the modeline."
 ;; (defadvice w3m-reload-this-page (around emacspeak pre act)
 ;;   "Speech-enable W3M."
 ;;   (cond
-;;    ((interactive-p)
+;;    ((ems-interactive-p )
 ;;     (emacspeak-auditory-icon 'select-object)
 ;;     (let ((emacspeak-speak-messages nil))
 ;;       ad-do-it))
@@ -311,12 +334,12 @@ instead of the modeline."
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Produce auditory icon."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (emacspeak-auditory-icon 'select-object)))))
 
 (defadvice w3m-submit-form (after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'button)))
 
 (loop for f in
@@ -327,7 +350,7 @@ instead of the modeline."
       (eval
        `(defadvice ,f (after emacspeak pre act comp)
           "Provide auditory feedback."
-          (when (interactive-p)
+          (when (ems-interactive-p )
             (declare (special w3m-current-title))
             (emacspeak-auditory-icon 'select-object)
             (if emacspeak-w3m-speak-titles-on-switch
@@ -336,7 +359,7 @@ instead of the modeline."
 
 (defadvice w3m-delete-buffer (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (declare (special w3m-current-title))
     (emacspeak-auditory-icon 'close-object)
     (if emacspeak-w3m-speak-titles-on-switch
@@ -345,7 +368,7 @@ instead of the modeline."
 
 (defadvice w3m-delete-other-buffers (after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (declare (special w3m-current-title))
     (emacspeak-auditory-icon 'close-object)
     (if emacspeak-w3m-speak-titles-on-switch
@@ -354,7 +377,7 @@ instead of the modeline."
 
 (defadvice w3m-bookmark-kill-entry (around emacspeak pre act comp)
   "Resets the punctuation mode to the one before the delete"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'ask-question)
     (let ((current-punct-mode dtk-punctuation-mode))
       ad-do-it
@@ -363,12 +386,12 @@ instead of the modeline."
 
 (defadvice w3m-bookmark-add-current-url (after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)))
 
 (defadvice w3m-bookmark-add-this-url (after emacspeak pre act comp)
   "Produce auditory icon."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'save-object)))
 
 (loop for f in
@@ -380,7 +403,7 @@ instead of the modeline."
        `(defadvice ,f (around emacspeak pre act)
           "Speech-enable W3M."
           (cond
-           ((interactive-p)
+           ((ems-interactive-p )
             (let ((emacspeak-speak-messages nil))
               ad-do-it
               (emacspeak-auditory-icon 'large-movement)
@@ -391,7 +414,7 @@ instead of the modeline."
 (defadvice w3m-view-this-url (around emacspeak pre act comp)
   "Speech-enable W3M."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((url (emacspeak-w3m-anchor))
           (act (emacspeak-w3m-action)))
       (when url
@@ -412,7 +435,7 @@ instead of the modeline."
 (defadvice w3m-history (around emacspeak pre act)
   "Speech-enable W3M."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (let ((emacspeak-speak-messages nil))
       ad-do-it))
@@ -421,7 +444,7 @@ instead of the modeline."
 (defadvice w3m-antenna (around emacspeak pre act)
   "Speech-enable W3M."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (let ((emacspeak-speak-messages nil))
       ad-do-it))
@@ -430,7 +453,7 @@ instead of the modeline."
 (defadvice w3m-bookmark-view (around emacspeak pre act)
   "Speech-enable W3M."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (let ((emacspeak-speak-messages nil))
       ad-do-it))
@@ -448,7 +471,7 @@ instead of the modeline."
        `(defadvice ,f (around emacspeak pre act comp)
           "Speech-enable scrolling."
           (cond
-           ((interactive-p)
+           ((ems-interactive-p )
             (let ((opoint (save-excursion
                             (beginning-of-line)
                             (point))))
@@ -464,7 +487,7 @@ instead of the modeline."
 (defadvice w3m (around emacspeak pre act)
   "Speech-enable W3M."
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (let ((emacspeak-speak-messages nil))
       ad-do-it)
@@ -474,31 +497,31 @@ instead of the modeline."
 
 (defadvice w3m-process-stop (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 (defadvice w3m-close-window (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (with-current-buffer (window-buffer)
       (emacspeak-speak-mode-line))))
 
 (defadvice w3m-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (with-current-buffer (window-buffer)
       (emacspeak-speak-mode-line))))
 
 (defadvice w3m-wget (after emacspeak pre act comp)
   "provide auditory confirmation"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)))
 
 (defadvice w3m-view-header (after emacspeak pre act comp)
   "Speech enable w3m"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (declare (special w3m-current-title
                       w3m-current-url))
     (cond
@@ -507,7 +530,7 @@ instead of the modeline."
 
 (defadvice w3m-view-source (after emacspeak pre act comp)
   "Speech enable w3m"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (declare (special w3m-current-title
                       w3m-current-url))
     (cond
@@ -516,19 +539,19 @@ instead of the modeline."
 
 (defadvice w3m-history-store-position (after emacspeak pre act comp)
   "Speech enable w3m."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak "Marking page position")))
 
 (defadvice w3m-history-restore-position (after emacspeak pre act comp)
   "Speech enable w3m."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (dtk-speak "Restoring previously marked position")))
 
 (defadvice w3m-history (after emacspeak pre act comp)
   "Speech enable w3m"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (dtk-speak "Viewing history")))
 
 ;;}}}
@@ -545,60 +568,60 @@ instead of the modeline."
 
 (defadvice w3m-select-buffer (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice w3m-select-buffer-show-this-line (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-other-window 1)))
 
 (defadvice w3m-select-buffer-show-this-line-and-down (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'scroll)
     (emacspeak-speak-other-window 1)))
 
 (defadvice w3m-select-buffer-show-this-line-and-switch (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice w3m-select-buffer-show-this-line-and-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
 (defadvice w3m-select-buffer-next-line (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice w3m-select-buffer-previous-line (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice w3m-select-buffer-delete-buffer (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-line)))
 
 (defadvice w3m-select-buffer-delete-other-buffers (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)))
 
 (defadvice w3m-select-buffer-quit (after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
@@ -611,11 +634,11 @@ instead of the modeline."
             (emacspeak-speak-line)))
 
 (defadvice w3m-form-input-select-set (after emacspeak pre act comp)
-  (when (and (interactive-p) (w3m-anchor-sequence))
+  (when (and (ems-interactive-p ) (w3m-anchor-sequence))
     (emacspeak-w3m-speak-this-anchor)))
 
 (defadvice w3m-form-input-select-exit (after emacspeak pre act comp)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
@@ -627,12 +650,12 @@ instead of the modeline."
             (dtk-speak "edit text area")))
 
 (defadvice w3m-form-input-textarea-set (after emacspeak pre act comp)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-w3m-speak-this-anchor)))
 
 (defadvice w3m-form-input-textarea-exit (after emacspeak pre act comp)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
 ;;}}}
@@ -653,8 +676,9 @@ instead of the modeline."
   "Preview this buffer in w3m."
   (interactive)
   (let ((filename
-         (format "/tmp/%s.html"
-                 (make-temp-name "w3m"))))
+         (make-temp-file
+          (format "%s.html"
+                  (make-temp-name "w3m")))))
     (write-region (point-min)
                   (point-max)
                   filename)
@@ -728,7 +752,7 @@ instead of the modeline."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
