@@ -1,5 +1,5 @@
 ;;; emacspeak-we.el --- Transform Web Pages Using XSLT
-;;; $Id: emacspeak-we.el 5375 2007-11-22 00:50:13Z tv.raman.tv $
+;;; $Id: emacspeak-we.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Edit/Transform Web Pages using XSLT
 ;;; Keywords: Emacspeak,  Audio Desktop Web, XSLT
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-11-21 16:50:13 -0800 (Wed, 21 Nov 2007) $ |
+;;; $Date: 2008-08-04 09:12:03 -0700 (Mon, 04 Aug 2008) $ |
 ;;;  $Revision: 4532 $ |
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -82,15 +82,14 @@ a rewrite rule even if one is already defined."
   (let ((url (funcall emacspeak-webutils-url-at-point))
         (redirect nil))
     (unless url (error "Not on a link."))
-    (when (or prompt
-              (null emacspeak-we-url-rewrite-rule))
+    (when (or prompt (null emacspeak-we-url-rewrite-rule))
       (setq emacspeak-we-url-rewrite-rule
             (read-minibuffer  "Specify rewrite rule: " "(")))
     (setq redirect
           (replace-regexp-in-string
            (first emacspeak-we-url-rewrite-rule)
-           (second emacspeak-we-url-rewrite-rule) url)
-          url)
+           (second emacspeak-we-url-rewrite-rule)
+           url))
     (emacspeak-auditory-icon 'select-object)
     (browse-url (or redirect url))))
 
@@ -163,7 +162,7 @@ Nil means no transform is used. "
 
 ;;; Note that emacspeak-we-xsl-transform, emacspeak-we-xsl-params
 ;;; and emacspeak-we-xsl-p
-;;; need to be set at top-lvle since the page-rendering code is
+;;; need to be set at top-level since the page-rendering code is
 ;;; called asynchronously.
 
 ;;;###autoload
@@ -189,7 +188,7 @@ Nil means no transform is used. "
   (interactive (list (emacspeak-xslt-read)))
   (declare (special emacspeak-we-xsl-transform))
   (setq emacspeak-we-xsl-transform xsl)
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (message "Will apply %s before displaying HTML pages."
              (file-name-sans-extension
@@ -201,7 +200,7 @@ Nil means no transform is used. "
   (interactive)
   (declare (special emacspeak-we-xsl-p))
   (setq emacspeak-we-xsl-p (not emacspeak-we-xsl-p))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if emacspeak-we-xsl-p 'on 'off))
     (message "Turned %s XSL"
@@ -244,13 +243,17 @@ Nil means no transform is used. "
   (declare (special emacspeak-we-xsl-keep-result))
   (setq emacspeak-we-xsl-keep-result
         (not emacspeak-we-xsl-keep-result))
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if emacspeak-we-xsl-keep-result
          'on 'off))
     (message "Turned %s xslt keep results."
              (if emacspeak-we-xsl-keep-result
                  'on 'off))))
+(defcustom emacspeak-we-filters-rename-buffer nil
+  "Set to T  if you want the buffer name to contain the applied filter."
+  :type  'boolean
+  :group 'emacspeak-we)
 
 ;;;###autoload
 (defun emacspeak-we-xslt-filter (path    url  &optional speak)
@@ -261,17 +264,16 @@ from Web page -- default is the current page being viewed."
     (read-from-minibuffer "XPath: ")
     (emacspeak-webutils-read-url)
     current-prefix-arg))
-  (declare (special emacspeak-we-xsl-filter ))
+  (declare (special emacspeak-we-xsl-filter
+                    emacspeak-we-filters-rename-buffer))
   (let ((params (emacspeak-xslt-params-from-xpath  path url)))
-    (emacspeak-webutils-rename-buffer (format "Filtered %s" path))
+    (when emacspeak-we-filters-rename-buffer(emacspeak-webutils-rename-buffer (format "Filtered %s" path)))
     (when speak (emacspeak-webutils-autospeak))
     (emacspeak-webutils-with-xsl-environment
      emacspeak-we-xsl-filter
      params
      emacspeak-xslt-options             ;options
-     (browse-url url)
-     (or speak (interactive-p)))))
-
+     (browse-url url))))
 
 ;;;###autoload
 (defun emacspeak-we-xslt-junk (path    url &optional speak)
@@ -280,7 +282,7 @@ from Web page -- default is the current page being viewed."
    (list
     (read-from-minibuffer "XPath: ")
     (emacspeak-webutils-read-url)
-    (interactive-p)))
+    (ems-interactive-p )))
   (declare (special emacspeak-we-xsl-junk ))
   (let ((params (emacspeak-xslt-params-from-xpath  path url)))
     (emacspeak-webutils-rename-buffer
@@ -321,7 +323,7 @@ operate on current web page when in a browser buffer; otherwise
   (interactive
    (list
     (emacspeak-webutils-read-url)
-    (interactive-p)))
+    (ems-interactive-p )))
   (declare (special emacspeak-we-media-stream-suffixes))
   (let ((filter "//a[%s]")
         (predicate
@@ -344,7 +346,7 @@ operate on current web page when in a browser buffer; otherwise
   (interactive
    (list
     (emacspeak-webutils-read-url)
-    (interactive-p)))
+    (ems-interactive-p )))
   (let ((filter "//a[contains(@href,\"print\")]"))
     (emacspeak-we-xslt-filter filter url speak)))
 
@@ -364,7 +366,7 @@ operate on current web page when in a browser buffer; otherwise
    (list
     (read-from-minibuffer "Pattern: ")
     (emacspeak-webutils-read-url)
-    (interactive-p)))
+    (ems-interactive-p )))
   (let ((filter
          (format
           "//a[contains(@href,\"%s\")]"
@@ -381,7 +383,7 @@ spoken automatically."
    (list
     (read-from-minibuffer "Table Index: ")
     (emacspeak-webutils-read-url)
-    (interactive-p)))
+    (ems-interactive-p )))
   (emacspeak-we-xslt-filter
    (format "(//table//table)[%s]" index)
    url speak))
@@ -428,7 +430,7 @@ Empty value finishes the list."
    (list
     (emacspeak-we-get-table-list)
     (emacspeak-webutils-read-url)
-    (interactive-p)))
+    (ems-interactive-p )))
   (let ((filter
          (mapconcat
           #'(lambda  (i)
@@ -451,8 +453,7 @@ Default is to extract from current page."
    (format "/descendant::table[%s]"
            position)
    url
-   (or (interactive-p)
-       speak)))
+   speak))
 
 ;;;###autoload
 (defun emacspeak-we-extract-tables-by-position-list (positions url &optional speak)
@@ -473,7 +474,7 @@ Tables are specified by their position in the list
     (emacspeak-we-xslt-filter
      filter
      url
-     (or (interactive-p)
+     (or (ems-interactive-p )
          speak))))
 
 ;;;###autoload
@@ -489,7 +490,7 @@ Tables are specified by their position in the list
    (format "(/descendant::table[contains(., \"%s\")])[last()]"
            match)
    url
-   (or (interactive-p)
+   (or (ems-interactive-p )
        speak)))
 
 ;;;###autoload
@@ -512,7 +513,7 @@ Tables are specified by containing  match pattern
     (emacspeak-we-xslt-filter
      filter
      url
-     (or (interactive-p)
+     (or (ems-interactive-p )
          speak))))
 
 (defvar emacspeak-we-buffer-class-cache nil
@@ -534,7 +535,6 @@ Tables are specified by containing  match pattern
       (skip-syntax-forward " ")
       (delete-region (point-min) (point))
       (setq values (split-string (buffer-string))))
-    (message "Values: %s" values)
     (add-hook
      'emacspeak-web-post-process-hook
      (eval
@@ -545,7 +545,6 @@ Tables are specified by containing  match pattern
                 ',(copy-sequence values))))))
     (kill-buffer content)))
 
-
 (defvar emacspeak-we-buffer-id-cache nil
   "Caches id attribute values for current buffer.")
 
@@ -572,6 +571,32 @@ Tables are specified by containing  match pattern
                 ',(copy-sequence values))))))
     (kill-buffer content)))
 
+(defvar emacspeak-we-buffer-role-cache nil
+  "Caches role attribute values for current buffer.")
+
+(make-variable-buffer-local 'emacspeak-we-buffer-role-cache)
+
+(defsubst emacspeak-we-build-role-cache ()
+  "Build role cache and forward it to rendered page."
+  (let ((values nil)
+        (content (clone-buffer)))
+    (save-excursion
+      (set-buffer content)
+      (setq buffer-undo-list t)
+      (emacspeak-xslt-run
+       (emacspeak-xslt-get "role-values.xsl")
+       (point-min) (point-max))
+      (setq values (split-string (buffer-string))))
+    (add-hook
+     'emacspeak-web-post-process-hook
+     (eval
+      `(function
+        (lambda nil
+          (declare (special  emacspeak-we-buffer-role-cache))
+          (setq emacspeak-we-buffer-role-cache
+                ',(copy-sequence values))))))
+    (kill-buffer content)))
+
 ;;;###autoload
 (defun emacspeak-we-extract-by-class (class    url &optional speak)
   "Extract elements having specified class attribute from HTML. Extracts
@@ -584,11 +609,26 @@ buffer. Interactive use provides list of class values as completion."
     (emacspeak-webutils-read-url)
     current-prefix-arg))
   (let ((filter (format "//*[contains(@class,\"%s\")]" class)))
-    (message "filter:%s" filter)
     (emacspeak-we-xslt-filter filter
                               url
-                              (or (interactive-p)
+                              (or (ems-interactive-p )
                                   speak))))
+;;;###autoload
+(defun emacspeak-we-junk-by-class (class    url &optional speak)
+  "Extract elements not having specified class attribute from HTML. Extracts
+specified elements from current WWW page and displays it in a separate
+buffer. Interactive use provides list of class values as completion."
+  (interactive
+   (list
+    (completing-read "Class: "
+                     emacspeak-we-buffer-class-cache)
+    (emacspeak-webutils-read-this-url)
+    current-prefix-arg))
+  (let ((filter (format "//*[contains(@class,\"%s\")]" class)))
+    (emacspeak-we-xslt-junk filter
+                            url
+                            (or (ems-interactive-p )
+                                speak))))
 
 (defsubst  emacspeak-we-get-id-list ()
   "Collect a list of ids by prompting repeatedly in the
@@ -638,7 +678,7 @@ values as completion. "
     (let ((completion-ignore-case t))
       (emacspeak-we-css-get-class-list))
     (emacspeak-webutils-read-url)
-        current-prefix-arg))
+    current-prefix-arg))
   (let ((filter
          (mapconcat
           #'(lambda  (c)
@@ -648,7 +688,30 @@ values as completion. "
     (emacspeak-we-xslt-filter
      (format "//*[%s]" filter)
      url
-     (or (interactive-p) speak))))
+     (or (ems-interactive-p ) speak))))
+;;;###autoload
+(defun emacspeak-we-junk-by-class-list(classes   url &optional
+                                                 speak)
+  "Extract elements not having class specified in list `classes' from HTML.
+Extracts specified elements from current WWW page and displays it
+in a separate buffer.  Interactive use provides list of class
+values as completion. "
+  (interactive
+   (list
+    (let ((completion-ignore-case t))
+      (emacspeak-we-css-get-class-list))
+    (emacspeak-webutils-read-this-url)
+    current-prefix-arg))
+  (let ((filter
+         (mapconcat
+          #'(lambda  (c)
+              (format "(@class=\"%s\")" c))
+          classes
+          " or ")))
+    (emacspeak-we-xslt-junk
+     (format "//*[%s]" filter)
+     url
+     (or (ems-interactive-p ) speak))))
 
 ;;;###autoload
 (defun emacspeak-we-extract-by-id (id   url &optional speak)
@@ -667,7 +730,7 @@ Interactive use provides list of id values as completion."
    (format "//*[@id=\"%s\"]"
            id)
    url
-   (or (interactive-p) speak)))
+   speak))
 
 ;;;###autoload
 (defun emacspeak-we-extract-by-id-list(ids   url &optional speak)
@@ -688,33 +751,52 @@ separate buffer. Interactive use provides list of id values as completion. "
     (emacspeak-we-xslt-filter
      (format "//*[%s]" filter)
      url
-     (or (interactive-p)
+     (or (ems-interactive-p )
          speak))))
 
 ;;;###autoload
-(defun emacspeak-we-junk-by-class-list(classes   url &optional speak)
-  "Junk elements having class specified in list `classes' from HTML.
-Extracts specified elements from current WWW page and displays it in a
-separate buffer.
- Interactive use provides list of class values as
-completion. "
+(defun emacspeak-we-extract-id-text (id   url &optional speak)
+  "Extract text nodes from elements having specified id attribute from HTML. Extracts
+specified elements from current WWW page and displays it in a separate
+buffer.
+Interactive use provides list of id values as completion."
   (interactive
    (list
-    (emacspeak-we-css-get-class-list)
+    (let ((completion-ignore-case t))
+      (completing-read "Id: "
+                       emacspeak-we-buffer-id-cache))
+    (emacspeak-webutils-read-url)
+    current-prefix-arg))
+  (emacspeak-we-xslt-filter
+   (format "//*[@id=\"%s\"]//text()"
+           id)
+   url
+   speak))
+
+;;;###autoload
+(defun emacspeak-we-extract-id-list-text(ids   url &optional speak)
+  "Extract text nodes from elements having id specified in list `ids' from HTML.
+Extracts specified elements from current WWW page and displays it in a
+separate buffer. Interactive use provides list of id values as completion. "
+  (interactive
+   (list
+    (emacspeak-we-get-id-list)
     (emacspeak-webutils-read-url)
     current-prefix-arg))
   (let ((filter
          (mapconcat
           #'(lambda  (c)
-              (format "(@class=\"%s\")" c))
-          classes
+              (format "(@id=\"%s\")" c))
+          ids
           " or ")))
-    (emacspeak-we-xslt-junk
-     (format "//*[%s]" filter)
+    (emacspeak-we-xslt-filter
+     (format "//*[%s]//text()" filter)
      url
-     (or (interactive-p)
+     (or (ems-interactive-p )
          speak))))
 
+;;;###autoload
+
 (defvar emacspeak-we-url-rewrite-rule nil
   "URL rewrite rule to use in current buffer.")
 
@@ -799,22 +881,38 @@ specifies the page to extract contents  from."
   (emacspeak-we-xslt-filter
    (format "//*[contains(@style,  \"%s\")]" style)
    url
-   (or (interactive-p) speak)))
+   (or (ems-interactive-p ) speak)))
 
 ;;}}}
 ;;{{{ xpath  filter
 
+(defvar emacspeak-we-xpath-filter-history 
+  (list
+   emacspeak-we-recent-xpath-filter
+   "//p|//div"
+   "//p|//ol|//ul|//dl|//h1|//h2|//h3|//h4|//h5|//h6|//blockquote")
+  "History list recording XPath filters we've used.")
+
+(put 'emacspeak-we-xpath-filter-history 'history-length 10)
+
 (defvar emacspeak-we-xpath-filter nil
   "Buffer local variable specifying a XPath filter for following
 urls.")
 
 (make-variable-buffer-local 'emacspeak-we-xpath-filter)
+;;;###autoload
 (defcustom emacspeak-we-recent-xpath-filter
-  "//p|ol|ul|dl|h1|h2|h3|h4|h5|h6|blockquote|div"
+  "//p|//ol|//ul|//dl|//h1|//h2|//h3|//h4|//h5|//h6|//blockquote|//div"
   "Caches most recently used xpath filter.
 Can be customized to set up initial default."
   :type 'string
   :group 'emacspeak-we)
+;;;###autoload
+(defcustom emacspeak-we-paragraphs-xpath-filter
+  "//p"
+  "Filter paragraphs."
+  :type 'string
+  :group 'emacspeak-we)
 
 ;;;###autoload
 (defun emacspeak-we-xpath-filter-and-follow (&optional prompt)
@@ -824,7 +922,7 @@ interactive prefix arg. If there is a known rewrite url rule, that is
 used as well."
   (interactive "P")
   (declare (special emacspeak-we-xpath-filter
-                    emacspeak-we-recent-xpath-filter
+                    emacspeak-we-recent-xpath-filter emacspeak-we-xpath-filter-history
                     emacspeak-we-url-rewrite-rule))
   (emacspeak-webutils-browser-check)
   (let ((url (funcall emacspeak-webutils-url-at-point))
@@ -838,14 +936,70 @@ used as well."
              url)))
     (when (or prompt (null emacspeak-we-xpath-filter))
       (setq emacspeak-we-xpath-filter
-            (read-from-minibuffer  "Specify XPath: "
-                                   emacspeak-we-recent-xpath-filter))
+            (read-from-minibuffer
+             "Specify XPath: "
+             nil nil nil
+             'emacspeak-we-xpath-filter-history
+             emacspeak-we-recent-xpath-filter))
+      (pushnew emacspeak-we-xpath-filter emacspeak-we-xpath-filter-history)
       (setq emacspeak-we-recent-xpath-filter
             emacspeak-we-xpath-filter))
     (emacspeak-we-xslt-filter emacspeak-we-xpath-filter
                               (or redirect url)
                               'speak)))
 
+(defvar emacspeak-we-class-filter-history 
+  nil
+  "History list recording Class filters we've used.")
+
+(put 'emacspeak-we-class-filter-history 'history-length 10)
+
+(defvar emacspeak-we-class-filter nil
+  "Buffer local variable specifying a Class filter for following
+urls.")
+
+(make-variable-buffer-local 'emacspeak-we-class-filter)
+(defcustom emacspeak-we-recent-class-filter
+  nil
+  "Caches most recently used class filter.
+Can be customized to set up initial default."
+  :type 'string
+  :group 'emacspeak-we)
+;;;###autoload
+(defun emacspeak-we-class-filter-and-follow-link (&optional prompt)
+  "Follow url and point, and filter the result by specified class.
+Class can be set locally for a buffer, and overridden with an
+interactive prefix arg. If there is a known rewrite url rule, that is
+used as well."
+  (interactive "P")
+  (declare (special emacspeak-we-class-filter
+                    emacspeak-we-recent-class-filter emacspeak-we-class-filter-history
+                    emacspeak-we-url-rewrite-rule))
+  (emacspeak-webutils-browser-check)
+  (let ((url (funcall emacspeak-webutils-url-at-point))
+        (redirect nil))
+    (unless url (error "Not on a link."))
+    (when emacspeak-we-url-rewrite-rule
+      (setq redirect
+            (replace-regexp-in-string
+             (first emacspeak-we-url-rewrite-rule)
+             (second emacspeak-we-url-rewrite-rule)
+             url)))
+    (when (or prompt (null emacspeak-we-class-filter))
+      (setq emacspeak-we-class-filter
+            (read-from-minibuffer
+             "Specify Class: "
+             nil nil nil
+             'emacspeak-we-class-filter-history
+             emacspeak-we-recent-class-filter))
+      (pushnew emacspeak-we-class-filter emacspeak-we-class-filter-history)
+      (setq emacspeak-we-recent-class-filter
+            emacspeak-we-class-filter))
+    (emacspeak-we-xslt-filter
+     (format "//*[@class=\"%s\"]"emacspeak-we-class-filter)
+     (or redirect url)
+     'speak)))
+
 (defvar emacspeak-we-xpath-junk nil
   "Records XPath pattern used to junk elements.")
 
@@ -889,6 +1043,39 @@ used as well."
      (or redirect url)
      'speak)))
 
+;;}}}
+;;{{{ Property filter
+
+;;;###autoload
+(defun emacspeak-we-extract-by-property (url &optional speak)
+  "Interactively prompt for an HTML property, e.g. id or class,
+and provide a completion list of applicable  property values. Filter document by property that is specified."
+  (interactive
+   (list
+    (emacspeak-webutils-read-url)
+    current-prefix-arg))
+  (let* ((completion-ignore-case t)
+         (choices
+          (mapcar 'symbol-name (intersection
+                                '(id class style role)
+                                (emacspeak-webutils-property-names-from-html-stack (emacspeak-w3-html-stack)))))
+         (property
+          (read
+           (completing-read "Property: "
+                            choices)))
+         (values (emacspeak-webutils-get-property-from-html-stack
+                  (emacspeak-w3-html-stack)
+                  property))
+         (v (completing-read "Having value: " values))
+         (filter
+          (if (eq property 'class)
+              (format "//*[contains(@%s, \"%s\")]"
+                      property v)
+            (format "//*[@%s=\"%s\"]"
+                    property v))))
+    (emacspeak-we-xslt-filter filter url
+                              (or (ems-interactive-p ) speak))))
+
 ;;}}}
 ;;{{{  xsl keymap
 
@@ -897,6 +1084,8 @@ used as well."
 (loop for binding in
       '(
         ("C" emacspeak-we-extract-by-class-list)
+        ("D" emacspeak-we-junk-by-class-list)
+        ("w" emacspeak-we-extract-by-property)
         ("M" emacspeak-we-extract-tables-by-match-list)
         ("P" emacspeak-we-extract-print-streams)
         ("R" emacspeak-we-extract-media-streams-under-point)
@@ -909,15 +1098,17 @@ used as well."
         ("\C-x" emacspeak-we-count-nested-tables)
         ("a" emacspeak-we-xslt-apply)
         ("c" emacspeak-we-extract-by-class)
+        ("d" emacspeak-we-junk-by-class)
         ("e" emacspeak-we-url-expand-and-execute)
         ("f" emacspeak-we-xslt-filter)
         ("i" emacspeak-we-extract-by-id)
         ("I" emacspeak-we-extract-by-id-list)
         ("j" emacspeak-we-xslt-junk)
-        ("k" emacspeak-we-set-xsl-keep-result)
+        ("k" emacspeak-we-toggle-xsl-keep-result)
         ("m" emacspeak-we-extract-table-by-match)
         ("o" emacspeak-we-xsl-toggle)
         ("p" emacspeak-we-xpath-filter-and-follow)
+        ("v" emacspeak-we-class-filter-and-follow-link)
         ("r" emacspeak-we-extract-media-streams)
         ("S" emacspeak-we-style-filter)
         ("s" emacspeak-we-xslt-select)
@@ -936,7 +1127,7 @@ used as well."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
