@@ -1,5 +1,5 @@
 ;;; emacspeak-widget.el --- Speech enable Emacs' native GUI widget library
-;;; $Id: emacspeak-widget.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-widget.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak extensions to widgets
 ;;; Keywords:emacspeak, audio interface to emacs customized widgets
@@ -8,14 +8,14 @@
 ;;; LCD Archive Entry:
 ;;; emacspeak| T. V. Raman |raman@cs.cornell.edu
 ;;; A speech interface to Emacs |
-;;; $Date: 2007-08-25 18:28:19 -0700 (Sat, 25 Aug 2007) $ |
+;;; $Date: 2008-03-23 20:20:09 -0700 (Sun, 23 Mar 2008) $ |
 ;;;  $Revision: 4532 $ | 
 ;;; Location undetermined
 ;;;
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2011, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -180,8 +180,6 @@ Returns a string with appropriate personality."
     (concat label
             help-echo
             value)))
-     
-           
 
 (widget-put (get 'default 'widget-type)
             :emacspeak-help 'emacspeak-widget-default-summarize)
@@ -252,7 +250,6 @@ Returns a string with appropriate personality."
     (concat label
             help-echo
             context )))
-       
 
 (widget-put (get 'push-button 'widget-type)
             :emacspeak-help 'emacspeak-widget-help-push-button)
@@ -373,7 +370,6 @@ Returns a string with appropriate personality."
             (if child
                 (widget-apply child :emacspeak-help)
               value))))
-      
 
 (widget-put (get 'menu-choice 'widget-type)
             :emacspeak-help 'emacspeak-widget-help-menu-choice)
@@ -411,8 +407,6 @@ Returns a string with appropriate personality."
             " has "
             selections 
             " checked ")))
-     
-      
 
 (widget-put (get 'checklist 'widget-type)
             :emacspeak-help 'emacspeak-widget-help-checklist)
@@ -528,7 +522,7 @@ Returns a string with appropriate personality."
 (defadvice widget-beginning-of-line (after emacspeak pre act comp)
   "Provide auditory feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((widget (widget-at (point ))))
       ad-do-it
       (emacspeak-auditory-icon 'select-object)
@@ -542,7 +536,7 @@ Returns a string with appropriate personality."
 (defadvice widget-end-of-line (around emacspeak pre act comp)
   "Provide auditory feedback"
   (cond
-   ((interactive-p)
+   ((ems-interactive-p )
     (let ((widget (widget-at (point ))))
       ad-do-it
       (emacspeak-auditory-icon 'select-object)
@@ -555,19 +549,19 @@ Returns a string with appropriate personality."
 
 (defadvice widget-forward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-widget-summarize (widget-at  (point )))))
 
 (defadvice widget-backward (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'large-movement)
     (emacspeak-widget-summarize (widget-at (point)))))
 
 (defadvice widget-kill-line (after emacspeak pre act comp)
   "Provide auditory feedback"
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'delete-object)
     (emacspeak-speak-current-kill 0)
     (dtk-tone 500 30)))
@@ -577,22 +571,32 @@ Returns a string with appropriate personality."
 
 (defadvice widget-button-press (around emacspeak pre act comp)
   "Provide auditory feedback"
+  (declare (special emacspeak-webutils-url-at-point
+                    emacspeak-we-url-executor))
   (let ((inhibit-read-only t)
         (widget (widget-at (ad-get-arg 0))))
     (cond
-     (widget                            ; First record some state:
+     (widget                           ; First record some state:
       (let ((pos (ad-get-arg 0))
             (old-position (point)))
-        (when (eq major-mode 'w3-mode)
-          (emacspeak-auditory-icon 'button))
-        ad-do-it
         (cond
-         ((= old-position (point ))     ;did not move
+         ((and
+           (or (eq major-mode 'w3-mode) (eq major-mode 'w3m-mode))
+           emacspeak-webutils-url-at-point
+           (funcall emacspeak-webutils-url-at-point)
+           emacspeak-we-url-executor
+           (boundp 'emacspeak-we-url-executor)
+           (fboundp emacspeak-we-url-executor))
           (emacspeak-auditory-icon 'button)
-          (emacspeak-widget-summarize (widget-at pos)))
-         (t  (emacspeak-auditory-icon 'large-movement)
-             (or (emacspeak-widget-summarize (widget-at (point)))
-                 (emacspeak-speak-line))))))
+          (call-interactively 'emacspeak-we-url-expand-and-execute))
+         (t ad-do-it
+            (cond
+             ((= old-position (point )) ;did not move
+              (emacspeak-auditory-icon 'button)
+              (emacspeak-widget-summarize (widget-at pos)))
+             (t  (emacspeak-auditory-icon 'large-movement)
+                 (or (emacspeak-widget-summarize (widget-at (point)))
+                     (emacspeak-speak-line))))))))
      (t ad-do-it))
     ad-return-value))
 
@@ -667,7 +671,7 @@ widget before summarizing."
               )
         do
         (define-key map  emacspeak-prefix 'emacspeak-prefix-command)
-        (define-key map  "\C-e\C-e" 'widget-end-of-line)
+                                        ;(define-key map  "\C-e\C-e" 'widget-end-of-line)
         (define-key map "\M-h" 'emacspeak-widget-help)
         (define-key map "\M-p" 'emacspeak-widget-summarize-parent)
         (define-key map "\M-\C-m"
@@ -727,7 +731,7 @@ widget before summarizing."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
