@@ -1,5 +1,5 @@
 ;;; emacspeak-xslt-process.el --- speech-enable xslt-process 
-;;; $Id: emacspeak-xslt-process.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id: emacspeak-xslt-process.el 8574 2013-11-24 02:01:07Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak module for speech-enabling
 ;;; xslt-process mode
@@ -17,7 +17,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -55,7 +55,7 @@
 (defadvice xslt-process-toggle-debug-mode (
                                            after emacspeak pre act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon
      (if xslt-process-debug-mode 'on 'off))
     (message "Turned %s xslt debug mode."
@@ -64,7 +64,7 @@
 (defadvice xslt-process-quit-debug (after emacspeak pre act
                                           comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)
     (emacspeak-speak-mode-line)))
 
@@ -72,7 +72,7 @@
                                                   pre act
                                                   comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)
     (emacspeak-speak-mode-line)))
 
@@ -80,7 +80,7 @@
                                                    pre act
                                                    comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)
     (emacspeak-speak-mode-line)))
 
@@ -88,82 +88,82 @@
                                                  pre act
                                                  comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'task-done)
     (emacspeak-speak-mode-line)))
 
 (defadvice xslt-process-set-breakpoint (after emacspeak pre
                                               act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (beginning-of-line)
       (let ((start (point))
             (end (progn (end-of-line)
                         (point))))
-        (ems-modify-buffer-safely
-         (put-text-property start end
-                            'auditory-icon 'mark-object)
-         (put-text-property start end
-                            'personality voice-animate))
+        (with-silent-modifications
+          (put-text-property start end
+                             'auditory-icon 'mark-object)
+          (put-text-property start end
+                             'personality voice-animate))
         (emacspeak-speak-line)
         (emacspeak-auditory-icon 'mark-object)))))
 (defadvice xslt-process-remove-breakpoint (after emacspeak pre
                                                  act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (save-excursion
       (beginning-of-line)
       (let ((start (point))
             (end (progn (end-of-line)
                         (point))))
-        (ems-modify-buffer-safely
-         (put-text-property start end
-                            'auditory-icon nil))
+        (with-silent-modifications
+          (put-text-property start end
+                             'auditory-icon nil))
         (emacspeak-speak-line)
         (emacspeak-auditory-icon 'deselect-object)))))
 
 (defadvice xslt-process-do-run (after emacspeak pre act
                                       comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (message "Debug %s" ad-return-value)))
 (defadvice xslt-process-do-step (after emacspeak pre act
                                        comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice xslt-process-do-next (after emacspeak pre act
                                        comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-line)))
 
 (defadvice xslt-process-do-finish (after emacspeak pre act
                                          comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     
 
     (defadvice xslt-process-do-continue (after emacspeak pre act
                                                comp)
       "Provide auditory feedback."
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (emacspeak-auditory-icon 'select-object)))
 
     (defadvice xslt-process-do-stop (after emacspeak pre act
                                            comp)
       "Provide auditory feedback."
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (emacspeak-auditory-icon 'select-object)))
 
     (defadvice xslt-process-do-quit (after emacspeak pre act
                                            comp)
       "Provide auditory feedback."
-      (when (interactive-p)
+      (when (ems-interactive-p )
         (emacspeak-auditory-icon 'select-object)))
 
     (emacspeak-auditory-icon 'close-object)))
@@ -172,7 +172,7 @@
                                               emacspeak pre
                                               act comp)
   "Provide auditory feedback."
-  (when (interactive-p)
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'open-object)
     (emacspeak-speak-mode-line)))
 
@@ -183,7 +183,7 @@
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
