@@ -1,5 +1,5 @@
 ;;; voice-setup.el --- Setup voices for voice-lock
-;;; $Id: voice-setup.el 5246 2007-09-01 22:30:13Z tv.raman.tv $
+;;; $Id: voice-setup.el 8579 2013-11-25 19:57:31Z tv.raman.tv $
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Voice lock mode for Emacspeak
 ;;{{{  LCD Archive entry:
@@ -14,7 +14,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2007, T. V. Raman
+;;;Copyright (C) 1995 -- 2011, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -48,7 +48,6 @@
 ;;
 ;; Comments will be spoken in `emacspeak-voice-lock-comment-personality'.
 ;; Strings will be spoken in `emacspeak-voice-lock-string-personality'.
-;; Doc strings will be spoken in `emacspeak-voice-lock-doc-string-personality'.
 ;; Function and variable names (in their defining forms) will be
 ;;  spoken in `emacspeak-voice-lock-function-name-personality'.
 ;; Reserved words will be spoken in `emacspeak-voice-lock-keyword-personality'.
@@ -71,7 +70,7 @@
 ;;; defining face->personality mappings.
 ;;; Older code calls def-voice-font directly, but over time those
 ;;; calls will be changed to the more succinct form provided by
-;;; voice-setup-add-map. For use from other moduels, also see
+;;; voice-setup-add-map. For use from other modules, also see
 ;;; function voice-setup-map-face which is useful when mapping a
 ;;; single face.
 ;;; Both voice-setup-add-map and voice-setup-map-face call
@@ -82,20 +81,22 @@
 ;;; style specifications see special form defvoice Voices defined
 ;;; via defvoice can be customized via custom see the
 ;;; documentation for defvoice.
+;;; Code:
 
 ;;}}}
 ;;{{{ Required modules
 
-;;; Code:
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
+(eval-when-compile (require 'easy-mmode))
 (require 'custom)
-(require 'backquote)
 (require 'acss-structure)
 (require 'outloud-voices)
 (require 'multispeech-voices)
+(require 'mac-voices)
 (require 'espeak-voices)
 (require 'dectalk-voices)
+(require 'emacspeak-sounds)
 ;;}}}
 ;;{{{ customization group
 
@@ -151,15 +152,12 @@
   (declare (special  voice-setup-face-voice-table))
   (gethash face voice-setup-face-voice-table))
 
-(defun voice-setup-show-rogue-voices ()
+(defun voice-setup-show-rogue-faces ()
   "Return list of voices that map to non-existent faces."
   (declare (special voice-setup-face-voice-table))
-  (loop
-   for v being the hash-keys of
-   voice-setup-face-voice-table
-   unless (facep v)
-   collect v))
-        
+  (loop for f being the hash-keys of voice-setup-face-voice-table
+        unless (facep f) collect f))
+
 ;;}}}
 ;;{{{ special form def-voice-font
 
@@ -277,9 +275,9 @@ command \\[customize-variable] on <personality>-settings.. "
   `(progn
      (defvar  ,personality
        (voice-setup-personality-from-style ,settings)
-       (concat
-        ,doc
-        ,(format "Customize this overlay via %s-settings."
+       ,(concat
+         doc
+         (format "Customize this overlay via %s-settings."
                  personality )))
      (defcustom ,(intern (format "%s-settings"  personality))
        ,settings
@@ -312,14 +310,14 @@ command \\[customize-variable] on <personality>-settings.. "
        '(lambda  (sym val)
           (let ((voice-name (voice-setup-personality-from-style val)))
             (setq ,personality voice-name)
-;;; update all observers                ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ;
+;;; update all observers                ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ; ;
             (voice-setup-update-personalities ',personality)
             (set-default sym val))))))
 
-;;}}}                                   ; ; ;
-;;{{{ voices defined using ACSS         ; ; ;
+;;}}}                                   ; ; ; ;
+;;{{{ voices defined using ACSS         
 
-;;; these voices are device independent ; ; ;
+;;; these voices are device independent 
 
 (defvoice  voice-punctuations-all (list nil nil nil nil  nil 'all)
   "Turns current voice into one that  speaks all
@@ -420,12 +418,16 @@ punctuations.")
 
 ;;}}}
 ;;{{{  Define some voice personalities:
+
 (voice-setup-add-map
  '(
+   (shr-link voice-bolden)
    (bold voice-bolden)
+   (variable-pitch voice-animate)
    (bold-italic voice-bolden-and-animate)
    (button voice-bolden)
-   (fixed voice-monotone)
+   (link voice-bolden)
+   (warning voice-bolden-and-animate)
    (fixed-pitch voice-monotone)
    (font-lock-builtin-face voice-bolden)
    (font-lock-comment-face voice-monotone)
@@ -435,17 +437,16 @@ punctuations.")
    (font-lock-negation-char-face voice-brighten-extra)
    (font-lock-constant-face voice-lighten)
    (font-lock-doc-face voice-monotone-medium)
-   (font-lock-doc-string-face voice-smoothen-extra)
    (font-lock-function-name-face voice-bolden-medium)
    (font-lock-keyword-face voice-animate-extra)
    (font-lock-preprocessor-face voice-monotone-medium)
    (shadow voice-monotone-medium)
-   (font-lock-reference-face voice-animate-medium)
    (font-lock-string-face voice-lighten-extra)
    (font-lock-type-face voice-smoothen)
    (font-lock-variable-name-face voice-bolden)
    (font-lock-warning-face voice-bolden-and-animate)
    (help-argument-name voice-smoothen)
+   (isearch voice-bolden)
    (highlight voice-animate)
    (italic voice-animate)
    (match voice-animate)
@@ -456,48 +457,54 @@ punctuations.")
 ;;}}}
 ;;{{{ new light-weight voice lock
 
-(defcustom voice-lock-mode t
-  "Determines  if property personality results in text being
-voicified."
-  :type 'boolean
-  :group 'emacspeak)
-
 ;;;###autoload
-(defun voice-lock-mode (&optional arg)
-  "Toggle Voice Lock mode.
-With arg, turn Voice Lock mode on if and only if arg is positive.
+(define-minor-mode voice-lock-mode
+  "Toggle voice lock mode."
+  t nil nil
+  (when (ems-interactive-p )
+    (let ((state (if voice-lock-mode 'on 'off)))
+      (when (ems-interactive-p )
+        (emacspeak-auditory-icon state)))))
 
-This light-weight voice lock engine leverages work already done by
-font-lock.  Voicification is effective only if font lock is on."
-  (interactive "P")
-  ;; Don't turn on Voice Lock mode if we don't have a display (we're running a
-  ;; batch job) or if the buffer is invisible (the name starts with a space).
-  (let ((on-p (and (not noninteractive)
-                   (not (eq (aref (buffer-name) 0) ?\ ))
-                   (if arg
-                       (> (prefix-numeric-value arg) 0)
-                     (not voice-lock-mode)))))
-    (set (make-local-variable 'voice-lock-mode) on-p)
-    ;; Turn on Voice Lock mode.
-    (when on-p
-      )
-    ;; Turn off Voice Lock mode.
-    (force-mode-line-update))
-  (when (interactive-p)
-    (message
-     (format "Turned %s voice lock mode"
-             (if voice-lock-mode "on" "off")))
-    (emacspeak-auditory-icon
-     (if voice-lock-mode
-         'on 'off ))))
 ;;;###autoload
 (defun turn-on-voice-lock ()
   "Turn on Voice Lock mode ."
+  (interactive)
   (unless voice-lock-mode (voice-lock-mode)))
 
+;;;###autoload
+(defun turn-off-voice-lock ()
+  "Turn off Voice Lock mode ."
+  (interactive)
+  (when voice-lock-mode (voice-lock-mode -1)))
+
+;;;### autoload
+(defun voice-lock-toggle ()
+  "Interactively toggle voice lock."
+  (interactive)
+  (if voice-lock-mode
+      (turn-off-voice-lock)
+    (turn-on-voice-lock))
+  (when (ems-interactive-p )
+    (let ((state (if voice-lock-mode 'on 'off)))
+      (when (ems-interactive-p )
+        (emacspeak-auditory-icon state)))))
+
+;;;###autoload
+(defvar global-voice-lock-mode t
+  "Global value of voice-lock-mode.")
+
+(when (string-match "24" emacs-version)
+  (define-globalized-minor-mode global-voice-lock-mode
+    voice-lock-mode turn-on-voice-lock
+    :initialize 'custom-initialize-delay
+    :init-value (not (or noninteractive emacs-basic-display))
+    :group 'voice-lock
+    :version "24.1"))
+
 ;; Install ourselves:
 (declaim (special text-property-default-nonsticky))
-(unless (assoc 'personality text-property-default-nonsticky)
+(unless (assq 'personality text-property-default-nonsticky)
   (push  (cons 'personality t) text-property-default-nonsticky))
 
 (unless (assq 'voice-lock-mode minor-mode-alist)
@@ -526,6 +533,7 @@ Sample text to use comes from variable
 
 ;;}}}
 ;;{{{ interactively silence personalities 
+
 (defvar voice-setup-buffer-face-voice-table (make-hash-table)
   "Hash table used to store buffer local face->personality mappings.")
 ;;;###autoload
@@ -552,7 +560,8 @@ take effect."
          (gethash face voice-setup-buffer-face-voice-table)
          personality)
         (emacspeak-auditory-icon 'close-object)))
-    (normal-mode)))
+    (when (buffer-file-name)
+      (normal-mode))))
 
 ;;}}}
 (provide 'voice-setup)
@@ -560,7 +569,7 @@ take effect."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end:
 
 ;;}}}
